@@ -17,7 +17,9 @@
 #include <stdlib.h>
 
 #ifdef _MSC_VER
+#ifndef UNICODE
 #define UNICODE
+#endif
 #include <locale>
 #include <codecvt>
 #include <stringapiset.h>
@@ -102,6 +104,34 @@ std::string MDAL::readFileToString( const std::string &filename )
   return "";
 }
 
+bool MDAL::deleteFile( const std::string &path )
+{
+  if ( MDAL::fileExists( path ) )
+  {
+#ifdef _MSC_VER
+    std::wstring_convert< std::codecvt_utf8_utf16< wchar_t > > converter;
+    std::wstring wStr = converter.from_bytes( path );
+    return DeleteFileW( wStr.c_str() ) != 0;
+#else
+    return std::remove( path.c_str() ) == 0;
+#endif
+  }
+
+  return false;
+}
+
+bool MDAL::renameFile( const std::string &from, const std::string &to )
+{
+#ifdef _MSC_VER
+  std::wstring_convert< std::codecvt_utf8_utf16< wchar_t > > converter;
+  std::wstring wFrom = converter.from_bytes( from );
+  std::wstring wTo = converter.from_bytes( to );
+  return _wrename( wFrom.c_str(), wTo.c_str() ) == 0;
+#else
+  return std::rename( from.c_str(), to.c_str() ) == 0;
+#endif
+}
+
 bool MDAL::startsWith( const std::string &str, const std::string &substr, ContainsBehaviour behaviour )
 {
   if ( ( str.size() < substr.size() ) || substr.empty() )
@@ -1113,12 +1143,12 @@ std::vector<std::string> MDAL::Library::libraryFilesInDir( const std::string &di
 {
   std::vector<std::string> filesList;
 #ifdef _WIN32
-  WIN32_FIND_DATA data;
+  WIN32_FIND_DATAA data;
   HANDLE hFind;
   std::string pattern = dirPath;
   pattern.push_back( '*' );
 
-  hFind = FindFirstFile( pattern.c_str(), &data );
+  hFind = FindFirstFileA( pattern.c_str(), &data );
 
   if ( hFind == INVALID_HANDLE_VALUE )
     return filesList;
@@ -1129,7 +1159,7 @@ std::vector<std::string> MDAL::Library::libraryFilesInDir( const std::string &di
     if ( !fileName.empty() && fileExtension( fileName ) == ".dll" )
       filesList.push_back( fileName );
   }
-  while ( FindNextFile( hFind, &data ) != 0 );
+  while ( FindNextFileA( hFind, &data ) != 0 );
 
   FindClose( hFind );
 #else
@@ -1140,8 +1170,8 @@ std::vector<std::string> MDAL::Library::libraryFilesInDir( const std::string &di
     std::string fileName( de->d_name );
     if ( !fileName.empty() )
     {
-      std::string extentsion = fileExtension( fileName );
-      if ( extentsion == ".so" || extentsion == ".dylib" )
+      std::string extension = fileExtension( fileName );
+      if ( extension == ".so" || extension == ".dylib" )
         filesList.push_back( fileName );
     }
     de = readdir( dir );
@@ -1160,7 +1190,7 @@ bool MDAL::Library::loadLibrary()
 #ifdef _WIN32
   UINT uOldErrorMode =
     SetErrorMode( SEM_NOOPENFILEERRORBOX | SEM_FAILCRITICALERRORS );
-  d->mLibrary = LoadLibrary( d->mLibraryFile.c_str() );
+  d->mLibrary = LoadLibraryA( d->mLibraryFile.c_str() );
   SetErrorMode( uOldErrorMode );
 #else
   d->mLibrary = dlopen( d->mLibraryFile.c_str(), RTLD_LAZY );
