@@ -12,12 +12,21 @@
 #include "o0abstractstore.h"
 #include "o0requestparameter.h"
 
-/// Base class of OAuth authenticators
-class O0_EXPORT O0BaseAuth : public QObject {
-    Q_OBJECT
+class O2ReplyServer;
+class O2PollServer;
 
+/// Base class of OAuth authenticators
+class O0_EXPORT O0BaseAuth : public QObject
+{
+    Q_OBJECT
 public:
-    explicit O0BaseAuth(QObject *parent = 0);
+    enum class LogLevel
+    {
+        Debug,
+        Warning,
+        Critical
+    };
+    explicit O0BaseAuth(QObject *parent = nullptr, O0AbstractStore *store = nullptr);
 
 public:
     /// Are we authenticated?
@@ -48,6 +57,17 @@ public:
     QString clientSecret();
     void setClientSecret(const QString &value);
 
+    /// Should we use a reply server (default) or an external web interceptor?
+    Q_PROPERTY(bool useExternalWebInterceptor READ useExternalWebInterceptor WRITE setUseExternalWebInterceptor NOTIFY useExternalWebInterceptorChanged)
+    bool useExternalWebInterceptor();
+    void setUseExternalWebInterceptor(bool useExternalWebInterceptor);
+
+    /// Page content on local host after successful oauth.
+    /// Provide it in case you do not want to close the browser, but display something
+    Q_PROPERTY(QByteArray replyContent READ replyContent WRITE setReplyContent NOTIFY replyContentChanged)
+    QByteArray replyContent() const;
+    void setReplyContent(const QByteArray &value);
+
     /// TCP port number to use in local redirections.
     /// The OAuth "redirect_uri" will be set to "http://localhost:<localPort>/".
     /// If localPort is set to 0 (default), O2 will replace it with a free one.
@@ -61,6 +81,14 @@ public:
     /// Construct query string from list of headers
     static QByteArray createQueryParameters(const QList<O0RequestParameter> &parameters);
 
+    /// Sets a custom logging function to use instead of the default qDebug()/qWarning() mechanism
+    static void setLoggingFunction( std::function<void( const QString&, LogLevel level ) > function );
+
+    /// Logs a message
+    ///
+    /// This will default to using qDebug/qWarning, unless a custom logger function has been registered
+    static void log( const QString& message, LogLevel level = LogLevel::Debug );
+
 public Q_SLOTS:
     /// Authenticate.
     Q_INVOKABLE virtual void link() = 0;
@@ -75,6 +103,9 @@ Q_SIGNALS:
     /// Emitted when client can close the browser window.
     void closeBrowser();
 
+    /// Emitted when client needs to show a verification uri and user code
+    void showVerificationUriAndCode(const QUrl &uri, const QString &code);
+
     /// Emitted when authentication/deauthentication succeeded.
     void linkingSucceeded();
 
@@ -90,6 +121,8 @@ Q_SIGNALS:
     void tokenChanged();
     void tokenSecretChanged();
     void extraTokensChanged();
+    void useExternalWebInterceptorChanged( bool enabled );
+    void replyContentChanged();
 
 protected:
     /// Set authentication token.
@@ -104,6 +137,16 @@ protected:
     /// Set extra tokens found in OAuth response
     void setExtraTokens(QVariantMap extraTokens);
 
+    /// Set local reply server
+    void setReplyServer(O2ReplyServer *server);
+
+    O2ReplyServer * replyServer() const;
+
+    /// Set local poll server
+    void setPollServer(O2PollServer *server);
+
+    O2PollServer * pollServer() const;
+
 protected:
     QString clientId_;
     QString clientSecret_;
@@ -114,10 +157,20 @@ protected:
     QUrl authorizeUrl_;
     QUrl accessTokenUrl_;
     quint16 localPort_;
-    O0AbstractStore *store_;
+    O0AbstractStore *store_{nullptr};
     QVariantMap extraTokens_;
     QByteArray pkceCodeVerifier_;
     QString pkceCodeChallenge_;
+    bool useExternalWebInterceptor_{false};
+    QByteArray replyContent_;
+    static std::function<void( const QString&, LogLevel level ) > sLoggingFunction;
+
+private:
+    O2ReplyServer *replyServer_{nullptr};
+    O2PollServer *pollServer_{nullptr};
+
+    friend class TestBaseAuth;
+    friend class TestO2;
 };
 
 #endif // O0BASEAUTH
