@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 ***************************************************************************
     utils.py
@@ -17,9 +15,9 @@
 ***************************************************************************
 """
 
-__author__ = 'Martin Dobias'
-__date__ = 'November 2009'
-__copyright__ = '(C) 2009, Martin Dobias'
+__author__ = "Martin Dobias"
+__date__ = "November 2009"
+__copyright__ = "(C) 2009, Martin Dobias"
 
 """
 QGIS utilities module
@@ -27,7 +25,14 @@ QGIS utilities module
 """
 from typing import List, Dict, Optional
 
-from qgis.PyQt.QtCore import QCoreApplication, QLocale, QThread, qDebug, QUrl
+from qgis.PyQt.QtCore import (
+    QT_VERSION_STR,
+    QCoreApplication,
+    QLocale,
+    QThread,
+    qDebug,
+    QUrl,
+)
 from qgis.PyQt.QtGui import QDesktopServices
 from qgis.PyQt.QtWidgets import QPushButton, QApplication
 from qgis.core import Qgis, QgsMessageLog, qgsfunction, QgsMessageOutput
@@ -45,44 +50,49 @@ import time
 import functools
 
 import builtins
-builtins.__dict__['unicode'] = str
-builtins.__dict__['basestring'] = str
-builtins.__dict__['long'] = int
-builtins.__dict__['Set'] = set
+
+builtins.__dict__["unicode"] = str
+builtins.__dict__["basestring"] = str
+builtins.__dict__["long"] = int
+builtins.__dict__["Set"] = set
 
 # ######################
 # ERROR HANDLING
 
-warnings.simplefilter('default')
+warnings.simplefilter("default")
 warnings.filterwarnings("ignore", "the sets module is deprecated")
 
 
 def showWarning(message, category, filename, lineno, file=None, line=None):
     stk = ""
     for s in traceback.format_stack()[:-2]:
-        if hasattr(s, 'decode'):
+        if hasattr(s, "decode"):
             stk += s.decode(sys.getfilesystemencoding())
         else:
             stk += s
-    if hasattr(filename, 'decode'):
+    if hasattr(filename, "decode"):
         decoded_filename = filename.decode(sys.getfilesystemencoding())
     else:
         decoded_filename = filename
     QgsMessageLog.logMessage(
-        "warning:{}\ntraceback:{}".format(warnings.formatwarning(message, category, decoded_filename, lineno), stk),
-        QCoreApplication.translate("Python", "Python warning")
+        f"warning:{warnings.formatwarning(message, category, decoded_filename, lineno)}\ntraceback:{stk}",
+        QCoreApplication.translate("Python", "Python warning"),
     )
 
 
-def showException(type, value, tb, msg, messagebar=False, level=Qgis.Warning):
+def showException(
+    type, value, tb, msg, messagebar=False, level=Qgis.MessageLevel.Warning
+):
     if msg is None:
-        msg = QCoreApplication.translate('Python', 'An error has occurred while executing Python code:')
+        msg = QCoreApplication.translate(
+            "Python", "An error has occurred while executing Python code:"
+        )
 
-    logmessage = ''
+    logmessage = ""
     for s in traceback.format_exception(type, value, tb):
-        logmessage += s.decode('utf-8', 'replace') if hasattr(s, 'decode') else s
+        logmessage += s.decode("utf-8", "replace") if hasattr(s, "decode") else s
 
-    title = QCoreApplication.translate('Python', 'Python error')
+    title = QCoreApplication.translate("Python", "Python error")
     QgsMessageLog.logMessage(logmessage, title, level)
 
     try:
@@ -111,13 +121,26 @@ def showException(type, value, tb, msg, messagebar=False, level=Qgis.Warning):
         # Return of we already have a message with the same error message
         return
 
-    widget = bar.createMessage(title, msg + " " + QCoreApplication.translate("Python", "See message log (Python Error) for more details."))
+    widget = bar.createMessage(
+        title,
+        msg
+        + " "
+        + QCoreApplication.translate(
+            "Python", "See message log (Python Error) for more details."
+        ),
+    )
     widget.setProperty("Error", msg)
-    stackbutton = QPushButton(QCoreApplication.translate("Python", "Stack trace"), pressed=functools.partial(open_stack_dialog, type, value, tb, msg))
-    button = QPushButton(QCoreApplication.translate("Python", "View message log"), pressed=show_message_log)
+    stackbutton = QPushButton(
+        QCoreApplication.translate("Python", "Stack trace"),
+        pressed=functools.partial(open_stack_dialog, type, value, tb, msg),
+    )
+    button = QPushButton(
+        QCoreApplication.translate("Python", "View message log"),
+        pressed=show_message_log,
+    )
     widget.layout().addWidget(stackbutton)
     widget.layout().addWidget(button)
-    bar.pushWidget(widget, Qgis.Warning)
+    bar.pushWidget(widget, Qgis.MessageLevel.Warning)
 
 
 def show_message_log(pop_error=True):
@@ -132,10 +155,12 @@ def open_stack_dialog(type, value, tb, msg, pop_error=True):
         iface.messageBar().popWidget()
 
     if msg is None:
-        msg = QCoreApplication.translate('Python', 'An error has occurred while executing Python code:')
+        msg = QCoreApplication.translate(
+            "Python", "An error has occurred while executing Python code:"
+        )
 
     # TODO Move this to a template HTML file
-    txt = '''<font color="red"><b>{msg}</b></font>
+    txt = """<font color="red"><b>{msg}</b></font>
 <br>
 <h3>{main_error}</h3>
 <pre>
@@ -149,42 +174,49 @@ def open_stack_dialog(type, value, tb, msg, pop_error=True):
 <h4>{pypath_label}</h4>
 <ul>
 {pypath}
-</ul>'''
+</ul>"""
 
-    error = ''
+    error = ""
     lst = traceback.format_exception(type, value, tb)
     for s in lst:
-        error += s.decode('utf-8', 'replace') if hasattr(s, 'decode') else s
-    error = error.replace('\n', '<br>')
+        error += s.decode("utf-8", "replace") if hasattr(s, "decode") else s
+    error = error.replace("\n", "<br>")
 
-    main_error = lst[-1].decode('utf-8', 'replace') if hasattr(lst[-1], 'decode') else lst[-1]
+    main_error = (
+        lst[-1].decode("utf-8", "replace") if hasattr(lst[-1], "decode") else lst[-1]
+    )
 
-    version_label = QCoreApplication.translate('Python', 'Python version:')
-    qgis_label = QCoreApplication.translate('Python', 'QGIS version:')
-    pypath_label = QCoreApplication.translate('Python', 'Python Path:')
-    txt = txt.format(msg=msg,
-                     main_error=main_error,
-                     error=error,
-                     version_label=version_label,
-                     num=sys.version,
-                     qgis_label=qgis_label,
-                     qversion=Qgis.QGIS_VERSION,
-                     qgisrelease=Qgis.QGIS_RELEASE_NAME,
-                     devversion=Qgis.QGIS_DEV_VERSION,
-                     pypath_label=pypath_label,
-                     pypath="".join("<li>{}</li>".format(path) for path in sys.path))
+    version_label = QCoreApplication.translate("Python", "Python version:")
+    qgis_label = QCoreApplication.translate("Python", "QGIS version:")
+    pypath_label = QCoreApplication.translate("Python", "Python Path:")
+    txt = txt.format(
+        msg=msg,
+        main_error=main_error,
+        error=error,
+        version_label=version_label,
+        num=sys.version,
+        qgis_label=qgis_label,
+        qversion=Qgis.QGIS_VERSION,
+        qgisrelease=Qgis.QGIS_RELEASE_NAME,
+        devversion=Qgis.QGIS_DEV_VERSION,
+        pypath_label=pypath_label,
+        pypath="".join(f"<li>{path}</li>" for path in sys.path),
+    )
 
-    txt = txt.replace('  ', '&nbsp; ')  # preserve whitespaces for nicer output
+    txt = txt.replace("  ", "&nbsp; ")  # preserve whitespaces for nicer output
 
     dlg = QgsMessageOutput.createMessageOutput()
     dlg.setTitle(msg)
-    dlg.setMessage(txt, QgsMessageOutput.MessageHtml)
+    dlg.setMessage(txt, QgsMessageOutput.MessageType.MessageHtml)
     dlg.showMessage()
 
 
 def qgis_excepthook(type, value, tb):
     # detect if running in the main thread
-    in_main_thread = QCoreApplication.instance() is None or QThread.currentThread() == QCoreApplication.instance().thread()
+    in_main_thread = (
+        QCoreApplication.instance() is None
+        or QThread.currentThread() == QCoreApplication.instance().thread()
+    )
 
     # only use messagebar if running in main thread - otherwise it will crash!
     showException(type, value, tb, None, messagebar=in_main_thread)
@@ -213,7 +245,7 @@ iface = None
 
 def initInterface(pointer):
     from qgis.gui import QgisInterface
-    from sip import wrapinstance
+    from qgis.PyQt.sip import wrapinstance
 
     global iface
     iface = wrapinstance(pointer, QgisInterface)
@@ -222,6 +254,9 @@ def initInterface(pointer):
 #######################
 # PLUGINS
 
+# The current path for home directory Python plugins.
+HOME_PLUGIN_PATH: Optional[str] = None
+
 # list of plugin paths. it gets filled in by the QGIS python library
 plugin_paths = []
 
@@ -242,14 +277,14 @@ plugins_metadata_parser = {}
 
 
 def findPlugins(path):
-    """ for internal use: return list of plugins in given path """
+    """for internal use: return list of plugins in given path"""
     for plugin in glob.glob(path + "/*"):
         if not os.path.isdir(plugin):
             continue
-        if not os.path.exists(os.path.join(plugin, '__init__.py')):
+        if not os.path.exists(os.path.join(plugin, "__init__.py")):
             continue
 
-        metadataFile = os.path.join(plugin, 'metadata.txt')
+        metadataFile = os.path.join(plugin, "metadata.txt")
         if not os.path.exists(metadataFile):
             continue
 
@@ -271,7 +306,7 @@ def metadataParser() -> dict:
 
 
 def updateAvailablePlugins(sort_by_dependencies=False):
-    """ Go through the plugin_paths list and find out what plugins are available. """
+    """Go through the plugin_paths list and find out what plugins are available."""
     # merge the lists
     plugins = []
     metadata_parser = {}
@@ -283,16 +318,22 @@ def updateAvailablePlugins(sort_by_dependencies=False):
             if plugin_id not in plugins:
                 plugins.append(plugin_id)
                 metadata_parser[plugin_id] = parser
-                plugin_name_map[parser.get('general', 'name')] = plugin_id
+                plugin_name_map[parser.get("general", "name")] = plugin_id
 
     global plugins_metadata_parser
     plugins_metadata_parser = metadata_parser
 
     global available_plugins
-    available_plugins = _sortAvailablePlugins(plugins, plugin_name_map) if sort_by_dependencies else plugins
+    available_plugins = (
+        _sortAvailablePlugins(plugins, plugin_name_map)
+        if sort_by_dependencies
+        else plugins
+    )
 
 
-def _sortAvailablePlugins(plugins: List[str], plugin_name_map: Dict[str, str]) -> List[str]:
+def _sortAvailablePlugins(
+    plugins: list[str], plugin_name_map: dict[str, str]
+) -> list[str]:
     """Place dependent plugins after their dependencies
 
     1. Make a copy of plugins list to modify it.
@@ -309,7 +350,7 @@ def _sortAvailablePlugins(plugins: List[str], plugin_name_map: Dict[str, str]) -
 
     deps = {}
     for plugin in plugins:
-        deps[plugin] = [plugin_name_map.get(dep, '') for dep in get_plugin_deps(plugin)]
+        deps[plugin] = [plugin_name_map.get(dep, "") for dep in get_plugin_deps(plugin)]
 
     for plugin in plugins:
         _move_plugin(plugin, deps, visited_plugins, sorted_plugins)
@@ -317,7 +358,12 @@ def _sortAvailablePlugins(plugins: List[str], plugin_name_map: Dict[str, str]) -
     return sorted_plugins
 
 
-def _move_plugin(plugin: str, deps: Dict[str, List[str]], visited: List[str], sorted_plugins: List[str]):
+def _move_plugin(
+    plugin: str,
+    deps: dict[str, list[str]],
+    visited: list[str],
+    sorted_plugins: list[str],
+):
     """Use recursion to move a plugin after its dependencies in a list of
     sorted plugins.
 
@@ -358,34 +404,34 @@ def _move_plugin(plugin: str, deps: Dict[str, List[str]], visited: List[str], so
         sorted_plugins.insert(max_index, plugin)
 
 
-def get_plugin_deps(plugin_id: str) -> Dict[str, Optional[str]]:
+def get_plugin_deps(plugin_id: str) -> dict[str, Optional[str]]:
     result = {}
     try:
         parser = plugins_metadata_parser[plugin_id]
-        plugin_deps = parser.get('general', 'plugin_dependencies')
+        plugin_deps = parser.get("general", "plugin_dependencies")
     except (configparser.NoOptionError, configparser.NoSectionError, KeyError):
         return result
 
-    for dep in plugin_deps.split(','):
-        if dep.find('==') > 0:
-            name, version_required = dep.split('==')
+    for dep in plugin_deps.split(","):
+        if "==" in dep:
+            name, version_required = dep.split("==")
         else:
-            name = dep
-            version_required = None
-        result[name] = version_required
+            name, version_required = dep, None
+        result[name.strip()] = version_required.strip() if version_required else None
+
     return result
 
 
 def pluginMetadata(packageName: str, fct: str) -> str:
-    """ fetch metadata from a plugin - use values from metadata.txt """
+    """fetch metadata from a plugin - use values from metadata.txt"""
     try:
-        return plugins_metadata_parser[packageName].get('general', fct)
+        return plugins_metadata_parser[packageName].get("general", fct)
     except Exception:
         return "__error__"
 
 
 def loadPlugin(packageName: str) -> bool:
-    """ load plugin's package """
+    """load plugin's package"""
 
     try:
         __import__(packageName)
@@ -401,13 +447,22 @@ def loadPlugin(packageName: str) -> bool:
         __import__(packageName)
         return True
     except:
-        msg = QCoreApplication.translate("Python", "Couldn't load plugin '{0}'").format(packageName)
-        showException(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2], msg, messagebar=True, level=Qgis.Critical)
+        msg = QCoreApplication.translate("Python", "Couldn't load plugin '{0}'").format(
+            packageName
+        )
+        showException(
+            sys.exc_info()[0],
+            sys.exc_info()[1],
+            sys.exc_info()[2],
+            msg,
+            messagebar=True,
+            level=Qgis.MessageLevel.Critical,
+        )
         return False
 
 
 def _startPlugin(packageName: str) -> bool:
-    """ initializes a plugin, but does not load GUI """
+    """initializes a plugin, but does not load GUI"""
     global plugins, active_plugins, iface, plugin_times
 
     if packageName in active_plugins:
@@ -423,21 +478,32 @@ def _startPlugin(packageName: str) -> bool:
         plugins[packageName] = package.classFactory(iface)
     except:
         _unloadPluginModules(packageName)
-        errMsg = QCoreApplication.translate("Python", "Couldn't load plugin '{0}'").format(packageName)
-        msg = QCoreApplication.translate("Python", "{0} due to an error when calling its classFactory() method").format(errMsg)
-        showException(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2], msg, messagebar=True, level=Qgis.Critical)
+        errMsg = QCoreApplication.translate(
+            "Python", "Couldn't load plugin '{0}'"
+        ).format(packageName)
+        msg = QCoreApplication.translate(
+            "Python", "{0} due to an error when calling its classFactory() method"
+        ).format(errMsg)
+        showException(
+            sys.exc_info()[0],
+            sys.exc_info()[1],
+            sys.exc_info()[2],
+            msg,
+            messagebar=True,
+            level=Qgis.MessageLevel.Critical,
+        )
         return False
     return True
 
 
 def _addToActivePlugins(packageName: str, duration: int):
-    """ Adds a plugin to the list of active plugins """
+    """Adds a plugin to the list of active plugins"""
     active_plugins.append(packageName)
-    plugin_times[packageName] = "{0:02f}s".format(duration)
+    plugin_times[packageName] = f"{duration:02f}s"
 
 
 def startPlugin(packageName: str) -> bool:
-    """ initialize the plugin """
+    """initialize the plugin"""
     global plugins, active_plugins, iface, plugin_times
     start = time.process_time()
     if not _startPlugin(packageName):
@@ -449,9 +515,20 @@ def startPlugin(packageName: str) -> bool:
     except:
         del plugins[packageName]
         _unloadPluginModules(packageName)
-        errMsg = QCoreApplication.translate("Python", "Couldn't load plugin '{0}'").format(packageName)
-        msg = QCoreApplication.translate("Python", "{0} due to an error when calling its initGui() method").format(errMsg)
-        showException(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2], msg, messagebar=True, level=Qgis.Critical)
+        errMsg = QCoreApplication.translate(
+            "Python", "Couldn't load plugin '{0}'"
+        ).format(packageName)
+        msg = QCoreApplication.translate(
+            "Python", "{0} due to an error when calling its initGui() method"
+        ).format(errMsg)
+        showException(
+            sys.exc_info()[0],
+            sys.exc_info()[1],
+            sys.exc_info()[2],
+            msg,
+            messagebar=True,
+            level=Qgis.MessageLevel.Critical,
+        )
         return False
 
     end = time.process_time()
@@ -460,18 +537,29 @@ def startPlugin(packageName: str) -> bool:
 
 
 def startProcessingPlugin(packageName: str) -> bool:
-    """ initialize only the Processing components of a plugin """
+    """initialize only the Processing components of a plugin"""
     global plugins, active_plugins, iface, plugin_times
     start = time.process_time()
     if not _startPlugin(packageName):
         return False
 
-    errMsg = QCoreApplication.translate("Python", "Couldn't load plugin '{0}'").format(packageName)
-    if not hasattr(plugins[packageName], 'initProcessing'):
+    errMsg = QCoreApplication.translate("Python", "Couldn't load plugin '{0}'").format(
+        packageName
+    )
+    if not hasattr(plugins[packageName], "initProcessing"):
         del plugins[packageName]
         _unloadPluginModules(packageName)
-        msg = QCoreApplication.translate("Python", "{0} - plugin has no initProcessing() method").format(errMsg)
-        showException(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2], msg, messagebar=True, level=Qgis.Critical)
+        msg = QCoreApplication.translate(
+            "Python", "{0} - plugin has no initProcessing() method"
+        ).format(errMsg)
+        showException(
+            sys.exc_info()[0],
+            sys.exc_info()[1],
+            sys.exc_info()[2],
+            msg,
+            messagebar=True,
+            level=Qgis.MessageLevel.Critical,
+        )
         return False
 
     # initProcessing
@@ -480,8 +568,16 @@ def startProcessingPlugin(packageName: str) -> bool:
     except:
         del plugins[packageName]
         _unloadPluginModules(packageName)
-        msg = QCoreApplication.translate("Python", "{0} due to an error when calling its initProcessing() method").format(errMsg)
-        showException(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2], msg, messagebar=True)
+        msg = QCoreApplication.translate(
+            "Python", "{0} due to an error when calling its initProcessing() method"
+        ).format(errMsg)
+        showException(
+            sys.exc_info()[0],
+            sys.exc_info()[1],
+            sys.exc_info()[2],
+            msg,
+            messagebar=True,
+        )
         return False
 
     end = time.process_time()
@@ -490,8 +586,27 @@ def startProcessingPlugin(packageName: str) -> bool:
     return True
 
 
+def finalizeProcessingStartup() -> bool:
+    """
+    Finalizes the startup of the Processing plugin
+
+    This should only be called after the startProcessingPlugin() method has been called
+    for every installed and enabled plugin.
+    """
+    global plugins, active_plugins, iface, plugin_times
+    if "processing" not in plugins:
+        return False
+
+    try:
+        plugins["processing"].finalizeStartup()
+    except:
+        return False
+
+    return True
+
+
 def canUninstallPlugin(packageName: str) -> bool:
-    """ confirm that the plugin can be uninstalled """
+    """confirm that the plugin can be uninstalled"""
     global plugins, active_plugins
 
     if packageName not in plugins:
@@ -506,12 +621,18 @@ def canUninstallPlugin(packageName: str) -> bool:
         return bool(metadata.canBeUninstalled())
     except:
         msg = "Error calling " + packageName + ".canBeUninstalled"
-        showException(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2], msg, messagebar=True)
+        showException(
+            sys.exc_info()[0],
+            sys.exc_info()[1],
+            sys.exc_info()[2],
+            msg,
+            messagebar=True,
+        )
         return True
 
 
 def unloadPlugin(packageName: str) -> bool:
-    """ unload and delete plugin! """
+    """unload and delete plugin!"""
     global plugins, active_plugins
 
     if packageName not in plugins:
@@ -526,13 +647,21 @@ def unloadPlugin(packageName: str) -> bool:
         _unloadPluginModules(packageName)
         return True
     except Exception as e:
-        msg = QCoreApplication.translate("Python", "Error while unloading plugin {0}").format(packageName)
-        showException(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2], msg, messagebar=True)
+        msg = QCoreApplication.translate(
+            "Python", "Error while unloading plugin {0}"
+        ).format(packageName)
+        showException(
+            sys.exc_info()[0],
+            sys.exc_info()[1],
+            sys.exc_info()[2],
+            msg,
+            messagebar=True,
+        )
         return False
 
 
 def _unloadPluginModules(packageName: str):
-    """ unload plugin package with all its modules (files) """
+    """unload plugin package with all its modules (files)"""
     global _plugin_modules
 
     if packageName not in _plugin_modules:
@@ -548,14 +677,14 @@ def _unloadPluginModules(packageName: str):
         # otherwise we might experience a segfault next time the plugin is loaded
         # because Qt will try to access invalid plugin resource data
         try:
-            if hasattr(sys.modules[mod], 'qCleanupResources'):
+            if hasattr(sys.modules[mod], "qCleanupResources"):
                 sys.modules[mod].qCleanupResources()
         except:
             # Print stack trace for debug
             qDebug("qCleanupResources error:\n%s" % traceback.format_exc())
 
         # try removing path
-        if hasattr(sys.modules[mod], '__path__'):
+        if hasattr(sys.modules[mod], "__path__"):
             for path in sys.modules[mod].__path__:
                 try:
                     sys.path.remove(path)
@@ -573,16 +702,16 @@ def _unloadPluginModules(packageName: str):
 
 
 def isPluginLoaded(packageName: str) -> bool:
-    """ find out whether a plugin is active (i.e. has been started) """
+    """find out whether a plugin is active (i.e. has been started)"""
     global plugins, active_plugins
 
     if packageName not in plugins:
         return False
-    return (packageName in active_plugins)
+    return packageName in active_plugins
 
 
 def reloadPlugin(packageName: str) -> bool:
-    """ unload and start again a plugin """
+    """unload and start again a plugin"""
     global active_plugins
     if packageName not in active_plugins:
         return False  # it's not active
@@ -629,7 +758,7 @@ def showPluginHelp(packageName: str = None, filename: str = "index", section: st
 
 
 def pluginDirectory(packageName: str) -> str:
-    """ return directory where the plugin resides. Plugin must be loaded already """
+    """return directory where the plugin resides. Plugin must be loaded already"""
     return os.path.dirname(sys.modules[packageName].__file__)
 
 
@@ -640,12 +769,15 @@ def reloadProjectMacros():
     from qgis.core import QgsProject
 
     code, ok = QgsProject.instance().readEntry("Macros", "/pythonCode")
-    if not ok or not code or code == '':
+    if not ok or not code or code == "":
         return
 
     # create a new empty python module
     import importlib
-    mod = importlib.util.module_from_spec(importlib.machinery.ModuleSpec("proj_macros_mod", None))
+
+    mod = importlib.util.module_from_spec(
+        importlib.machinery.ModuleSpec("proj_macros_mod", None)
+    )
 
     # set the module code and store it sys.modules
     exec(str(code), mod.__dict__)
@@ -668,7 +800,7 @@ def openProjectMacro():
     if "proj_macros_mod" not in sys.modules:
         return
     mod = sys.modules["proj_macros_mod"]
-    if hasattr(mod, 'openProject'):
+    if hasattr(mod, "openProject"):
         mod.openProject()
 
 
@@ -676,7 +808,7 @@ def saveProjectMacro():
     if "proj_macros_mod" not in sys.modules:
         return
     mod = sys.modules["proj_macros_mod"]
-    if hasattr(mod, 'saveProject'):
+    if hasattr(mod, "saveProject"):
         mod.saveProject()
 
 
@@ -684,10 +816,57 @@ def closeProjectMacro():
     if "proj_macros_mod" not in sys.modules:
         return
     mod = sys.modules["proj_macros_mod"]
-    if hasattr(mod, 'closeProject'):
+    if hasattr(mod, "closeProject"):
         mod.closeProject()
 
 
+#######################
+
+
+def _list_project_expression_functions():
+    """Get a list of expression functions stored in the current project"""
+    import ast
+    from qgis.core import QgsProject
+
+    functions = []
+    project_functions, ok = QgsProject.instance().readEntry(
+        "ExpressionFunctions", "/pythonCode"
+    )
+    if ok and project_functions:
+        code = ast.parse(project_functions)
+
+        for e in code.body:
+            if isinstance(e, ast.FunctionDef):
+                for d in e.decorator_list:
+                    if d.func.id == "qgsfunction":
+                        functions.append(e.name)
+
+    return functions
+
+
+def clean_project_expression_functions():
+    """
+    Unload expression functions from current project
+    and reload user expressions from profile folder
+    to avoid any potential overwrite from the
+    unloaded project functions
+    """
+    project_functions = _list_project_expression_functions()
+    if project_functions:
+        from qgis.core import QgsExpression
+
+        for function in project_functions:
+            QgsExpression.unregisterFunction(function)
+
+        # Reload user expressions
+        from qgis.core import QgsApplication
+        import expressions
+
+        userpythonhome = os.path.join(QgsApplication.qgisSettingsDirPath(), "python")
+        expressionspath = os.path.join(userpythonhome, "expressions")
+        expressions.reload(expressionspath)
+
+
 #######################
 # SERVER PLUGINS
 #
@@ -710,13 +889,14 @@ serverIface = None
 def initServerInterface(pointer):
     from qgis.server import QgsServerInterface
     from sip import wrapinstance
+
     sys.excepthook = sys.__excepthook__
     global serverIface
     serverIface = wrapinstance(pointer, QgsServerInterface)
 
 
 def startServerPlugin(packageName: str):
-    """ initialize the plugin """
+    """initialize the plugin"""
     global server_plugins, server_active_plugins, serverIface
 
     if packageName in server_active_plugins:
@@ -726,15 +906,18 @@ def startServerPlugin(packageName: str):
 
     package = sys.modules[packageName]
 
-    errMsg = QCoreApplication.translate("Python", "Couldn't load server plugin {0}").format(packageName)
+    errMsg = QCoreApplication.translate(
+        "Python", "Couldn't load server plugin {0}"
+    ).format(packageName)
 
     # create an instance of the plugin
     try:
         server_plugins[packageName] = package.serverClassFactory(serverIface)
     except:
         _unloadPluginModules(packageName)
-        msg = QCoreApplication.translate("Python",
-                                         "{0} due to an error when calling its serverClassFactory() method").format(errMsg)
+        msg = QCoreApplication.translate(
+            "Python", "{0} due to an error when calling its serverClassFactory() method"
+        ).format(errMsg)
         showException(sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2], msg)
         return False
 
@@ -745,7 +928,7 @@ def startServerPlugin(packageName: str):
 
 def spatialite_connect(*args, **kwargs):
     """returns a dbapi2.Connection to a SpatiaLite db
-using the "mod_spatialite" extension (python3)"""
+    using the "mod_spatialite" extension (python3)"""
     import sqlite3
     import re
 
@@ -762,12 +945,12 @@ using the "mod_spatialite" extension (python3)"""
         # SpatiaLite >= 4.2 and Sqlite < 3.7.17 (Travis)
         ("mod_spatialite.so", "sqlite3_modspatialite_init"),
         # SpatiaLite < 4.2 (linux)
-        ("libspatialite.so", "sqlite3_extension_init")
+        ("libspatialite.so", "sqlite3_extension_init"),
     ]
     found = False
     for lib, entry_point in libs:
         try:
-            cur.execute("select load_extension('{}', '{}')".format(lib, entry_point))
+            cur.execute(f"select load_extension('{lib}', '{entry_point}')")
         except sqlite3.OperationalError:
             continue
         else:
@@ -775,12 +958,14 @@ using the "mod_spatialite" extension (python3)"""
             break
     if not found:
         raise RuntimeError("Cannot find any suitable spatialite module")
-    if any(['.gpkg' in arg for arg in args]):
+    if any([".gpkg" in arg for arg in args]):
         try:
             cur.execute("SELECT EnableGpkgAmphibiousMode()")
         except (sqlite3.Error, sqlite3.DatabaseError, sqlite3.NotSupportedError):
-            QgsMessageLog.logMessage("warning:{}".format("Could not enable geopackage amphibious mode"),
-                                     QCoreApplication.translate("Python", "Python warning"))
+            QgsMessageLog.logMessage(
+                "warning:{}".format("Could not enable geopackage amphibious mode"),
+                QCoreApplication.translate("Python", "Python warning"),
+            )
 
     cur.close()
     con.enable_load_extension(False)
@@ -788,7 +973,7 @@ using the "mod_spatialite" extension (python3)"""
     return con
 
 
-class OverrideCursor():
+class OverrideCursor:
     """
     Executes a code block with a different cursor set and makes sure the cursor
     is restored even if exceptions are raised or an intermediate ``return``
@@ -815,15 +1000,15 @@ class OverrideCursor():
 #######################
 # IMPORT wrapper
 
-if os.name == 'nt' and sys.version_info < (3, 8):
+if os.name == "nt" and sys.version_info < (3, 8):
     import ctypes
     from ctypes import windll, wintypes
 
-    kernel32 = ctypes.WinDLL('kernel32', use_last_error=True)
+    kernel32 = ctypes.WinDLL("kernel32", use_last_error=True)
 
-    _hasAddDllDirectory = hasattr(kernel32, 'AddDllDirectory')
+    _hasAddDllDirectory = hasattr(kernel32, "AddDllDirectory")
     if _hasAddDllDirectory:
-        _import_path = os.environ['PATH']
+        _import_path = os.environ["PATH"]
         _import_paths = {}
 
         def _errcheck_zero(result, func, args):
@@ -845,10 +1030,12 @@ if os.name == 'nt' and sys.version_info < (3, 8):
 _uses_builtins = True
 try:
     import builtins
+
     _builtin_import = builtins.__import__
 except AttributeError:
     _uses_builtins = False
     import __builtin__
+
     _builtin_import = __builtin__.__import__
 
 _plugin_modules = {}
@@ -862,28 +1049,49 @@ def _import(name, globals={}, locals={}, fromlist=[], level=None):
     if level is None:
         level = 0
 
-    if 'PyQt4' in name:
-        msg = 'PyQt4 classes cannot be imported in QGIS 3.x.\n' \
-              'Use {} or the version independent {} import instead.'.format(name.replace('PyQt4', 'PyQt5'), name.replace('PyQt4', 'qgis.PyQt'))
+    if "PyQt4" in name:
+        msg = (
+            "PyQt4 classes cannot be imported in QGIS 3.x.\n"
+            "Use {} or preferably the version independent {} import instead.".format(
+                name.replace("PyQt4", "PyQt5"), name.replace("PyQt4", "qgis.PyQt")
+            )
+        )
+        raise ImportError(msg)
+    qt_version = int(QT_VERSION_STR.split(".")[0])
+    if qt_version == 5 and "PyQt6" in name:
+        msg = (
+            "PyQt6 classes cannot be imported in a QGIS build based on Qt5.\n"
+            "Use {} or preferably the version independent {} import instead (where available).".format(
+                name.replace("PyQt6", "PyQt5"), name.replace("PyQt6", "qgis.PyQt")
+            )
+        )
+        raise ImportError(msg)
+    elif qt_version == 6 and "PyQt5" in name:
+        msg = (
+            "PyQt5 classes cannot be imported in a QGIS build based on Qt6.\n"
+            "Use {} or preferably the version independent {} import instead (where available).".format(
+                name.replace("PyQt5", "PyQt6"), name.replace("PyQt5", "qgis.PyQt")
+            )
+        )
         raise ImportError(msg)
 
-    if os.name == 'nt' and sys.version_info < (3, 8):
+    if os.name == "nt" and sys.version_info < (3, 8):
         global _hasAddDllDirectory
         if _hasAddDllDirectory:
             global _import_path
             global _import_paths
 
             old_path = _import_path
-            new_path = os.environ['PATH']
+            new_path = os.environ["PATH"]
             if old_path != new_path:
                 global _AddDllDirectory
                 global _RemoveDllDirectory
 
-                for p in set(new_path.split(';')) - set(old_path.split(';')):
+                for p in set(new_path.split(";")) - set(old_path.split(";")):
                     if p is not None and p not in _import_path and os.path.isdir(p):
                         _import_paths[p] = _AddDllDirectory(p)
 
-                for p in set(old_path.split(';')) - set(new_path.split(';')):
+                for p in set(old_path.split(";")) - set(new_path.split(";")):
                     if p in _import_paths:
                         _RemoveDllDirectory(_import_paths.pop(p))
 
@@ -891,9 +1099,9 @@ def _import(name, globals={}, locals={}, fromlist=[], level=None):
 
     mod = _builtin_import(name, globals, locals, fromlist, level)
 
-    if mod and getattr(mod, '__file__', None):
+    if mod and getattr(mod, "__file__", None):
         module_name = mod.__name__ if fromlist else name
-        package_name = module_name.split('.')[0]
+        package_name = module_name.split(".")[0]
         # check whether the module belongs to one of our plugins
         if package_name in available_plugins:
             if package_name not in _plugin_modules:
@@ -909,7 +1117,7 @@ def _import(name, globals={}, locals={}, fromlist=[], level=None):
     return mod
 
 
-if not os.environ.get('QGIS_NO_OVERRIDE_IMPORT'):
+if not os.environ.get("QGIS_NO_OVERRIDE_IMPORT"):
     if _uses_builtins:
         builtins.__import__ = _import
     else:
@@ -919,43 +1127,87 @@ if not os.environ.get('QGIS_NO_OVERRIDE_IMPORT'):
 def processing_algorithm_from_script(filepath: str):
     """
     Tries to import a Python processing algorithm from given file, and returns an instance
-    of the algorithm
+    of the algorithm.
+
+    Warning -- this ALSO execs the file as a script, so treat with caution!
     """
     import sys
     import inspect
     from qgis.processing import alg
+
+    filename = filepath.replace("\\\\", "/")
+    dirname = os.path.dirname(filename)
+
+    # Append the directory of the file to the path and set __file__ to the filename
+    added_script_dir_to_path = False
+    if dirname not in sys.path:
+        sys.path.append(dirname)
+        added_script_dir_to_path = True
+
+    alg_instance = None
+
     try:
-        from qgis.core import QgsApplication, QgsProcessingAlgorithm, QgsProcessingFeatureBasedAlgorithm
-        _locals = {}
-        with open(filepath.replace("\\\\", "/").encode(sys.getfilesystemencoding())) as input_file:
-            exec(input_file.read(), _locals)
+        from qgis.core import (
+            QgsApplication,
+            QgsProcessingAlgorithm,
+            QgsProcessingFeatureBasedAlgorithm,
+        )
+
+        _locals = {"__file__": filename}
+
+        with open(filename.encode(sys.getfilesystemencoding())) as input_file:
+            code_object = compile(input_file.read(), filename, "exec")
+            exec(code_object, _locals)
         alg_instance = None
         try:
             alg_instance = alg.instances.pop().createInstance()
         except IndexError:
             for name, attr in _locals.items():
-                if inspect.isclass(attr) and issubclass(attr, (QgsProcessingAlgorithm, QgsProcessingFeatureBasedAlgorithm)) and attr.__name__ not in ("QgsProcessingAlgorithm", "QgsProcessingFeatureBasedAlgorithm"):
+                if (
+                    inspect.isclass(attr)
+                    and issubclass(
+                        attr,
+                        (QgsProcessingAlgorithm, QgsProcessingFeatureBasedAlgorithm),
+                    )
+                    and attr.__name__
+                    not in (
+                        "QgsProcessingAlgorithm",
+                        "QgsProcessingFeatureBasedAlgorithm",
+                    )
+                ):
                     alg_instance = attr()
                     break
-        if alg_instance:
-            script_provider = QgsApplication.processingRegistry().providerById("script")
-            alg_instance.setProvider(script_provider)
-            alg_instance.initAlgorithm()
-            return alg_instance
+
     except ImportError:
         pass
 
-    return None
+    if alg_instance:
+        script_provider = QgsApplication.processingRegistry().providerById("script")
+        alg_instance.setProvider(script_provider)
+        alg_instance.initAlgorithm()
+
+    # gracefully clean up, restore previous system paths
+
+    if added_script_dir_to_path:
+        try:
+            sys.path.remove(dirname)
+        except ValueError:
+            pass
+
+    return alg_instance
 
 
 def import_script_algorithm(filepath: str) -> Optional[str]:
     """
     Imports a script algorithm from given file to the processing script provider, and returns the
-    ID of the imported algorithm
+    ID of the imported algorithm.
+
+    Warning -- this ALSO execs the file as a script, so treat with caution!
     """
     alg_instance = processing_algorithm_from_script(filepath)
     if alg_instance:
         from qgis.core import QgsApplication
+
         script_provider = QgsApplication.processingRegistry().providerById("script")
         script_provider.add_algorithm_class(type(alg_instance))
         return alg_instance.id()
@@ -973,6 +1225,8 @@ def run_script_from_file(filepath: str):
     except ImportError:
         return
 
+    # Despite the misleading name, processing_algorithm_from_script will ALWAYS
+    # execute the script from the file!
     alg_instance = processing_algorithm_from_script(filepath)
     if alg_instance:
         execAlgorithmDialog(alg_instance)
