@@ -15,6 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "qgselevationprofilewidget.h"
+#include "moc_qgselevationprofilewidget.cpp"
 #include "qgisapp.h"
 #include "qgsapplication.h"
 #include "qgselevationprofilecanvas.h"
@@ -25,6 +26,7 @@
 #include "qgsmaptoolprofilecurve.h"
 #include "qgsmaptoolprofilecurvefromfeature.h"
 #include "qgsprojectelevationproperties.h"
+#include "qgsvectorlayerelevationproperties.h"
 #include "qgsrubberband.h"
 #include "qgsplottoolpan.h"
 #include "qgsplottoolxaxiszoom.h"
@@ -55,11 +57,13 @@
 #include "qgsprofileexporter.h"
 #include "qgsexpressioncontextutils.h"
 #include "qgsterrainprovider.h"
+#include "qgsprofilesourceregistry.h"
+#include "qgsnewnamedialog.h"
 
 #include <QToolBar>
 #include <QProgressBar>
 #include <QTimer>
-#include <QPrinter>
+#include <QPdfWriter>
 #include <QSplitter>
 #include <QShortcut>
 #include <QActionGroup>
@@ -106,9 +110,9 @@ void QgsElevationProfileLayersDialog::setHiddenLayers( const QList<QgsMapLayer *
   mModel->setExceptedLayerList( layers );
 }
 
-QList< QgsMapLayer *> QgsElevationProfileLayersDialog::selectedLayers() const
+QList<QgsMapLayer *> QgsElevationProfileLayersDialog::selectedLayers() const
 {
-  QList< QgsMapLayer * > layers;
+  QList<QgsMapLayer *> layers;
 
   const QModelIndexList selection = listMapLayers->selectionModel()->selectedIndexes();
   for ( const QModelIndex &index : selection )
@@ -131,7 +135,7 @@ void QgsElevationProfileLayersDialog::filterVisible( bool enabled )
   if ( enabled )
     mModel->setLayerAllowlist( mVisibleLayers );
   else
-    mModel->setLayerAllowlist( QList< QgsMapLayer * >() );
+    mModel->setLayerAllowlist( QList<QgsMapLayer *>() );
 }
 
 
@@ -160,8 +164,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   mCanvas->setLockAxisScales( settingLockAxis->value() );
 
   mCanvas->setBackgroundColor( settingBackgroundColor->value() );
-  connect( QgsGui::instance(), &QgsGui::optionsChanged, this, [ = ]
-  {
+  connect( QgsGui::instance(), &QgsGui::optionsChanged, this, [=] {
     mCanvas->setBackgroundColor( settingBackgroundColor->value() );
   } );
 
@@ -170,8 +173,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   mLayerTreeView = new QgsAppElevationProfileLayerTreeView( mLayerTree.get() );
   connect( mLayerTreeView, &QgsAppElevationProfileLayerTreeView::addLayers, this, &QgsElevationProfileWidget::addLayersInternal );
 
-  connect( mLayerTreeView, &QAbstractItemView::doubleClicked, this, [ = ]( const QModelIndex & index )
-  {
+  connect( mLayerTreeView, &QAbstractItemView::doubleClicked, this, [=]( const QModelIndex &index ) {
     if ( QgsMapLayer *layer = mLayerTreeView->indexToLayer( index ) )
     {
       QgisApp::instance()->showLayerProperties( layer, QStringLiteral( "mOptsPage_Elevation" ) );
@@ -192,8 +194,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   QAction *showLayerTree = new QAction( tr( "Show Layer Tree" ), this );
   showLayerTree->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mIconLayerTree.svg" ) ) );
   showLayerTree->setCheckable( true );
-  connect( showLayerTree, &QAction::toggled, this, [ = ]( bool checked )
-  {
+  connect( showLayerTree, &QAction::toggled, this, [=]( bool checked ) {
     settingShowLayerTree->setValue( checked );
     mLayerTreeView->setVisible( checked );
   } );
@@ -205,8 +206,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   mCaptureCurveAction = new QAction( tr( "Capture Curve" ), this );
   mCaptureCurveAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mActionCaptureLine.svg" ) ) );
   mCaptureCurveAction->setCheckable( true );
-  connect( mCaptureCurveAction, &QAction::triggered, this, [ = ]
-  {
+  connect( mCaptureCurveAction, &QAction::triggered, this, [=] {
     if ( mCaptureCurveMapTool && mMainCanvas )
     {
       mMainCanvas->setMapTool( mCaptureCurveMapTool.get() );
@@ -217,8 +217,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   mCaptureCurveFromFeatureAction = new QAction( tr( "Capture Curve From Feature" ), this );
   mCaptureCurveFromFeatureAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mActionCaptureCurveFromFeature.svg" ) ) );
   mCaptureCurveFromFeatureAction->setCheckable( true );
-  connect( mCaptureCurveFromFeatureAction, &QAction::triggered, this, [ = ]
-  {
+  connect( mCaptureCurveFromFeatureAction, &QAction::triggered, this, [=] {
     if ( mCaptureCurveFromFeatureMapTool && mMainCanvas )
     {
       mMainCanvas->setMapTool( mCaptureCurveFromFeatureMapTool.get() );
@@ -238,8 +237,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   mNudgeRightAction->setEnabled( false );
   toolBar->addAction( mNudgeRightAction );
 
-  auto createShortcuts = [ = ]( const QString & objectName, void ( QgsElevationProfileWidget::* slot )() )
-  {
+  auto createShortcuts = [=]( const QString &objectName, void ( QgsElevationProfileWidget::*slot )() ) {
     if ( QShortcut *sc = QgsGui::shortcutsManager()->shortcutByName( objectName ) )
       connect( sc, &QShortcut::activated, this, slot );
   };
@@ -258,7 +256,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   identifyToolAction->setCheckable( true );
   identifyToolAction->setChecked( true );
   mIdentifyTool->setAction( identifyToolAction );
-  connect( identifyToolAction, &QAction::triggered, mPanTool, [ = ] { mCanvas->setTool( mIdentifyTool ); } );
+  connect( identifyToolAction, &QAction::triggered, mPanTool, [=] { mCanvas->setTool( mIdentifyTool ); } );
   toolBar->addAction( identifyToolAction );
 
   QAction *panToolAction = new QAction( tr( "Pan" ), this );
@@ -266,21 +264,21 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   panToolAction->setCheckable( true );
   panToolAction->setChecked( false );
   mPanTool->setAction( panToolAction );
-  connect( panToolAction, &QAction::triggered, mPanTool, [ = ] { mCanvas->setTool( mPanTool ); } );
+  connect( panToolAction, &QAction::triggered, mPanTool, [=] { mCanvas->setTool( mPanTool ); } );
   toolBar->addAction( panToolAction );
 
   QAction *zoomXAxisToolAction = new QAction( tr( "Zoom X Axis" ), this );
   zoomXAxisToolAction->setCheckable( true );
   zoomXAxisToolAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "/mActionZoomInXAxis.svg" ) ) );
   mXAxisZoomTool->setAction( zoomXAxisToolAction );
-  connect( zoomXAxisToolAction, &QAction::triggered, mXAxisZoomTool, [ = ] { mCanvas->setTool( mXAxisZoomTool ); } );
+  connect( zoomXAxisToolAction, &QAction::triggered, mXAxisZoomTool, [=] { mCanvas->setTool( mXAxisZoomTool ); } );
   toolBar->addAction( zoomXAxisToolAction );
 
   QAction *zoomToolAction = new QAction( tr( "Zoom" ), this );
   zoomToolAction->setCheckable( true );
   zoomToolAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "/mActionZoomIn.svg" ) ) );
   mZoomTool->setAction( zoomToolAction );
-  connect( zoomToolAction, &QAction::triggered, mZoomTool, [ = ] { mCanvas->setTool( mZoomTool ); } );
+  connect( zoomToolAction, &QAction::triggered, mZoomTool, [=] { mCanvas->setTool( mZoomTool ); } );
   toolBar->addAction( zoomToolAction );
 
   QAction *resetViewAction = new QAction( tr( "Zoom Full" ), this );
@@ -295,14 +293,13 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   connect( enabledSnappingAction, &QAction::toggled, mCanvas, &QgsElevationProfileCanvas::setSnappingEnabled );
   toolBar->addAction( enabledSnappingAction );
 
-  mMeasureTool = std::make_unique< QgsElevationProfileToolMeasure> ( mCanvas );
+  mMeasureTool = std::make_unique<QgsElevationProfileToolMeasure>( mCanvas );
 
   QAction *measureToolAction = new QAction( tr( "Measure Distances" ), this );
   measureToolAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "/mActionMeasure.svg" ) ) );
   measureToolAction->setCheckable( true );
   mMeasureTool->setAction( measureToolAction );
-  connect( measureToolAction, &QAction::triggered, this, [ = ]
-  {
+  connect( measureToolAction, &QAction::triggered, this, [=] {
     mCanvas->setTool( mMeasureTool.get() );
   } );
   toolBar->addAction( measureToolAction );
@@ -349,7 +346,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
 
   mLockRatioAction = new QAction( tr( "Lock Distance/Elevation Scales" ), this );
   mLockRatioAction->setCheckable( true );
-  mLockRatioAction->setChecked( settingLockAxis->value( ) );
+  mLockRatioAction->setChecked( settingLockAxis->value() );
   connect( mLockRatioAction, &QAction::toggled, this, &QgsElevationProfileWidget::axisScaleLockToggled );
   mOptionsMenu->addAction( mLockRatioAction );
 
@@ -382,8 +379,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
     action->setData( QVariant::fromValue( unit ) );
     action->setCheckable( true );
     action->setActionGroup( unitGroup );
-    connect( action, &QAction::toggled, this, [ = ]( bool active )
-    {
+    connect( action, &QAction::toggled, this, [=]( bool active ) {
       if ( active )
       {
         mCanvas->setDistanceUnit( unit );
@@ -391,11 +387,10 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
     } );
     mDistanceUnitMenu->addAction( action );
   }
-  connect( mDistanceUnitMenu, &QMenu::aboutToShow, this, [ = ]
-  {
+  connect( mDistanceUnitMenu, &QMenu::aboutToShow, this, [=] {
     for ( QAction *action : mDistanceUnitMenu->actions() )
     {
-      if ( action->data().value< Qgis::DistanceUnit >() == mCanvas->distanceUnit() && !action->isChecked() )
+      if ( action->data().value<Qgis::DistanceUnit>() == mCanvas->distanceUnit() && !action->isChecked() )
         action->setChecked( true );
     }
   } );
@@ -406,8 +401,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   mSettingsAction = new QgsElevationProfileWidgetSettingsAction( mOptionsMenu );
 
   mSettingsAction->toleranceSpinBox()->setValue( settingTolerance->value() );
-  connect( mSettingsAction->toleranceSpinBox(), qOverload< double >( &QDoubleSpinBox::valueChanged ), this, [ = ]( double value )
-  {
+  connect( mSettingsAction->toleranceSpinBox(), qOverload<double>( &QDoubleSpinBox::valueChanged ), this, [=]( double value ) {
     settingTolerance->setValue( value );
     createOrUpdateRubberBands();
     scheduleUpdate();
@@ -415,6 +409,12 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
 
   mOptionsMenu->addAction( mSettingsAction );
 
+  mOptionsMenu->addSeparator();
+
+  mRenameProfileAction = new QAction( tr( "Rename Profile…" ), this );
+  connect( mRenameProfileAction, &QAction::triggered, this, &QgsElevationProfileWidget::renameProfileTriggered );
+  mOptionsMenu->addAction( mRenameProfileAction );
+
   mBtnOptions = new QToolButton();
   mBtnOptions->setAutoRaise( true );
   mBtnOptions->setToolTip( tr( "Options" ) );
@@ -442,7 +442,7 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   layout->addLayout( topLayout );
 
   QSplitter *splitter = new QSplitter( Qt::Horizontal );
-  splitter->addWidget( mLayerTreeView ) ;
+  splitter->addWidget( mLayerTreeView );
   splitter->addWidget( mCanvas );
   layout->addWidget( splitter );
   splitter->setCollapsible( 0, false );
@@ -451,19 +451,17 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   QgsSettings settings;
   splitter->restoreState( settings.value( QStringLiteral( "Windows/ElevationProfile/SplitState" ) ).toByteArray() );
 
-  connect( splitter, &QSplitter::splitterMoved, this, [splitter]
-  {
+  connect( splitter, &QSplitter::splitterMoved, this, [splitter] {
     QgsSettings settings;
     settings.setValue( QStringLiteral( "Windows/ElevationProfile/SplitState" ), splitter->saveState() );
   } );
   setLayout( layout );
 
-  mDockableWidgetHelper = new QgsDockableWidgetHelper( true, mCanvasName, this, QgisApp::instance(), Qt::BottomDockWidgetArea,  QStringList(), true );
+  mDockableWidgetHelper = new QgsDockableWidgetHelper( true, mCanvasName, this, QgisApp::instance(), Qt::BottomDockWidgetArea, QStringList(), true );
   QToolButton *toggleButton = mDockableWidgetHelper->createDockUndockToolButton();
   toggleButton->setToolTip( tr( "Dock Elevation Profile View" ) );
   toolBar->addWidget( toggleButton );
-  connect( mDockableWidgetHelper, &QgsDockableWidgetHelper::closed, this, [ = ]()
-  {
+  connect( mDockableWidgetHelper, &QgsDockableWidgetHelper::closed, this, [=]() {
     close();
   } );
 
@@ -476,6 +474,9 @@ QgsElevationProfileWidget::QgsElevationProfileWidget( const QString &name )
   // initially populate layer tree with project layers
   mLayerTreeView->populateInitialLayers( QgsProject::instance() );
 
+  connect( QgsProject::instance()->elevationProperties(), &QgsProjectElevationProperties::changed, this, &QgsElevationProfileWidget::onProjectElevationPropertiesChanged );
+  connect( QgsProject::instance(), &QgsProject::crs3DChanged, this, &QgsElevationProfileWidget::onProjectElevationPropertiesChanged );
+
   updateCanvasLayers();
 }
 
@@ -502,11 +503,10 @@ void QgsElevationProfileWidget::setMainCanvas( QgsMapCanvas *canvas )
 {
   mMainCanvas = canvas;
 
-  mCaptureCurveMapTool = std::make_unique< QgsMapToolProfileCurve >( canvas, QgisApp::instance()->cadDockWidget() );
+  mCaptureCurveMapTool = std::make_unique<QgsMapToolProfileCurve>( canvas, QgisApp::instance()->cadDockWidget() );
   mCaptureCurveMapTool->setAction( mCaptureCurveAction );
-  connect( mCaptureCurveMapTool.get(), &QgsMapToolProfileCurve::curveCaptured, this, [ = ]( const QgsGeometry & curve ) {  setProfileCurve( curve, true ); } );
-  connect( mCaptureCurveMapTool.get(), &QgsMapToolProfileCurve::captureStarted, this, [ = ]
-  {
+  connect( mCaptureCurveMapTool.get(), &QgsMapToolProfileCurve::curveCaptured, this, [=]( const QgsGeometry &curve ) { setProfileCurve( curve, true ); } );
+  connect( mCaptureCurveMapTool.get(), &QgsMapToolProfileCurve::captureStarted, this, [=] {
     // if capturing a new curve, we just hide the existing rubber band -- if the user cancels the new curve digitizing then we'll
     // re-show the old curve rubber band
     if ( mRubberBand )
@@ -516,8 +516,7 @@ void QgsElevationProfileWidget::setMainCanvas( QgsMapCanvas *canvas )
     if ( mMapPointRubberBand )
       mMapPointRubberBand->hide();
   } );
-  connect( mCaptureCurveMapTool.get(), &QgsMapToolProfileCurve::captureCanceled, this, [ = ]
-  {
+  connect( mCaptureCurveMapTool.get(), &QgsMapToolProfileCurve::captureCanceled, this, [=] {
     if ( mRubberBand )
       mRubberBand->show();
     if ( mToleranceRubberBand )
@@ -526,9 +525,9 @@ void QgsElevationProfileWidget::setMainCanvas( QgsMapCanvas *canvas )
       mMapPointRubberBand->show();
   } );
 
-  mCaptureCurveFromFeatureMapTool = std::make_unique< QgsMapToolProfileCurveFromFeature >( canvas );
+  mCaptureCurveFromFeatureMapTool = std::make_unique<QgsMapToolProfileCurveFromFeature>( canvas );
   mCaptureCurveFromFeatureMapTool->setAction( mCaptureCurveFromFeatureAction );
-  connect( mCaptureCurveFromFeatureMapTool.get(), &QgsMapToolProfileCurveFromFeature::curveCaptured, this, [ = ]( const QgsGeometry & curve ) { setProfileCurve( curve, true ); } );
+  connect( mCaptureCurveFromFeatureMapTool.get(), &QgsMapToolProfileCurveFromFeature::curveCaptured, this, [=]( const QgsGeometry &curve ) { setProfileCurve( curve, true ); } );
 
   mMapPointRubberBand.reset( new QgsRubberBand( canvas, Qgis::GeometryType::Point ) );
   mMapPointRubberBand->setZValue( 1000 );
@@ -540,8 +539,7 @@ void QgsElevationProfileWidget::setMainCanvas( QgsMapCanvas *canvas )
   mMapPointRubberBand->hide();
 
   mCanvas->setDistanceUnit( mMainCanvas->mapSettings().destinationCrs().mapUnits() );
-  connect( mMainCanvas, &QgsMapCanvas::destinationCrsChanged, this, [ = ]
-  {
+  connect( mMainCanvas, &QgsMapCanvas::destinationCrsChanged, this, [=] {
     mCanvas->setDistanceUnit( mMainCanvas->mapSettings().destinationCrs().mapUnits() );
   } );
 }
@@ -558,7 +556,7 @@ void QgsElevationProfileWidget::addLayers()
 
   // The add layers dialog should only show layers which CAN have elevation, yet currently don't
   // have it enabled. So collect layers which don't match this criteria now for filtering out.
-  QList< QgsMapLayer * > layersWhichAlreadyHaveElevationOrCannotHaveElevation;
+  QList<QgsMapLayer *> layersWhichAlreadyHaveElevationOrCannotHaveElevation;
   for ( auto it = allMapLayers.constBegin(); it != allMapLayers.constEnd(); ++it )
   {
     if ( !QgsElevationUtils::canEnableElevationForLayer( it.value() ) || it.value()->elevationProperties()->hasElevation() )
@@ -579,7 +577,7 @@ void QgsElevationProfileWidget::addLayers()
 
 void QgsElevationProfileWidget::addLayersInternal( const QList<QgsMapLayer *> &layers )
 {
-  QList< QgsMapLayer * > updatedLayers;
+  QList<QgsMapLayer *> updatedLayers;
   if ( !layers.empty() )
   {
     for ( QgsMapLayer *layer : layers )
@@ -605,7 +603,7 @@ void QgsElevationProfileWidget::addLayersInternal( const QList<QgsMapLayer *> &l
 void QgsElevationProfileWidget::updateCanvasLayers()
 {
   QList<QgsMapLayer *> layers;
-  const QList< QgsMapLayer * > layerOrder = mLayerTree->layerOrder();
+  const QList<QgsMapLayer *> layerOrder = mLayerTree->layerOrder();
   layers.reserve( layerOrder.size() );
   for ( QgsMapLayer *layer : layerOrder )
   {
@@ -635,11 +633,9 @@ void QgsElevationProfileWidget::onTotalPendingJobsCountChanged( int count )
       mJobProgressBarTimer.setSingleShot( true );
       mJobProgressBarTimer.setInterval( 500 );
       disconnect( mJobProgressBarTimerConnection );
-      mJobProgressBarTimerConnection = connect( &mJobProgressBarTimer, &QTimer::timeout, this, [ = ]()
-      {
+      mJobProgressBarTimerConnection = connect( &mJobProgressBarTimer, &QTimer::timeout, this, [=]() {
         mProgressPendingJobs->setVisible( true );
-      }
-                                              );
+      } );
       mJobProgressBarTimer.start();
     }
     else
@@ -687,16 +683,16 @@ void QgsElevationProfileWidget::onCanvasPointHovered( const QgsPointXY &, const
 void QgsElevationProfileWidget::updatePlot()
 {
   mCanvas->setTolerance( mSettingsAction->toleranceSpinBox()->value() );
-  mCanvas->setCrs( mMainCanvas->mapSettings().destinationCrs() );
+  mCanvas->setCrs( QgsProject::instance()->crs3D() );
 
   if ( !mProfileCurve.isEmpty() )
   {
-    if ( const QgsCurve *curve = qgsgeometry_cast< const QgsCurve *>( mProfileCurve.constGet()->simplifiedTypeRef() ) )
+    if ( const QgsCurve *curve = qgsgeometry_cast<const QgsCurve *>( mProfileCurve.constGet()->simplifiedTypeRef() ) )
     {
       mCanvas->setProfileCurve( curve->clone() );
       mCanvas->refresh();
     }
-    else if ( const QgsMultiCurve *multiCurve = qgsgeometry_cast< const QgsMultiCurve *>( mProfileCurve.constGet()->simplifiedTypeRef() ) )
+    else if ( const QgsMultiCurve *multiCurve = qgsgeometry_cast<const QgsMultiCurve *>( mProfileCurve.constGet()->simplifiedTypeRef() ) )
     {
       // hm, just grab the first part!
       mCanvas->setProfileCurve( multiCurve->curveN( 0 )->clone() );
@@ -737,10 +733,11 @@ void QgsElevationProfileWidget::exportAsPdf()
   this->raise();
 #endif
   outputFileName = QFileDialog::getSaveFileName(
-                     this,
-                     tr( "Export to PDF" ),
-                     outputFileName,
-                     tr( "PDF Format" ) + " (*.pdf *.PDF)" );
+    this,
+    tr( "Export to PDF" ),
+    outputFileName,
+    tr( "PDF Format" ) + " (*.pdf *.PDF)"
+  );
   this->activateWindow();
   if ( outputFileName.isEmpty() )
   {
@@ -755,24 +752,17 @@ void QgsElevationProfileWidget::exportAsPdf()
   if ( !dialog.exec() )
     return;
 
-  QPrinter printer;
-  printer.setOutputFileName( outputFileName );
-  printer.setOutputFormat( QPrinter::PdfFormat );
+  QPdfWriter pdfWriter( outputFileName );
 
   const QgsLayoutSize pageSizeMM = dialog.pageSizeMM();
-  QPageLayout pageLayout( QPageSize( pageSizeMM.toQSizeF(), QPageSize::Millimeter ),
-                          QPageLayout::Portrait,
-                          QMarginsF( 0, 0, 0, 0 ) );
+  QPageLayout pageLayout( QPageSize( pageSizeMM.toQSizeF(), QPageSize::Millimeter ), QPageLayout::Portrait, QMarginsF( 0, 0, 0, 0 ) );
   pageLayout.setMode( QPageLayout::FullPageMode );
-  printer.setPageLayout( pageLayout );
-  printer.setFullPage( true );
-  printer.setPageMargins( QMarginsF( 0, 0, 0, 0 ) );
-  printer.setFullPage( true );
-  printer.setColorMode( QPrinter::Color );
-  printer.setResolution( 1200 );
+  pdfWriter.setPageLayout( pageLayout );
+  pdfWriter.setPageMargins( QMarginsF( 0, 0, 0, 0 ) );
+  pdfWriter.setResolution( 1200 );
 
   QPainter p;
-  if ( !p.begin( &printer ) )
+  if ( !p.begin( &pdfWriter ) )
   {
     //error beginning print
     QgisApp::instance()->messageBar()->pushWarning( tr( "Save as PDF" ), tr( "Could not create %1" ).arg( QDir::toNativeSeparators( outputFileName ) ) );
@@ -790,8 +780,7 @@ void QgsElevationProfileWidget::exportAsPdf()
   Qgs2DPlot plotSettings;
   dialog.updatePlotSettings( plotSettings );
 
-  mCanvas->render( rc, rc.convertToPainterUnits( pageSizeMM.width(), Qgis::RenderUnit::Millimeters ),
-                   rc.convertToPainterUnits( pageSizeMM.height(), Qgis::RenderUnit::Millimeters ), plotSettings );
+  mCanvas->render( rc, rc.convertToPainterUnits( pageSizeMM.width(), Qgis::RenderUnit::Millimeters ), rc.convertToPainterUnits( pageSizeMM.height(), Qgis::RenderUnit::Millimeters ), plotSettings );
   p.end();
 
   QgisApp::instance()->messageBar()->pushSuccess( tr( "Save as PDF" ), tr( "Successfully saved the profile to <a href=\"%1\">%2</a>" ).arg( QUrl::fromLocalFile( outputFileName ).toString(), QDir::toNativeSeparators( outputFileName ) ) );
@@ -847,19 +836,18 @@ void QgsElevationProfileWidget::exportAsImage()
   image.save( fileWithExtension.first );
 
   QgisApp::instance()->messageBar()->pushSuccess( tr( "Save as Image" ), tr( "Successfully saved the profile to <a href=\"%1\">%2</a>" ).arg( QUrl::fromLocalFile( fileWithExtension.first ).toString(), QDir::toNativeSeparators( fileWithExtension.first ) ) );
-
 }
 
 void QgsElevationProfileWidget::exportResults( Qgis::ProfileExportType type )
 {
-  std::unique_ptr< QgsCurve > profileCurve;
+  std::unique_ptr<QgsCurve> profileCurve;
   if ( !mProfileCurve.isEmpty() )
   {
-    if ( const QgsCurve *curve = qgsgeometry_cast< const QgsCurve *>( mProfileCurve.constGet()->simplifiedTypeRef() ) )
+    if ( const QgsCurve *curve = qgsgeometry_cast<const QgsCurve *>( mProfileCurve.constGet()->simplifiedTypeRef() ) )
     {
       profileCurve.reset( curve->clone() );
     }
-    else if ( const QgsMultiCurve *multiCurve = qgsgeometry_cast< const QgsMultiCurve *>( mProfileCurve.constGet()->simplifiedTypeRef() ) )
+    else if ( const QgsMultiCurve *multiCurve = qgsgeometry_cast<const QgsMultiCurve *>( mProfileCurve.constGet()->simplifiedTypeRef() ) )
     {
       // hm, just grab the first part!
       profileCurve.reset( multiCurve->curveN( 0 )->clone() );
@@ -881,7 +869,7 @@ void QgsElevationProfileWidget::exportResults( Qgis::ProfileExportType type )
   file = QgsFileUtils::ensureFileNameHasExtension( file, QgsFileUtils::extensionsFromFilter( selectedFilter ) );
 
   QgsProfileRequest request( profileCurve.release() );
-  request.setCrs( mMainCanvas->mapSettings().destinationCrs() );
+  request.setCrs( QgsProject::instance()->crs3D() );
   request.setTolerance( mSettingsAction->toleranceSpinBox()->value() );
   request.setTransformContext( QgsProject::instance()->transformContext() );
   request.setTerrainProvider( QgsProject::instance()->elevationProperties()->terrainProvider() ? QgsProject::instance()->elevationProperties()->terrainProvider()->clone() : nullptr );
@@ -890,18 +878,20 @@ void QgsElevationProfileWidget::exportResults( Qgis::ProfileExportType type )
   context.appendScope( QgsExpressionContextUtils::projectScope( QgsProject::instance() ) );
   request.setExpressionContext( context );
 
-  const QList< QgsMapLayer * > layersToGenerate = mCanvas->layers();
-  QList< QgsAbstractProfileSource * > sources;
-  sources.reserve( layersToGenerate .size() );
+  const QList<QgsMapLayer *> layersToGenerate = mCanvas->layers();
+  QList<QgsAbstractProfileSource *> sources;
+  const QList<QgsAbstractProfileSource *> registrySources = QgsApplication::profileSourceRegistry()->profileSources();
+  sources.reserve( layersToGenerate.size() + registrySources.size() );
+
+  sources << registrySources;
   for ( QgsMapLayer *layer : layersToGenerate )
   {
-    if ( QgsAbstractProfileSource *source = dynamic_cast< QgsAbstractProfileSource * >( layer ) )
+    if ( QgsAbstractProfileSource *source = dynamic_cast<QgsAbstractProfileSource *>( layer ) )
       sources.append( source );
   }
 
   QgsProfileExporterTask *exportTask = new QgsProfileExporterTask( sources, request, type, file, QgsProject::instance()->transformContext() );
-  connect( exportTask, &QgsTask::taskCompleted, this, [exportTask]
-  {
+  connect( exportTask, &QgsTask::taskCompleted, this, [exportTask] {
     switch ( exportTask->result() )
     {
       case QgsProfileExporterTask::ExportResult::Success:
@@ -959,7 +949,19 @@ void QgsElevationProfileWidget::axisScaleLockToggled( bool active )
   mCanvas->setLockAxisScales( active );
 }
 
-void QgsElevationProfileWidget::createOrUpdateRubberBands( )
+void QgsElevationProfileWidget::renameProfileTriggered()
+{
+  QgsNewNameDialog dlg( tr( "elevation profile" ), canvasName(), {}, {}, Qt::CaseSensitive, this );
+  dlg.setWindowTitle( tr( "Rename Elevation Profile" ) );
+  dlg.setHintString( tr( "Enter a new elevation profile title" ) );
+  dlg.setAllowEmptyName( false );
+  if ( dlg.exec() == QDialog::Accepted )
+  {
+    setCanvasName( dlg.name() );
+  }
+}
+
+void QgsElevationProfileWidget::createOrUpdateRubberBands()
 {
   if ( !mRubberBand )
   {
@@ -969,18 +971,18 @@ void QgsElevationProfileWidget::createOrUpdateRubberBands( )
 
     QgsSymbolLayerList layers;
 
-    std::unique_ptr< QgsSimpleLineSymbolLayer > bottomLayer = std::make_unique< QgsSimpleLineSymbolLayer >();
+    std::unique_ptr<QgsSimpleLineSymbolLayer> bottomLayer = std::make_unique<QgsSimpleLineSymbolLayer>();
     bottomLayer->setWidth( 0.8 );
     bottomLayer->setWidthUnit( Qgis::RenderUnit::Millimeters );
     bottomLayer->setColor( QColor( 40, 40, 40, 100 ) );
     bottomLayer->setPenCapStyle( Qt::PenCapStyle::FlatCap );
     layers.append( bottomLayer.release() );
 
-    std::unique_ptr< QgsMarkerLineSymbolLayer > arrowLayer = std::make_unique< QgsMarkerLineSymbolLayer >();
+    std::unique_ptr<QgsMarkerLineSymbolLayer> arrowLayer = std::make_unique<QgsMarkerLineSymbolLayer>();
     arrowLayer->setPlacements( Qgis::MarkerLinePlacement::CentralPoint );
 
     QgsSymbolLayerList markerLayers;
-    std::unique_ptr< QgsSimpleMarkerSymbolLayer > arrowSymbolLayer = std::make_unique< QgsSimpleMarkerSymbolLayer >( Qgis::MarkerShape::EquilateralTriangle );
+    std::unique_ptr<QgsSimpleMarkerSymbolLayer> arrowSymbolLayer = std::make_unique<QgsSimpleMarkerSymbolLayer>( Qgis::MarkerShape::EquilateralTriangle );
     arrowSymbolLayer->setSize( 4 );
     arrowSymbolLayer->setAngle( 90 );
     arrowSymbolLayer->setSizeUnit( Qgis::RenderUnit::Millimeters );
@@ -989,12 +991,12 @@ void QgsElevationProfileWidget::createOrUpdateRubberBands( )
     arrowSymbolLayer->setStrokeWidth( 0.2 );
     markerLayers.append( arrowSymbolLayer.release() );
 
-    std::unique_ptr< QgsMarkerSymbol > markerSymbol = std::make_unique< QgsMarkerSymbol >( markerLayers );
+    std::unique_ptr<QgsMarkerSymbol> markerSymbol = std::make_unique<QgsMarkerSymbol>( markerLayers );
     arrowLayer->setSubSymbol( markerSymbol.release() );
 
     layers.append( arrowLayer.release() );
 
-    std::unique_ptr< QgsSimpleLineSymbolLayer > topLayer = std::make_unique< QgsSimpleLineSymbolLayer >();
+    std::unique_ptr<QgsSimpleLineSymbolLayer> topLayer = std::make_unique<QgsSimpleLineSymbolLayer>();
     topLayer->setWidth( 0.4 );
     topLayer->setWidthUnit( Qgis::RenderUnit::Millimeters );
     topLayer->setColor( QColor( 255, 255, 255, 255 ) );
@@ -1002,7 +1004,7 @@ void QgsElevationProfileWidget::createOrUpdateRubberBands( )
     topLayer->setPenCapStyle( Qt::PenCapStyle::FlatCap );
     layers.append( topLayer.release() );
 
-    std::unique_ptr< QgsLineSymbol > symbol = std::make_unique< QgsLineSymbol >( layers );
+    std::unique_ptr<QgsLineSymbol> symbol = std::make_unique<QgsLineSymbol>( layers );
 
     mRubberBand->setSymbol( symbol.release() );
     mRubberBand->updatePosition();
@@ -1021,12 +1023,12 @@ void QgsElevationProfileWidget::createOrUpdateRubberBands( )
 
       QgsSymbolLayerList layers;
 
-      std::unique_ptr< QgsSimpleFillSymbolLayer > bottomLayer = std::make_unique< QgsSimpleFillSymbolLayer >();
+      std::unique_ptr<QgsSimpleFillSymbolLayer> bottomLayer = std::make_unique<QgsSimpleFillSymbolLayer>();
       bottomLayer->setColor( QColor( 40, 40, 40, 50 ) );
       bottomLayer->setStrokeColor( QColor( 255, 255, 255, 150 ) );
       layers.append( bottomLayer.release() );
 
-      std::unique_ptr< QgsFillSymbol > symbol = std::make_unique< QgsFillSymbol >( layers );
+      std::unique_ptr<QgsFillSymbol> symbol = std::make_unique<QgsFillSymbol>( layers );
       mToleranceRubberBand->setSymbol( symbol.release() );
     }
 
@@ -1041,6 +1043,32 @@ void QgsElevationProfileWidget::createOrUpdateRubberBands( )
   }
 }
 
+void QgsElevationProfileWidget::onProjectElevationPropertiesChanged()
+{
+  // Only the vector layers whose clamping depend on the terrain need to be updated
+  // if the project elevation properties have changed.
+  // Therefore, update the plot if this criteria is met.
+  for ( QgsMapLayer *layer : mCanvas->layers() )
+  {
+    if ( layer->type() == Qgis::LayerType::Vector )
+    {
+      QgsVectorLayerElevationProperties *elevationProperties = qgis::down_cast<QgsVectorLayerElevationProperties *>( layer->elevationProperties() );
+      switch ( elevationProperties->clamping() )
+      {
+        case Qgis::AltitudeClamping::Relative:
+        case Qgis::AltitudeClamping::Terrain:
+        {
+          scheduleUpdate();
+          break;
+        }
+
+        case Qgis::AltitudeClamping::Absolute:
+          break;
+      }
+    }
+  }
+}
+
 QgsElevationProfileWidgetSettingsAction::QgsElevationProfileWidgetSettingsAction( QWidget *parent )
   : QWidgetAction( parent )
 {
@@ -1068,7 +1096,6 @@ QgsElevationProfileWidgetSettingsAction::QgsElevationProfileWidgetSettingsAction
 QgsAppElevationProfileLayerTreeView::QgsAppElevationProfileLayerTreeView( QgsLayerTree *rootNode, QWidget *parent )
   : QgsElevationProfileLayerTreeView( rootNode, parent )
 {
-
 }
 
 void QgsAppElevationProfileLayerTreeView::contextMenuEvent( QContextMenuEvent *event )
@@ -1082,8 +1109,7 @@ void QgsAppElevationProfileLayerTreeView::contextMenuEvent( QContextMenuEvent *e
     QMenu *menu = new QMenu();
 
     QAction *propertiesAction = new QAction( tr( "Properties…" ), menu );
-    connect( propertiesAction, &QAction::triggered, this, [layer]
-    {
+    connect( propertiesAction, &QAction::triggered, this, [layer] {
       QgisApp::instance()->showLayerProperties( layer, QStringLiteral( "mOptsPage_Elevation" ) );
     } );
     menu->addAction( propertiesAction );
