@@ -41,7 +41,7 @@ class CORE_EXPORT QgsClassificationEqualInterval : public QgsClassificationMetho
 
   private:
     QList<double> calculateBreaks( double &minimum, double &maximum,
-                                   const QList<double> &values, int nclasses ) override;
+                                   const QList<double> &values, int nclasses, QString &error ) override;
 
 };
 
