@@ -17,13 +17,13 @@
 
 #include "qgscircularstring.h"
 #include "qgsapplication.h"
+#include "qgsbox3d.h"
 #include "qgscoordinatetransform.h"
 #include "qgsgeometryutils.h"
 #include "qgslinestring.h"
-#include "qgsmaptopixel.h"
 #include "qgspoint.h"
+#include "qgsrectangle.h"
 #include "qgswkbptr.h"
-#include "qgslogger.h"
 #include "qgsgeometrytransformer.h"
 #include "qgsfeedback.h"
 
@@ -35,7 +35,7 @@
 
 QgsCircularString::QgsCircularString()
 {
-  mWkbType = QgsWkbTypes::CircularString;
+  mWkbType = Qgis::WkbType::CircularString;
 }
 
 QgsCircularString::QgsCircularString( const QgsPoint &p1, const QgsPoint &p2, const QgsPoint &p3 )
@@ -43,7 +43,7 @@ QgsCircularString::QgsCircularString( const QgsPoint &p1, const QgsPoint &p2, co
   //get wkb type from first point
   bool hasZ = p1.is3D();
   bool hasM = p1.isMeasure();
-  mWkbType = QgsWkbTypes::CircularString;
+  mWkbType = Qgis::WkbType::CircularString;
 
   mX.resize( 3 );
   mX[ 0 ] = p1.x();
@@ -73,7 +73,7 @@ QgsCircularString::QgsCircularString( const QgsPoint &p1, const QgsPoint &p2, co
 
 QgsCircularString::QgsCircularString( const QVector<double> &x, const QVector<double> &y, const QVector<double> &z, const QVector<double> &m )
 {
-  mWkbType = QgsWkbTypes::CircularString;
+  mWkbType = Qgis::WkbType::CircularString;
   int pointCount = std::min( x.size(), y.size() );
   if ( x.size() == pointCount )
   {
@@ -93,7 +93,7 @@ QgsCircularString::QgsCircularString( const QVector<double> &x, const QVector<do
   }
   if ( !z.isEmpty() && z.count() >= pointCount )
   {
-    mWkbType = QgsWkbTypes::CircularStringZ;
+    mWkbType = Qgis::WkbType::CircularStringZ;
     if ( z.size() == pointCount )
     {
       mZ = z;
@@ -123,34 +123,6 @@ QgsCircularString QgsCircularString::fromTwoPointsAndCenter( const QgsPoint &p1,
   return QgsCircularString( p1, midPoint, p2 );
 }
 
-bool QgsCircularString::equals( const QgsCurve &other ) const
-{
-  const QgsCircularString *otherLine = dynamic_cast< const QgsCircularString * >( &other );
-  if ( !otherLine )
-    return false;
-
-  if ( mWkbType != otherLine->mWkbType )
-    return false;
-
-  if ( mX.count() != otherLine->mX.count() )
-    return false;
-
-  for ( int i = 0; i < mX.count(); ++i )
-  {
-    if ( !qgsDoubleNear( mX.at( i ), otherLine->mX.at( i ) )
-         || !qgsDoubleNear( mY.at( i ), otherLine->mY.at( i ) ) )
-      return false;
-
-    if ( is3D() && !qgsDoubleNear( mZ.at( i ), otherLine->mZ.at( i ) ) )
-      return false;
-
-    if ( isMeasure() && !qgsDoubleNear( mM.at( i ), otherLine->mM.at( i ) ) )
-      return false;
-  }
-
-  return true;
-}
-
 QgsCircularString *QgsCircularString::createEmptyWithSameType() const
 {
   auto result = std::make_unique< QgsCircularString >();
@@ -261,7 +233,7 @@ QgsCircularString *QgsCircularString::clone() const
 
 void QgsCircularString::clear()
 {
-  mWkbType = QgsWkbTypes::CircularString;
+  mWkbType = Qgis::WkbType::CircularString;
   mX.clear();
   mY.clear();
   mZ.clear();
@@ -269,30 +241,46 @@ void QgsCircularString::clear()
   clearCache();
 }
 
-QgsRectangle QgsCircularString::calculateBoundingBox() const
+QgsBox3D QgsCircularString::calculateBoundingBox3D() const
 {
-  QgsRectangle bbox;
+  QgsBox3D bbox;
   int nPoints = numPoints();
   for ( int i = 0; i < ( nPoints - 2 ) ; i += 2 )
   {
+    QgsRectangle box2d = segmentBoundingBox( QgsPoint( mX[i], mY[i] ), QgsPoint( mX[i + 1], mY[i + 1] ), QgsPoint( mX[i + 2], mY[i + 2] ) );
+    double zMin = std::numeric_limits<double>::quiet_NaN();
+    double zMax = std::numeric_limits<double>::quiet_NaN();
+    if ( is3D() )
+    {
+      zMin = *std::min_element( mZ.begin() + i, mZ.begin() + i + 3 );
+      zMax = *std::max_element( mZ.begin() + i, mZ.begin() + i + 3 );
+    }
     if ( i == 0 )
     {
-      bbox = segmentBoundingBox( QgsPoint( mX[i], mY[i] ), QgsPoint( mX[i + 1], mY[i + 1] ), QgsPoint( mX[i + 2], mY[i + 2] ) );
+      bbox = QgsBox3D( box2d, zMin, zMax );
     }
     else
     {
-      QgsRectangle segmentBox = segmentBoundingBox( QgsPoint( mX[i], mY[i] ), QgsPoint( mX[i + 1], mY[i + 1] ), QgsPoint( mX[i + 2], mY[i + 2] ) );
-      bbox.combineExtentWith( segmentBox );
+      bbox.combineWith( QgsBox3D( box2d, zMin, zMax ) );
     }
   }
 
   if ( nPoints > 0 && nPoints % 2 == 0 )
   {
+    double z = std::numeric_limits<double>::quiet_NaN();
     if ( nPoints == 2 )
     {
-      bbox.combineExtentWith( mX[ 0 ], mY[ 0 ] );
+      if ( is3D() )
+      {
+        z = mZ[ 0 ];
+      }
+      bbox.combineWith( mX[ 0 ], mY[ 0 ], z );
     }
-    bbox.combineExtentWith( mX[ nPoints - 1 ], mY[ nPoints - 1 ] );
+    if ( is3D() )
+    {
+      z = mZ[ nPoints - 1 ];
+    }
+    bbox.combineWith( mX[ nPoints - 1 ], mY[ nPoints - 1 ], z );
   }
   return bbox;
 }
@@ -340,9 +328,9 @@ QgsRectangle QgsCircularString::segmentBoundingBox( const QgsPoint &pt1, const Q
   double centerX, centerY, radius;
   QgsGeometryUtils::circleCenterRadius( pt1, pt2, pt3, radius, centerX, centerY );
 
-  double p1Angle = QgsGeometryUtils::ccwAngle( pt1.y() - centerY, pt1.x() - centerX );
-  double p2Angle = QgsGeometryUtils::ccwAngle( pt2.y() - centerY, pt2.x() - centerX );
-  double p3Angle = QgsGeometryUtils::ccwAngle( pt3.y() - centerY, pt3.x() - centerX );
+  double p1Angle = QgsGeometryUtilsBase::ccwAngle( pt1.y() - centerY, pt1.x() - centerX );
+  double p2Angle = QgsGeometryUtilsBase::ccwAngle( pt2.y() - centerY, pt2.x() - centerX );
+  double p3Angle = QgsGeometryUtilsBase::ccwAngle( pt3.y() - centerY, pt3.x() - centerX );
 
   //start point, end point and compass points in between can be on bounding box
   QgsRectangle bbox( pt1.x(), pt1.y(), pt1.x(), pt1.y() );
@@ -442,8 +430,8 @@ bool QgsCircularString::fromWkb( QgsConstWkbPtr &wkbPtr )
   if ( !wkbPtr )
     return false;
 
-  QgsWkbTypes::Type type = wkbPtr.readHeader();
-  if ( QgsWkbTypes::flatType( type ) != QgsWkbTypes::CircularString )
+  Qgis::WkbType type = wkbPtr.readHeader();
+  if ( QgsWkbTypes::flatType( type ) != Qgis::WkbType::CircularString )
   {
     return false;
   }
@@ -451,14 +439,20 @@ bool QgsCircularString::fromWkb( QgsConstWkbPtr &wkbPtr )
   mWkbType = type;
 
   //type
-  bool hasZ = is3D();
-  bool hasM = isMeasure();
+  const bool hasZ = is3D();
+  const bool hasM = isMeasure();
   int nVertices = 0;
   wkbPtr >> nVertices;
   mX.resize( nVertices );
   mY.resize( nVertices );
-  hasZ ? mZ.resize( nVertices ) : mZ.clear();
-  hasM ? mM.resize( nVertices ) : mM.clear();
+  if ( hasZ )
+    mZ.resize( nVertices );
+  else
+    mZ.clear();
+  if ( hasM )
+    mM.resize( nVertices );
+  else
+    mM.clear();
   for ( int i = 0; i < nVertices; ++i )
   {
     wkbPtr >> mX[i];
@@ -480,9 +474,9 @@ bool QgsCircularString::fromWkt( const QString &wkt )
 {
   clear();
 
-  QPair<QgsWkbTypes::Type, QString> parts = QgsGeometryUtils::wktReadBlock( wkt );
+  QPair<Qgis::WkbType, QString> parts = QgsGeometryUtils::wktReadBlock( wkt );
 
-  if ( QgsWkbTypes::flatType( parts.first ) != QgsWkbTypes::CircularString )
+  if ( QgsWkbTypes::flatType( parts.first ) != Qgis::WkbType::CircularString )
     return false;
   mWkbType = parts.first;
 
@@ -592,7 +586,7 @@ double QgsCircularString::length() const
   double length = 0;
   for ( int i = 0; i < ( nPoints - 2 ) ; i += 2 )
   {
-    length += QgsGeometryUtils::circleLength( mX[i], mY[i], mX[i + 1], mY[i + 1], mX[i + 2], mY[i + 2] );
+    length += QgsGeometryUtilsBase::circleLength( mX[i], mY[i], mX[i + 1], mY[i + 1], mX[i + 2], mY[i + 2] );
   }
   return length;
 }
@@ -630,19 +624,26 @@ QgsLineString *QgsCircularString::curveToLine( double tolerance, SegmentationTol
   return line;
 }
 
-QgsCircularString *QgsCircularString::snappedToGrid( double hSpacing, double vSpacing, double dSpacing, double mSpacing ) const
+QgsCircularString *QgsCircularString::snappedToGrid( double hSpacing, double vSpacing, double dSpacing, double mSpacing, bool ) const
 {
   // prepare result
   std::unique_ptr<QgsCircularString> result { createEmptyWithSameType() };
 
+  // remove redundant not supported for circular strings
   bool res = snapToGridPrivate( hSpacing, vSpacing, dSpacing, mSpacing, mX, mY, mZ, mM,
-                                result->mX, result->mY, result->mZ, result->mM );
+                                result->mX, result->mY, result->mZ, result->mM, false );
   if ( res )
     return result.release();
   else
     return nullptr;
 }
 
+QgsAbstractGeometry *QgsCircularString::simplifyByDistance( double tolerance ) const
+{
+  std::unique_ptr< QgsLineString > line( curveToLine() );
+  return line->simplifyByDistance( tolerance );
+}
+
 bool QgsCircularString::removeDuplicateNodes( double epsilon, bool useZValues )
 {
   if ( mX.count() <= 3 )
@@ -760,18 +761,18 @@ QgsPoint QgsCircularString::pointN( int i ) const
     m = mM.at( i );
   }
 
-  QgsWkbTypes::Type t = QgsWkbTypes::Point;
+  Qgis::WkbType t = Qgis::WkbType::Point;
   if ( is3D() && isMeasure() )
   {
-    t = QgsWkbTypes::PointZM;
+    t = Qgis::WkbType::PointZM;
   }
   else if ( is3D() )
   {
-    t = QgsWkbTypes::PointZ;
+    t = Qgis::WkbType::PointZ;
   }
   else if ( isMeasure() )
   {
-    t = QgsWkbTypes::PointM;
+    t = Qgis::WkbType::PointM;
   }
   return QgsPoint( t, x, y, z, m );
 }
@@ -792,6 +793,22 @@ double QgsCircularString::yAt( int index ) const
     return 0.0;
 }
 
+double QgsCircularString::zAt( int index ) const
+{
+  if ( index >= 0 && index < mZ.size() )
+    return mZ.at( index );
+  else
+    return 0.0;
+}
+
+double QgsCircularString::mAt( int index ) const
+{
+  if ( index >= 0 && index < mM.size() )
+    return mM.at( index );
+  else
+    return 0.0;
+}
+
 bool QgsCircularString::transform( QgsAbstractGeometryTransformer *transformer, QgsFeedback *feedback )
 {
   if ( !transformer )
@@ -985,7 +1002,7 @@ void QgsCircularString::setPoints( const QgsPointSequence &points )
 
   if ( points.empty() )
   {
-    mWkbType = QgsWkbTypes::CircularString;
+    mWkbType = Qgis::WkbType::CircularString;
     mX.clear();
     mY.clear();
     mZ.clear();
@@ -998,7 +1015,7 @@ void QgsCircularString::setPoints( const QgsPointSequence &points )
   bool hasZ = firstPt.is3D();
   bool hasM = firstPt.isMeasure();
 
-  setZMTypeFromSubGeometry( &firstPt, QgsWkbTypes::CircularString );
+  setZMTypeFromSubGeometry( &firstPt, Qgis::WkbType::CircularString );
 
   mX.resize( points.size() );
   mY.resize( points.size() );
@@ -1045,7 +1062,7 @@ void QgsCircularString::append( const QgsCircularString *line )
 
   if ( numPoints() < 1 )
   {
-    setZMTypeFromSubGeometry( line, QgsWkbTypes::CircularString );
+    setZMTypeFromSubGeometry( line, Qgis::WkbType::CircularString );
   }
 
   // do not store duplicate points
@@ -1162,8 +1179,8 @@ void arcTo( QPainterPath &path, QPointF pt1, QPointF pt2, QPointF pt3 )
   QgsGeometryUtils::circleCenterRadius( QgsPoint( pt1.x(), pt1.y() ), QgsPoint( pt2.x(), pt2.y() ), QgsPoint( pt3.x(), pt3.y() ),
                                         radius, centerX, centerY );
 
-  double p1Angle = QgsGeometryUtils::ccwAngle( pt1.y() - centerY, pt1.x() - centerX );
-  double sweepAngle = QgsGeometryUtils::sweepAngle( centerX, centerY, pt1.x(), pt1.y(), pt2.x(), pt2.y(), pt3.x(), pt3.y() );
+  double p1Angle = QgsGeometryUtilsBase::ccwAngle( pt1.y() - centerY, pt1.x() - centerX );
+  double sweepAngle = QgsGeometryUtilsBase::sweepAngle( centerX, centerY, pt1.x(), pt1.y(), pt2.x(), pt2.y(), pt3.x(), pt3.y() );
 
   double diameter = 2 * radius;
   path.arcTo( centerX - radius, centerY - radius, diameter, diameter, -p1Angle, -sweepAngle );
@@ -1387,8 +1404,8 @@ void QgsCircularString::sumUpArea( double &sum ) const
       continue;
     }
 
-    bool circlePointLeftOfLine = QgsGeometryUtils::leftOfLine( p2.x(), p2.y(), p1.x(), p1.y(), p3.x(), p3.y() ) < 0;
-    bool centerPointLeftOfLine = QgsGeometryUtils::leftOfLine( centerX, centerY, p1.x(), p1.y(), p3.x(), p3.y() ) < 0;
+    bool circlePointLeftOfLine = QgsGeometryUtilsBase::leftOfLine( p2.x(), p2.y(), p1.x(), p1.y(), p3.x(), p3.y() ) < 0;
+    bool centerPointLeftOfLine = QgsGeometryUtilsBase::leftOfLine( centerX, centerY, p1.x(), p1.y(), p3.x(), p3.y() ) < 0;
 
     double cov = 0.5 - d * std::sqrt( r2 - d * d ) / ( M_PI * r2 ) - M_1_PI * std::asin( d / radius );
     double circleChordArea = 0;
@@ -1429,20 +1446,20 @@ double QgsCircularString::closestPointOnArc( double x1, double y1, double x2, do
   QgsPoint pt3( x3, y3 );
 
   QgsGeometryUtils::circleCenterRadius( pt1, pt2, pt3, radius, centerX, centerY );
-  double angle = QgsGeometryUtils::ccwAngle( pt.y() - centerY, pt.x() - centerX );
-  double angle1 = QgsGeometryUtils::ccwAngle( pt1.y() - centerY, pt1.x() - centerX );
-  double angle2 = QgsGeometryUtils::ccwAngle( pt2.y() - centerY, pt2.x() - centerX );
-  double angle3 = QgsGeometryUtils::ccwAngle( pt3.y() - centerY, pt3.x() - centerX );
+  double angle = QgsGeometryUtilsBase::ccwAngle( pt.y() - centerY, pt.x() - centerX );
+  double angle1 = QgsGeometryUtilsBase::ccwAngle( pt1.y() - centerY, pt1.x() - centerX );
+  double angle2 = QgsGeometryUtilsBase::ccwAngle( pt2.y() - centerY, pt2.x() - centerX );
+  double angle3 = QgsGeometryUtilsBase::ccwAngle( pt3.y() - centerY, pt3.x() - centerX );
 
-  bool clockwise = QgsGeometryUtils::circleClockwise( angle1, angle2, angle3 );
+  bool clockwise = QgsGeometryUtilsBase::circleClockwise( angle1, angle2, angle3 );
 
-  if ( QgsGeometryUtils::angleOnCircle( angle, angle1, angle2, angle3 ) )
+  if ( QgsGeometryUtilsBase::angleOnCircle( angle, angle1, angle2, angle3 ) )
   {
     //get point on line center -> pt with distance radius
     segmentPt = QgsGeometryUtils::pointOnLineWithDistance( QgsPoint( centerX, centerY ), pt, radius );
 
     //vertexAfter
-    vertexAfter.vertex = QgsGeometryUtils::circleAngleBetween( angle, angle1, angle2, clockwise ) ? 1 : 2;
+    vertexAfter.vertex = QgsGeometryUtilsBase::circleAngleBetween( angle, angle1, angle2, clockwise ) ? 1 : 2;
   }
   else
   {
@@ -1463,7 +1480,7 @@ double QgsCircularString::closestPointOnArc( double x1, double y1, double x2, do
 
   if ( leftOf )
   {
-    double sqrDistancePointToCenter = ( pt.x() - centerX ) * ( pt.x() - centerX ) + ( pt.y() - centerY ) * ( pt.y() - centerY );
+    double sqrDistancePointToCenter = pt.distanceSquared( centerX, centerY );
     *leftOf = clockwise ? ( sqrDistancePointToCenter > radius * radius ? -1 : 1 )
               : ( sqrDistancePointToCenter < radius * radius ? -1 : 1 );
   }
@@ -1552,7 +1569,7 @@ double QgsCircularString::vertexAngle( QgsVertexId vId ) const
       int vertex5 = vId.vertex + 2;
       double angle2 = QgsGeometryUtils::circleTangentDirection( QgsPoint( mX[vertex3], mY[vertex3] ),
                       QgsPoint( mX[vertex3], mY[vertex3] ), QgsPoint( mX[vertex4], mY[vertex4] ), QgsPoint( mX[vertex5], mY[vertex5] ) );
-      return QgsGeometryUtils::averageAngle( angle1, angle2 );
+      return QgsGeometryUtilsBase::averageAngle( angle1, angle2 );
     }
   }
   return 0.0;
@@ -1572,7 +1589,7 @@ double QgsCircularString::segmentLength( QgsVertexId startVertex ) const
   double y2 = mY.at( startVertex.vertex + 1 );
   double x3 = mX.at( startVertex.vertex + 2 );
   double y3 = mY.at( startVertex.vertex + 2 );
-  return QgsGeometryUtils::circleLength( x1, y1, x2, y2, x3, y3 );
+  return QgsGeometryUtilsBase::circleLength( x1, y1, x2, y2, x3, y3 );
 }
 
 QgsCircularString *QgsCircularString::reversed() const
@@ -1588,6 +1605,8 @@ QgsCircularString *QgsCircularString::reversed() const
   {
     std::reverse( copy->mM.begin(), copy->mM.end() );
   }
+
+  copy->mSummedUpArea = -mSummedUpArea;
   return copy;
 }
 
@@ -1601,9 +1620,9 @@ QgsPoint *QgsCircularString::interpolatePoint( const double distance ) const
   if ( totalPoints == 0 )
     return nullptr;
 
-  QgsWkbTypes::Type pointType = QgsWkbTypes::Point;
+  Qgis::WkbType pointType = Qgis::WkbType::Point;
   if ( is3D() )
-    pointType = QgsWkbTypes::PointZ;
+    pointType = Qgis::WkbType::PointZ;
   if ( isMeasure() )
     pointType = QgsWkbTypes::addM( pointType );
 
@@ -1639,7 +1658,7 @@ QgsPoint *QgsCircularString::interpolatePoint( const double distance ) const
     double z3 = z ? *z++ : 0.0;
     double m3 = m ? *m++ : 0.0;
 
-    const double segmentLength = QgsGeometryUtils::circleLength( x1, y1, x2, y2, x3, y3 );
+    const double segmentLength = QgsGeometryUtilsBase::circleLength( x1, y1, x2, y2, x3, y3 );
     if ( distance < distanceTraversed + segmentLength || qgsDoubleNear( distance, distanceTraversed + segmentLength ) )
     {
       // point falls on this segment - truncate to segment length if qgsDoubleNear test was actually > segment length
@@ -1674,9 +1693,9 @@ QgsCircularString *QgsCircularString::curveSubstring( double startDistance, doub
   QVector< QgsPoint > substringPoints;
   substringPoints.reserve( totalPoints );
 
-  QgsWkbTypes::Type pointType = QgsWkbTypes::Point;
+  Qgis::WkbType pointType = Qgis::WkbType::Point;
   if ( is3D() )
-    pointType = QgsWkbTypes::PointZ;
+    pointType = Qgis::WkbType::PointZ;
   if ( isMeasure() )
     pointType = QgsWkbTypes::addM( pointType );
 
@@ -1713,7 +1732,7 @@ QgsCircularString *QgsCircularString::curveSubstring( double startDistance, doub
     double m3 = m ? *m++ : 0.0;
 
     bool addedSegmentEnd = false;
-    const double segmentLength = QgsGeometryUtils::circleLength( x1, y1, x2, y2, x3, y3 );
+    const double segmentLength = QgsGeometryUtilsBase::circleLength( x1, y1, x2, y2, x3, y3 );
     if ( distanceTraversed <= startDistance && startDistance < distanceTraversed + segmentLength )
     {
       // start point falls on this segment
