@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsmeshdatasetgroupstore.h"
+#include "moc_qgsmeshdatasetgroupstore.cpp"
 #include "qgsmeshlayer.h"
 #include "qgsmeshlayerutils.h"
 #include "qgsapplication.h"
@@ -24,7 +25,7 @@
 
 QList<int> QgsMeshDatasetGroupStore::datasetGroupIndexes() const
 {
-  return mRegistery.keys();
+  return mRegistry.keys();
 }
 
 QList<int> QgsMeshDatasetGroupStore::enabledDatasetGroupIndexes() const
@@ -34,17 +35,16 @@ QList<int> QgsMeshDatasetGroupStore::enabledDatasetGroupIndexes() const
 
 int QgsMeshDatasetGroupStore::datasetGroupCount() const
 {
-  return mRegistery.count();
+  return mRegistry.count();
 }
 
 int QgsMeshDatasetGroupStore::extraDatasetGroupCount() const
 {
-  return mExtraDatasets->datasetGroupCount();
+  return mExtraDatasets.datasetGroupCount();
 }
 
 QgsMeshDatasetGroupStore::QgsMeshDatasetGroupStore( QgsMeshLayer *layer ):
   mLayer( layer ),
-  mExtraDatasets( new QgsMeshExtraDatasetStore ),
   mDatasetGroupTreeRootItem( new QgsMeshDatasetGroupTreeItem )
 {}
 
@@ -63,22 +63,19 @@ void QgsMeshDatasetGroupStore::setPersistentProvider( QgsMeshDataProvider *provi
   removeUnregisteredItemFromTree();
 
   //Once everything is in place, initialize the extra dataset groups
-  if ( mExtraDatasets )
-  {
-    const int groupCount = mExtraDatasets->datasetGroupCount();
-    for ( int i = 0; i < groupCount; ++i )
-      if ( mExtraDatasets->datasetGroup( i ) )
-        mExtraDatasets->datasetGroup( i )->initialize();
-  }
+  const int groupCount = mExtraDatasets.datasetGroupCount();
+  for ( int i = 0; i < groupCount; ++i )
+    if ( mExtraDatasets.datasetGroup( i ) )
+      mExtraDatasets.datasetGroup( i )->initialize();
 
-  mExtraDatasets->updateTemporalCapabilities();
+  mExtraDatasets.updateTemporalCapabilities();
 
   connect( mPersistentProvider, &QgsMeshDataProvider::datasetGroupsAdded, this, &QgsMeshDatasetGroupStore::onPersistentDatasetAdded );
 }
 
 QgsMeshDatasetGroupStore::DatasetGroup QgsMeshDatasetGroupStore::datasetGroup( int index ) const
 {
-  return mRegistery.value( index, DatasetGroup{nullptr, -1} );
+  return mRegistry.value( index, DatasetGroup{nullptr, -1} );
 }
 
 bool QgsMeshDatasetGroupStore::addPersistentDatasets( const QString &path )
@@ -90,7 +87,7 @@ bool QgsMeshDatasetGroupStore::addPersistentDatasets( const QString &path )
 
 bool QgsMeshDatasetGroupStore::addDatasetGroup( QgsMeshDatasetGroup *group )
 {
-  if ( !mExtraDatasets && !mLayer )
+  if ( !mLayer )
     return false;
 
   switch ( group->dataType() )
@@ -112,8 +109,8 @@ bool QgsMeshDatasetGroupStore::addDatasetGroup( QgsMeshDatasetGroup *group )
       break;
   }
 
-  int nativeIndex = mExtraDatasets->addDatasetGroup( group );
-  int groupIndex = registerDatasetGroup( DatasetGroup{mExtraDatasets.get(), nativeIndex} );
+  int nativeIndex = mExtraDatasets.addDatasetGroup( group );
+  int groupIndex = registerDatasetGroup( DatasetGroup{&mExtraDatasets, nativeIndex} );
 
   if ( groupIndex == -1 )
     return false;
@@ -197,13 +194,13 @@ QgsMeshDataBlock QgsMeshDatasetGroupStore::datasetValues( const QgsMeshDatasetIn
     return QgsMeshDataBlock();
 }
 
-QgsMesh3dDataBlock QgsMeshDatasetGroupStore::dataset3dValues( const QgsMeshDatasetIndex &index, int faceIndex, int count ) const
+QgsMesh3DDataBlock QgsMeshDatasetGroupStore::dataset3dValues( const QgsMeshDatasetIndex &index, int faceIndex, int count ) const
 {
   QgsMeshDatasetGroupStore::DatasetGroup  group = datasetGroup( index.group() );
   if ( group.first )
     return group.first->dataset3dValues( QgsMeshDatasetIndex( group.second, index.dataset() ), faceIndex, count );
   else
-    return QgsMesh3dDataBlock();
+    return QgsMesh3DDataBlock();
 }
 
 QgsMeshDataBlock QgsMeshDatasetGroupStore::areFacesActive( const QgsMeshDatasetIndex &index, int faceIndex, int count ) const
@@ -270,8 +267,8 @@ qint64 QgsMeshDatasetGroupStore::datasetRelativeTime( const QgsMeshDatasetIndex
 
   if ( group.first == mPersistentProvider )
     return mPersistentProvider->temporalCapabilities()->datasetTime( nativeIndex );
-  else if ( group.first == mExtraDatasets.get() )
-    return mExtraDatasets->datasetRelativeTime( nativeIndex );
+  else if ( group.first == &mExtraDatasets )
+    return mExtraDatasets.datasetRelativeTime( nativeIndex );
 
   return INVALID_MESHLAYER_TIME;
 
@@ -280,7 +277,7 @@ qint64 QgsMeshDatasetGroupStore::datasetRelativeTime( const QgsMeshDatasetIndex
 bool QgsMeshDatasetGroupStore::hasTemporalCapabilities() const
 {
   return ( mPersistentProvider && mPersistentProvider->temporalCapabilities()->hasTemporalCapabilities() ) ||
-         ( mExtraDatasets && mExtraDatasets->hasTemporalCapabilities() );
+         ( mExtraDatasets.hasTemporalCapabilities() );
 }
 
 QDomElement QgsMeshDatasetGroupStore::writeXml( QDomDocument &doc, const QgsReadWriteContext &context )
@@ -289,8 +286,8 @@ QDomElement QgsMeshDatasetGroupStore::writeXml( QDomDocument &doc, const QgsRead
   QDomElement storeElement = doc.createElement( QStringLiteral( "mesh-dataset-groups-store" ) );
   storeElement.appendChild( mDatasetGroupTreeRootItem->writeXml( doc, context ) );
 
-  QMap < int, DatasetGroup>::const_iterator it = mRegistery.constBegin();
-  while ( it != mRegistery.constEnd() )
+  QMap < int, DatasetGroup>::const_iterator it = mRegistry.constBegin();
+  while ( it != mRegistry.constEnd() )
   {
     QDomElement elemDataset;
     if ( it.value().first == mPersistentProvider )
@@ -300,12 +297,12 @@ QDomElement QgsMeshDatasetGroupStore::writeXml( QDomDocument &doc, const QgsRead
       elemDataset.setAttribute( QStringLiteral( "source-type" ), QStringLiteral( "persitent-provider" ) );
       elemDataset.setAttribute( QStringLiteral( "source-index" ), it.value().second );
     }
-    else if ( it.value().first == mExtraDatasets.get() )
+    else if ( it.value().first == &mExtraDatasets )
     {
       QgsMeshDatasetGroupTreeItem *item = mDatasetGroupTreeRootItem->childFromDatasetGroupIndex( it.key() );
       if ( item )
       {
-        elemDataset = mExtraDatasets->writeXml( it.value().second, doc, context );
+        elemDataset = mExtraDatasets.writeXml( it.value().second, doc, context );
         if ( !elemDataset.isNull() )
           elemDataset.setAttribute( QStringLiteral( "global-index" ), it.key() );
       }
@@ -331,7 +328,7 @@ QDomElement QgsMeshDatasetGroupStore::writeXml( QDomDocument &doc, const QgsRead
 void QgsMeshDatasetGroupStore::readXml( const QDomElement &storeElem, const QgsReadWriteContext &context )
 {
   Q_UNUSED( context );
-  mRegistery.clear();
+  mRegistry.clear();
   QDomElement datasetElem = storeElem.firstChildElement( "mesh-dataset" );
   QMap<int, QgsMeshDatasetGroup *> extraDatasetGroups;
   while ( !datasetElem.isNull() )
@@ -345,7 +342,7 @@ void QgsMeshDatasetGroupStore::readXml( const QDomElement &storeElem, const QgsR
     }
     else if ( sourceType == QLatin1String( "virtual" ) )
     {
-      QgsMeshDatasetSourceInterface *source = mExtraDatasets.get();
+      QgsMeshDatasetSourceInterface *source = &mExtraDatasets;
       QString name = datasetElem.attribute( QStringLiteral( "name" ) );
       QString formula = datasetElem.attribute( QStringLiteral( "formula" ) );
       qint64 startTime = datasetElem.attribute( QStringLiteral( "start-time" ) ).toLongLong();
@@ -353,13 +350,13 @@ void QgsMeshDatasetGroupStore::readXml( const QDomElement &storeElem, const QgsR
 
       QgsMeshDatasetGroup *dsg = new QgsMeshVirtualDatasetGroup( name, formula, mLayer, startTime, endTime );
       extraDatasetGroups[globalIndex] = dsg;
-      int sourceIndex = mExtraDatasets->addDatasetGroup( dsg );
+      int sourceIndex = mExtraDatasets.addDatasetGroup( dsg );
 
-      mRegistery[globalIndex] = DatasetGroup{source, sourceIndex};
+      mRegistry[globalIndex] = DatasetGroup{source, sourceIndex};
     }
     else
     {
-      QgsDebugMsg( QStringLiteral( "Unhandled source-type: %1." ).arg( sourceType ) );
+      QgsDebugError( QStringLiteral( "Unhandled source-type: %1." ).arg( sourceType ) );
     }
 
     datasetElem = datasetElem.nextSiblingElement( QStringLiteral( "mesh-dataset" ) );
@@ -387,7 +384,7 @@ void QgsMeshDatasetGroupStore::readXml( const QDomElement &storeElem, const QgsR
 
 int QgsMeshDatasetGroupStore::globalDatasetGroupIndexInSource( QgsMeshDatasetSourceInterface *source, int nativeGroupIndex ) const
 {
-  for ( QMap<int, DatasetGroup>::const_iterator it = mRegistery.cbegin(); it != mRegistery.cend(); ++it )
+  for ( QMap<int, DatasetGroup>::const_iterator it = mRegistry.cbegin(); it != mRegistry.cend(); ++it )
   {
     if ( it.value().first == source && it.value().second == nativeGroupIndex )
       return it.key();
@@ -396,6 +393,16 @@ int QgsMeshDatasetGroupStore::globalDatasetGroupIndexInSource( QgsMeshDatasetSou
   return -1;
 }
 
+int QgsMeshDatasetGroupStore::indexFromGroupName( const QString &groupName ) const
+{
+  return mGroupNameToGlobalIndex.value( groupName, -1 );
+}
+
+QString QgsMeshDatasetGroupStore::groupName( int groupIndex ) const
+{
+  return  datasetGroupMetadata( groupIndex ).name();
+}
+
 bool QgsMeshDatasetGroupStore::saveDatasetGroup( QString filePath, int groupIndex, QString driver )
 {
   DatasetGroup group = datasetGroup( groupIndex );
@@ -409,7 +416,7 @@ bool QgsMeshDatasetGroupStore::saveDatasetGroup( QString filePath, int groupInde
     eraseDatasetGroup( group );
     group.first = mPersistentProvider;
     group.second = mPersistentProvider->datasetGroupCount() - 1;
-    mRegistery[groupIndex] = group;
+    mRegistry[groupIndex] = group;
     //update the item type
     if ( mDatasetGroupTreeRootItem )
     {
@@ -435,7 +442,7 @@ void QgsMeshDatasetGroupStore::onPersistentDatasetAdded( int count )
     if ( mGroupNameToGlobalIndex.empty() && i < mPersistentExtraDatasetGroupIndexes.count() )
     {
       // This happens with QGIS project saved with version < 3.28
-      mRegistery[mPersistentExtraDatasetGroupIndexes.at( i )] = DatasetGroup( mPersistentProvider, i );
+      mRegistry[mPersistentExtraDatasetGroupIndexes.at( i )] = DatasetGroup( mPersistentProvider, i );
     }
     else if ( mGroupNameToGlobalIndex.contains( groupName ) )
     {
@@ -469,11 +476,11 @@ void QgsMeshDatasetGroupStore::removePersistentProvider()
 
   disconnect( mPersistentProvider, &QgsMeshDataProvider::datasetGroupsAdded, this, &QgsMeshDatasetGroupStore::onPersistentDatasetAdded );
 
-  QMap < int, DatasetGroup>::iterator it = mRegistery.begin();
-  while ( it != mRegistery.end() )
+  QMap < int, DatasetGroup>::iterator it = mRegistry.begin();
+  while ( it != mRegistry.end() )
   {
     if ( it.value().first == mPersistentProvider )
-      it = mRegistery.erase( it );
+      it = mRegistry.erase( it );
     else
       ++it;
   }
@@ -483,7 +490,7 @@ void QgsMeshDatasetGroupStore::removePersistentProvider()
 
 int QgsMeshDatasetGroupStore::newIndex()
 {
-  QSet usedIndex = qgis::listToSet( mRegistery.keys() );
+  QSet usedIndex = qgis::listToSet( mRegistry.keys() );
   usedIndex.unite( qgis::listToSet( mGroupNameToGlobalIndex.values() ) );
   int index = 0;
 
@@ -503,10 +510,10 @@ int QgsMeshDatasetGroupStore::registerDatasetGroup( const QgsMeshDatasetGroupSto
   {
     groupIndex = it.value();
 
-    if ( mRegistery.contains( groupIndex ) )
+    if ( mRegistry.contains( groupIndex ) )
     {
-      QgsDebugMsg( QStringLiteral( "Dupplicate group name for %1." ).arg( name ) );
-      return -1; // The registery has already a group with this index, we can't have two groups with the same name
+      QgsDebugError( QStringLiteral( "Duplicate group name for %1." ).arg( name ) );
+      return -1; // The registry has already a group with this index, we can't have two groups with the same name
     }
   }
   else
@@ -515,7 +522,7 @@ int QgsMeshDatasetGroupStore::registerDatasetGroup( const QgsMeshDatasetGroupSto
     mGroupNameToGlobalIndex.insert( name, groupIndex );
   }
 
-  mRegistery[groupIndex] = group;
+  mRegistry[groupIndex] = group;
   return groupIndex;
 }
 
@@ -523,20 +530,20 @@ void QgsMeshDatasetGroupStore::eraseDatasetGroup( const QgsMeshDatasetGroupStore
 {
   if ( group.first == mPersistentProvider )
     return; //removing persistent dataset group from the store is not allowed
-  else if ( group.first == mExtraDatasets.get() )
+  else if ( group.first == &mExtraDatasets )
     eraseExtraDataset( group.second );
 }
 
 void QgsMeshDatasetGroupStore::eraseExtraDataset( int indexInExtraStore )
 {
-  mExtraDatasets->removeDatasetGroup( indexInExtraStore );
+  mExtraDatasets.removeDatasetGroup( indexInExtraStore );
 
   //search dataset with index greater than indexInExtraStore and decrement it
-  QMap < int, DatasetGroup>::iterator it = mRegistery.begin();
-  while ( it != mRegistery.end() )
+  QMap < int, DatasetGroup>::iterator it = mRegistry.begin();
+  while ( it != mRegistry.end() )
   {
     int localIndex = it.value().second;
-    if ( it.value().first == mExtraDatasets.get() && localIndex > indexInExtraStore )
+    if ( it.value().first == &mExtraDatasets && localIndex > indexInExtraStore )
       it->second = localIndex - 1;
     ++it;
   }
@@ -559,10 +566,10 @@ void QgsMeshDatasetGroupStore::checkDatasetConsistency( QgsMeshDatasetSourceInte
   if ( !indexes.isEmpty() )
     createDatasetGroupTreeItems( indexes );
 
-  const QList<int> globalIndexes = mRegistery.keys();
+  const QList<int> globalIndexes = mRegistry.keys();
   for ( int globalIndex :  globalIndexes )
   {
-    if ( mRegistery.value( globalIndex ).first == source )
+    if ( mRegistry.value( globalIndex ).first == source )
       syncItemToDatasetGroup( globalIndex );
   }
 }
@@ -578,7 +585,7 @@ void QgsMeshDatasetGroupStore::removeUnregisteredItemFromTree()
   {
     QgsMeshDatasetGroupTreeItem *item = itemsToCheck.takeFirst();
     int globalIndex = item->datasetGroupIndex();
-    if ( !mRegistery.contains( globalIndex ) )
+    if ( !mRegistry.contains( globalIndex ) )
       indexItemToRemove.append( globalIndex );
     for ( int i = 0; i < item->childCount(); ++i )
       itemsToCheck.append( item->child( i ) );
@@ -596,19 +603,19 @@ void QgsMeshDatasetGroupStore::unregisterGroupNotPresentInTree()
 {
   if ( !mDatasetGroupTreeRootItem )
   {
-    mRegistery.clear();
+    mRegistry.clear();
     return;
   }
 
-  QMap < int, DatasetGroup>::iterator it = mRegistery.begin();
-  while ( it != mRegistery.end() )
+  QMap < int, DatasetGroup>::iterator it = mRegistry.begin();
+  while ( it != mRegistry.end() )
   {
     DatasetGroup datasetGroup = it.value();
     int globalIndex = it.key();
     if ( ! mDatasetGroupTreeRootItem->childFromDatasetGroupIndex( globalIndex ) // Not in the tree item
          && datasetGroup.first != mPersistentProvider ) // and not persistent
     {
-      it = mRegistery.erase( it ); //remove from registery
+      it = mRegistry.erase( it ); //remove from registry
       eraseDatasetGroup( datasetGroup ); //remove from where the dataset group is stored
     }
     else
@@ -628,10 +635,10 @@ void QgsMeshDatasetGroupStore::syncItemToDatasetGroup( int groupIndex )
     if ( item )
       item->setPersistentDatasetGroup( meta.uri() );
   }
-  else if ( group.first == mExtraDatasets.get() )
+  else if ( group.first == &mExtraDatasets )
   {
     if ( item )
-      item->setDatasetGroup( mExtraDatasets->datasetGroup( group.second ) );
+      item->setDatasetGroup( mExtraDatasets.datasetGroup( group.second ) );
   }
 }
 
@@ -655,7 +662,7 @@ void QgsMeshDatasetGroupStore::createDatasetGroupTreeItems( const QList<int> &in
     {
       auto it = mNameToItem.find( subdatasets[0] );
       if ( it == mNameToItem.end() )
-        QgsDebugMsg( QStringLiteral( "Unable to find parent group for %1." ).arg( name ) );
+        QgsDebugError( QStringLiteral( "Unable to find parent group for %1." ).arg( name ) );
       else
       {
         displayName = subdatasets[1];
@@ -663,12 +670,12 @@ void QgsMeshDatasetGroupStore::createDatasetGroupTreeItems( const QList<int> &in
       }
     }
     else if ( subdatasets.size() != 1 )
-      QgsDebugMsg( QStringLiteral( "Ignoring too deep child group name %1." ).arg( name ) );
+      QgsDebugError( QStringLiteral( "Ignoring too deep child group name %1." ).arg( name ) );
 
     QgsMeshDatasetGroupTreeItem *item = new QgsMeshDatasetGroupTreeItem( displayName, name, meta.isVector(), groupIndex );
     parent->appendChild( item );
     if ( mNameToItem.contains( name ) )
-      QgsDebugMsg( QStringLiteral( "Group %1 is not unique" ).arg( displayName ) );
+      QgsDebugError( QStringLiteral( "Group %1 is not unique" ).arg( displayName ) );
     mNameToItem[name] = item;
   }
 }
@@ -702,7 +709,7 @@ bool QgsMeshExtraDatasetStore::hasTemporalCapabilities() const
   return mTemporalCapabilities->hasTemporalCapabilities();
 }
 
-quint64 QgsMeshExtraDatasetStore::datasetRelativeTime( QgsMeshDatasetIndex index )
+qint64 QgsMeshExtraDatasetStore::datasetRelativeTime( QgsMeshDatasetIndex index ) const
 {
   return mTemporalCapabilities->datasetTime( index );
 }
@@ -796,13 +803,13 @@ QgsMeshDataBlock QgsMeshExtraDatasetStore::datasetValues( QgsMeshDatasetIndex in
   return QgsMeshDataBlock();
 }
 
-QgsMesh3dDataBlock QgsMeshExtraDatasetStore::dataset3dValues( QgsMeshDatasetIndex index, int faceIndex, int count ) const
+QgsMesh3DDataBlock QgsMeshExtraDatasetStore::dataset3dValues( QgsMeshDatasetIndex index, int faceIndex, int count ) const
 {
   // Not supported for now
   Q_UNUSED( index )
   Q_UNUSED( faceIndex )
   Q_UNUSED( count )
-  return QgsMesh3dDataBlock();
+  return QgsMesh3DDataBlock();
 }
 
 bool QgsMeshExtraDatasetStore::isFaceActive( QgsMeshDatasetIndex index, int faceIndex ) const
