@@ -29,12 +29,12 @@
 
 QgsPlot::~QgsPlot() = default;
 
-bool QgsPlot::writeXml( QDomElement &, QDomDocument &, QgsReadWriteContext & ) const
+bool QgsPlot::writeXml( QDomElement &, QDomDocument &, const QgsReadWriteContext & ) const
 {
   return true;
 }
 
-bool QgsPlot::readXml( const QDomElement &, QgsReadWriteContext & )
+bool QgsPlot::readXml( const QDomElement &, const QgsReadWriteContext & )
 {
   return true;
 }
@@ -45,25 +45,20 @@ bool QgsPlot::readXml( const QDomElement &, QgsReadWriteContext & )
 QgsPlotAxis::QgsPlotAxis()
 {
   // setup default style
-
-  mNumericFormat = std::make_unique< QgsBasicNumericFormat >();
-
-  std::unique_ptr< QgsSimpleLineSymbolLayer > gridMinor = std::make_unique< QgsSimpleLineSymbolLayer >( QColor( 20, 20, 20, 50 ), 0.1 );
-  gridMinor->setPenCapStyle( Qt::FlatCap );
-  mGridMinorSymbol = std::make_unique< QgsLineSymbol>( QgsSymbolLayerList( { gridMinor.release() } ) );
-
-  std::unique_ptr< QgsSimpleLineSymbolLayer > gridMajor = std::make_unique< QgsSimpleLineSymbolLayer >( QColor( 20, 20, 20, 150 ), 0.1 );
-  gridMajor->setPenCapStyle( Qt::FlatCap );
-  mGridMajorSymbol = std::make_unique< QgsLineSymbol>( QgsSymbolLayerList( { gridMajor.release() } ) );
+  mNumericFormat.reset( QgsPlotDefaultSettings::axisLabelNumericFormat() );
+  mGridMinorSymbol.reset( QgsPlotDefaultSettings::axisGridMinorSymbol() );
+  mGridMajorSymbol.reset( QgsPlotDefaultSettings::axisGridMajorSymbol() );
 }
 
 QgsPlotAxis::~QgsPlotAxis() = default;
 
-bool QgsPlotAxis::writeXml( QDomElement &element, QDomDocument &document, QgsReadWriteContext &context ) const
+bool QgsPlotAxis::writeXml( QDomElement &element, QDomDocument &document, const QgsReadWriteContext &context ) const
 {
   element.setAttribute( QStringLiteral( "gridIntervalMinor" ), qgsDoubleToString( mGridIntervalMinor ) );
   element.setAttribute( QStringLiteral( "gridIntervalMajor" ), qgsDoubleToString( mGridIntervalMajor ) );
   element.setAttribute( QStringLiteral( "labelInterval" ), qgsDoubleToString( mLabelInterval ) );
+  element.setAttribute( QStringLiteral( "suffix" ), mLabelSuffix );
+  element.setAttribute( QStringLiteral( "suffixPlacement" ), qgsEnumValueToKey( mSuffixPlacement ) );
 
   QDomElement numericFormatElement = document.createElement( QStringLiteral( "numericFormat" ) );
   mNumericFormat->writeXml( numericFormatElement, document, context );
@@ -83,12 +78,15 @@ bool QgsPlotAxis::writeXml( QDomElement &element, QDomDocument &document, QgsRea
   return true;
 }
 
-bool QgsPlotAxis::readXml( const QDomElement &element, QgsReadWriteContext &context )
+bool QgsPlotAxis::readXml( const QDomElement &element, const QgsReadWriteContext &context )
 {
   mGridIntervalMinor = element.attribute( QStringLiteral( "gridIntervalMinor" ) ).toDouble();
   mGridIntervalMajor = element.attribute( QStringLiteral( "gridIntervalMajor" ) ).toDouble();
   mLabelInterval = element.attribute( QStringLiteral( "labelInterval" ) ).toDouble();
 
+  mLabelSuffix = element.attribute( QStringLiteral( "suffix" ) );
+  mSuffixPlacement = qgsEnumKeyToValue( element.attribute( QStringLiteral( "suffixPlacement" ) ), Qgis::PlotAxisSuffixPlacement::NoLabels );
+
   const QDomElement numericFormatElement = element.firstChildElement( QStringLiteral( "numericFormat" ) );
   mNumericFormat.reset( QgsApplication::numericFormatRegistry()->createFromXml( numericFormatElement, context ) );
 
@@ -113,6 +111,26 @@ void QgsPlotAxis::setNumericFormat( QgsNumericFormat *format )
   mNumericFormat.reset( format );
 }
 
+QString QgsPlotAxis::labelSuffix() const
+{
+  return mLabelSuffix;
+}
+
+void QgsPlotAxis::setLabelSuffix( const QString &suffix )
+{
+  mLabelSuffix = suffix;
+}
+
+Qgis::PlotAxisSuffixPlacement QgsPlotAxis::labelSuffixPlacement() const
+{
+  return mSuffixPlacement;
+}
+
+void QgsPlotAxis::setLabelSuffixPlacement( Qgis::PlotAxisSuffixPlacement placement )
+{
+  mSuffixPlacement = placement;
+}
+
 QgsLineSymbol *QgsPlotAxis::gridMajorSymbol()
 {
   return mGridMajorSymbol.get();
@@ -152,14 +170,11 @@ Qgs2DPlot::Qgs2DPlot()
   : mMargins( 2, 2, 2, 2 )
 {
   // setup default style
-  std::unique_ptr< QgsSimpleFillSymbolLayer > chartFill = std::make_unique< QgsSimpleFillSymbolLayer >( QColor( 255, 255, 255 ) );
-  mChartBackgroundSymbol = std::make_unique< QgsFillSymbol>( QgsSymbolLayerList( { chartFill.release() } ) );
-
-  std::unique_ptr< QgsSimpleLineSymbolLayer > chartBorder = std::make_unique< QgsSimpleLineSymbolLayer >( QColor( 20, 20, 20 ), 0.1 );
-  mChartBorderSymbol = std::make_unique< QgsFillSymbol>( QgsSymbolLayerList( { chartBorder.release() } ) );
+  mChartBackgroundSymbol.reset( QgsPlotDefaultSettings::chartBackgroundSymbol() );
+  mChartBorderSymbol.reset( QgsPlotDefaultSettings::chartBorderSymbol() );
 }
 
-bool Qgs2DPlot::writeXml( QDomElement &element, QDomDocument &document, QgsReadWriteContext &context ) const
+bool Qgs2DPlot::writeXml( QDomElement &element, QDomDocument &document, const QgsReadWriteContext &context ) const
 {
   QgsPlot::writeXml( element, document, context );
 
@@ -187,7 +202,7 @@ bool Qgs2DPlot::writeXml( QDomElement &element, QDomDocument &document, QgsReadW
   return true;
 }
 
-bool Qgs2DPlot::readXml( const QDomElement &element, QgsReadWriteContext &context )
+bool Qgs2DPlot::readXml( const QDomElement &element, const QgsReadWriteContext &context )
 {
   QgsPlot::readXml( element, context );
 
@@ -227,8 +242,11 @@ void Qgs2DPlot::render( QgsRenderContext &context )
   const double firstMajorXGrid = std::ceil( mMinX / mXAxis.gridIntervalMajor() ) * mXAxis.gridIntervalMajor();
   const double firstMinorYGrid = std::ceil( mMinY / mYAxis.gridIntervalMinor() ) * mYAxis.gridIntervalMinor();
   const double firstMajorYGrid = std::ceil( mMinY / mYAxis.gridIntervalMajor() ) * mYAxis.gridIntervalMajor();
-  const double firstXLabel = std::ceil( mMinX / mXAxis.labelInterval() ) * mXAxis.labelInterval();
-  const double firstYLabel = std::ceil( mMinY / mYAxis.labelInterval() ) * mYAxis.labelInterval();
+  const double firstXLabel = mXAxis.labelInterval() > 0 ? std::ceil( mMinX / mXAxis.labelInterval() ) * mXAxis.labelInterval() : 0;
+  const double firstYLabel = mYAxis.labelInterval() > 0 ? std::ceil( mMinY / mYAxis.labelInterval() ) * mYAxis.labelInterval() : 0;
+
+  const QString xAxisSuffix = mXAxis.labelSuffix();
+  const QString yAxisSuffix = mYAxis.labelSuffix();
 
   const QRectF plotArea = interiorPlotArea( context );
 
@@ -240,11 +258,42 @@ void Qgs2DPlot::render( QgsRenderContext &context )
   // calculate text metrics
   double maxYAxisLabelWidth = 0;
   plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis" ), QStringLiteral( "y" ), true ) );
-  for ( double currentY = firstYLabel; currentY <= mMaxY && !qgsDoubleNear( currentY, mMaxY, yTolerance ); currentY += mYAxis.labelInterval() )
+  if ( mYAxis.labelInterval() > 0 )
   {
-    plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentY, true ) );
-    const QString text = mYAxis.numericFormat()->formatDouble( currentY, numericContext );
-    maxYAxisLabelWidth = std::max( maxYAxisLabelWidth, QgsTextRenderer::textWidth( context, mYAxis.textFormat(), { text } ) );
+    for ( double currentY = firstYLabel; ; currentY += mYAxis.labelInterval() )
+    {
+      const bool hasMoreLabels = currentY + mYAxis.labelInterval() <= mMaxY && !qgsDoubleNear( currentY + mYAxis.labelInterval(), mMaxY, yTolerance );
+      plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentY, true ) );
+      QString text = mYAxis.numericFormat()->formatDouble( currentY, numericContext );
+      switch ( mYAxis.labelSuffixPlacement() )
+      {
+        case Qgis::PlotAxisSuffixPlacement::NoLabels:
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::EveryLabel:
+          text += yAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstLabel:
+          if ( currentY == firstYLabel )
+            text += yAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::LastLabel:
+          if ( !hasMoreLabels )
+            text += yAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstAndLastLabels:
+          if ( currentY == firstYLabel || !hasMoreLabels )
+            text += yAxisSuffix;
+          break;
+      }
+
+      maxYAxisLabelWidth = std::max( maxYAxisLabelWidth, QgsTextRenderer::textWidth( context, mYAxis.textFormat(), { text } ) );
+      if ( !hasMoreLabels )
+        break;
+    }
   }
 
   const double chartAreaLeft = plotArea.left();
@@ -322,26 +371,88 @@ void Qgs2DPlot::render( QgsRenderContext &context )
   // x
   plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis" ), QStringLiteral( "x" ), true ) );
   objectNumber = 0;
-  for ( double currentX = firstXLabel; objectNumber < MAX_OBJECTS && ( currentX <= mMaxX || qgsDoubleNear( currentX, mMaxX, xTolerance ) ); currentX += mXAxis.labelInterval(), ++objectNumber )
+  if ( mXAxis.labelInterval() > 0 )
   {
-    plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentX, true ) );
-    const QString text = mXAxis.numericFormat()->formatDouble( currentX, numericContext );
-    QgsTextRenderer::drawText( QPointF( ( currentX - mMinX ) * xScale + chartAreaLeft, mSize.height() - context.convertToPainterUnits( mMargins.bottom(), QgsUnitTypes::RenderMillimeters ) ),
-                               0, Qgis::TextHorizontalAlignment::Center, { text }, context, mXAxis.textFormat() );
+    for ( double currentX = firstXLabel; ; currentX += mXAxis.labelInterval(), ++objectNumber )
+    {
+      const bool hasMoreLabels = objectNumber + 1 < MAX_OBJECTS && ( currentX + mXAxis.labelInterval() <= mMaxX || qgsDoubleNear( currentX + mXAxis.labelInterval(), mMaxX, xTolerance ) );
+      plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentX, true ) );
+      QString text = mXAxis.numericFormat()->formatDouble( currentX, numericContext );
+      switch ( mXAxis.labelSuffixPlacement() )
+      {
+        case Qgis::PlotAxisSuffixPlacement::NoLabels:
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::EveryLabel:
+          text += xAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstLabel:
+          if ( objectNumber == 0 )
+            text += xAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::LastLabel:
+          if ( !hasMoreLabels )
+            text += xAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstAndLastLabels:
+          if ( objectNumber == 0 || !hasMoreLabels )
+            text += xAxisSuffix;
+          break;
+      }
+
+      QgsTextRenderer::drawText( QPointF( ( currentX - mMinX ) * xScale + chartAreaLeft, mSize.height() - context.convertToPainterUnits( mMargins.bottom(), Qgis::RenderUnit::Millimeters ) ),
+                                 0, Qgis::TextHorizontalAlignment::Center, { text }, context, mXAxis.textFormat() );
+      if ( !hasMoreLabels )
+        break;
+    }
   }
 
   // y
   plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis" ), QStringLiteral( "y" ), true ) );
   objectNumber = 0;
-  for ( double currentY = firstYLabel; objectNumber < MAX_OBJECTS && ( currentY <= mMaxY || qgsDoubleNear( currentY, mMaxY, yTolerance ) ); currentY += mYAxis.labelInterval(), ++objectNumber )
+  if ( mYAxis.labelInterval() > 0 )
   {
-    plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentY, true ) );
-    const QString text = mYAxis.numericFormat()->formatDouble( currentY, numericContext );
-    const double height = QgsTextRenderer::textHeight( context, mYAxis.textFormat(), { text } );
-    QgsTextRenderer::drawText( QPointF(
-                                 maxYAxisLabelWidth + context.convertToPainterUnits( mMargins.left(), QgsUnitTypes::RenderMillimeters ),
-                                 chartAreaBottom - ( currentY - mMinY ) * yScale + height / 2 ),
-                               0, Qgis::TextHorizontalAlignment::Right, { text }, context, mYAxis.textFormat(), false );
+    for ( double currentY = firstYLabel; ; currentY += mYAxis.labelInterval(), ++objectNumber )
+    {
+      const bool hasMoreLabels = objectNumber + 1 < MAX_OBJECTS && ( currentY + mYAxis.labelInterval() <= mMaxY || qgsDoubleNear( currentY + mYAxis.labelInterval(), mMaxY, yTolerance ) );
+      plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentY, true ) );
+      QString text = mYAxis.numericFormat()->formatDouble( currentY, numericContext );
+      switch ( mYAxis.labelSuffixPlacement() )
+      {
+        case Qgis::PlotAxisSuffixPlacement::NoLabels:
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::EveryLabel:
+          text += yAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstLabel:
+          if ( objectNumber == 0 )
+            text += yAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::LastLabel:
+          if ( !hasMoreLabels )
+            text += yAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstAndLastLabels:
+          if ( objectNumber == 0 || !hasMoreLabels )
+            text += yAxisSuffix;
+          break;
+      }
+
+      const double height = QgsTextRenderer::textHeight( context, mYAxis.textFormat(), { text } );
+      QgsTextRenderer::drawText( QPointF(
+                                   maxYAxisLabelWidth + context.convertToPainterUnits( mMargins.left(), Qgis::RenderUnit::Millimeters ),
+                                   chartAreaBottom - ( currentY - mMinY ) * yScale + height / 2 ),
+                                 0, Qgis::TextHorizontalAlignment::Right, { text }, context, mYAxis.textFormat(), false );
+      if ( !hasMoreLabels )
+        break;
+    }
   }
 
   // give subclasses a chance to draw their content
@@ -388,7 +499,11 @@ QRectF Qgs2DPlot::interiorPlotArea( QgsRenderContext &context ) const
   const QgsExpressionContextScopePopper scopePopper( context.expressionContext(), plotScope );
 
   const double firstMinorYGrid = std::ceil( mMinY / mYAxis.gridIntervalMinor() ) * mYAxis.gridIntervalMinor();
-  const double firstXLabel = std::ceil( mMinX / mXAxis.labelInterval() ) * mXAxis.labelInterval();
+  const double firstXLabel = mXAxis.labelInterval() > 0 ? std::ceil( mMinX / mXAxis.labelInterval() ) * mXAxis.labelInterval() : 0;
+
+  const QString xAxisSuffix = mXAxis.labelSuffix();
+  const QString yAxisSuffix = mYAxis.labelSuffix();
+  const double yAxisSuffixWidth = yAxisSuffix.isEmpty() ? 0 : QgsTextRenderer::textWidth( context, mYAxis.textFormat(), { yAxisSuffix } );
 
   QgsNumericFormatContext numericContext;
 
@@ -401,47 +516,112 @@ QRectF Qgs2DPlot::interiorPlotArea( QgsRenderContext &context ) const
   int labelNumber = 0;
   double maxXAxisLabelHeight = 0;
   plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis" ), QStringLiteral( "x" ), true ) );
-  for ( double currentX = firstXLabel; labelNumber < MAX_LABELS && ( currentX <= mMaxX || qgsDoubleNear( currentX, mMaxX, xTolerance ) ); currentX += mXAxis.labelInterval(), labelNumber++ )
+  if ( mXAxis.labelInterval() > 0 )
   {
-    plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentX, true ) );
-    const QString text = mXAxis.numericFormat()->formatDouble( currentX, numericContext );
-    maxXAxisLabelHeight = std::max( maxXAxisLabelHeight, QgsTextRenderer::textHeight( context, mXAxis.textFormat(), { text } ) );
+    for ( double currentX = firstXLabel; ; currentX += mXAxis.labelInterval(), labelNumber++ )
+    {
+      const bool hasMoreLabels = labelNumber + 1 < MAX_LABELS && ( currentX + mXAxis.labelInterval() <= mMaxX || qgsDoubleNear( currentX + mXAxis.labelInterval(), mMaxX, xTolerance ) );
+
+      plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentX, true ) );
+      QString text = mXAxis.numericFormat()->formatDouble( currentX, numericContext );
+      switch ( mXAxis.labelSuffixPlacement() )
+      {
+        case Qgis::PlotAxisSuffixPlacement::NoLabels:
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::EveryLabel:
+          text += xAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstLabel:
+          if ( labelNumber == 0 )
+            text += xAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::LastLabel:
+          if ( !hasMoreLabels )
+            text += xAxisSuffix;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstAndLastLabels:
+          if ( labelNumber == 0 || !hasMoreLabels )
+            text += xAxisSuffix;
+          break;
+      }
+      maxXAxisLabelHeight = std::max( maxXAxisLabelHeight, QgsTextRenderer::textHeight( context, mXAxis.textFormat(), { text } ) );
+      if ( !hasMoreLabels )
+        break;
+    }
   }
 
   double maxYAxisLabelWidth = 0;
   labelNumber = 0;
   plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis" ), QStringLiteral( "y" ), true ) );
-  for ( double currentY = firstMinorYGrid; labelNumber < MAX_LABELS && ( currentY <= mMaxY || qgsDoubleNear( currentY, mMaxY, yTolerance ) ); currentY += mYAxis.gridIntervalMinor(), labelNumber ++ )
+  for ( double currentY = firstMinorYGrid; ; currentY += mYAxis.gridIntervalMinor(), labelNumber ++ )
   {
+    const bool hasMoreLabels = labelNumber + 1 < MAX_LABELS && ( currentY + mYAxis.gridIntervalMinor() <= mMaxY || qgsDoubleNear( currentY + mYAxis.gridIntervalMinor(), mMaxY, yTolerance ) );
     plotScope->addVariable( QgsExpressionContextScope::StaticVariable( QStringLiteral( "plot_axis_value" ), currentY, true ) );
     const QString text = mYAxis.numericFormat()->formatDouble( currentY, numericContext );
-    maxYAxisLabelWidth = std::max( maxYAxisLabelWidth, QgsTextRenderer::textWidth( context, mYAxis.textFormat(), { text } ) );
+    double thisLabelWidth = QgsTextRenderer::textWidth( context, mYAxis.textFormat(), { text } );
+    if ( yAxisSuffixWidth > 0 )
+    {
+      switch ( mYAxis.labelSuffixPlacement() )
+      {
+        case Qgis::PlotAxisSuffixPlacement::NoLabels:
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::EveryLabel:
+          thisLabelWidth += yAxisSuffixWidth;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstLabel:
+          if ( labelNumber == 0 )
+            thisLabelWidth += yAxisSuffixWidth;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::LastLabel:
+          if ( !hasMoreLabels )
+            thisLabelWidth += yAxisSuffixWidth;
+          break;
+
+        case Qgis::PlotAxisSuffixPlacement::FirstAndLastLabels:
+          if ( labelNumber == 0 || !hasMoreLabels )
+            thisLabelWidth += yAxisSuffixWidth;
+          break;
+      }
+    }
+    maxYAxisLabelWidth = std::max( maxYAxisLabelWidth, thisLabelWidth );
+    if ( !hasMoreLabels )
+      break;
   }
 
-  const double leftTextSize = maxYAxisLabelWidth + context.convertToPainterUnits( 1, QgsUnitTypes::RenderMillimeters );
+  const double leftTextSize = maxYAxisLabelWidth + context.convertToPainterUnits( 1, Qgis::RenderUnit::Millimeters );
   const double rightTextSize = 0;
-  const double bottomTextSize = maxXAxisLabelHeight + context.convertToPainterUnits( 0.5, QgsUnitTypes::RenderMillimeters );
+  const double bottomTextSize = maxXAxisLabelHeight + context.convertToPainterUnits( 0.5, Qgis::RenderUnit::Millimeters );
   const double topTextSize = 0;
 
-  const double leftMargin = context.convertToPainterUnits( mMargins.left(), QgsUnitTypes::RenderMillimeters ) + leftTextSize;
-  const double rightMargin = context.convertToPainterUnits( mMargins.right(), QgsUnitTypes::RenderMillimeters ) + rightTextSize;
-  const double topMargin = context.convertToPainterUnits( mMargins.top(), QgsUnitTypes::RenderMillimeters ) + topTextSize;
-  const double bottomMargin = context.convertToPainterUnits( mMargins.bottom(), QgsUnitTypes::RenderMillimeters ) + bottomTextSize;
+  const double leftMargin = context.convertToPainterUnits( mMargins.left(), Qgis::RenderUnit::Millimeters ) + leftTextSize;
+  const double rightMargin = context.convertToPainterUnits( mMargins.right(), Qgis::RenderUnit::Millimeters ) + rightTextSize;
+  const double topMargin = context.convertToPainterUnits( mMargins.top(), Qgis::RenderUnit::Millimeters ) + topTextSize;
+  const double bottomMargin = context.convertToPainterUnits( mMargins.bottom(), Qgis::RenderUnit::Millimeters ) + bottomTextSize;
 
   return QRectF( leftMargin, topMargin, mSize.width() - rightMargin - leftMargin, mSize.height() - bottomMargin - topMargin );
 }
 
 void Qgs2DPlot::calculateOptimisedIntervals( QgsRenderContext &context )
 {
+  if ( !mSize.isValid() )
+    return;
+
   // aim for about 40% coverage of label text to available space
   constexpr double IDEAL_WIDTH = 0.4;
   constexpr double TOLERANCE = 0.04;
   constexpr int MAX_LABELS = 1000;
 
-  const double leftMargin = context.convertToPainterUnits( mMargins.left(), QgsUnitTypes::RenderMillimeters );
-  const double rightMargin = context.convertToPainterUnits( mMargins.right(), QgsUnitTypes::RenderMillimeters );
-  const double topMargin = context.convertToPainterUnits( mMargins.top(), QgsUnitTypes::RenderMillimeters );
-  const double bottomMargin = context.convertToPainterUnits( mMargins.bottom(), QgsUnitTypes::RenderMillimeters );
+  const double leftMargin = context.convertToPainterUnits( mMargins.left(), Qgis::RenderUnit::Millimeters );
+  const double rightMargin = context.convertToPainterUnits( mMargins.right(), Qgis::RenderUnit::Millimeters );
+  const double topMargin = context.convertToPainterUnits( mMargins.top(), Qgis::RenderUnit::Millimeters );
+  const double bottomMargin = context.convertToPainterUnits( mMargins.bottom(), Qgis::RenderUnit::Millimeters );
 
   const double availableWidth = mSize.width() - leftMargin - rightMargin;
   const double availableHeight = mSize.height() - topMargin - bottomMargin;
@@ -529,11 +709,14 @@ void Qgs2DPlot::calculateOptimisedIntervals( QgsRenderContext &context )
     double labelIntervalX = mXAxis.labelInterval();
     double majorIntervalX = mXAxis.gridIntervalMajor();
     double minorIntervalX = mXAxis.gridIntervalMinor();
-    refineIntervalForAxis( mMinX, mMaxX, [ = ]( double position ) -> double
+    const QString suffixX = mXAxis.labelSuffix();
+    const double suffixWidth = !suffixX.isEmpty() ? QgsTextRenderer::textWidth( context,  mXAxis.textFormat(), { suffixX } ) : 0;
+    refineIntervalForAxis( mMinX, mMaxX, [this, &context, suffixWidth, &numericContext]( double position ) -> double
     {
       const QString text = mXAxis.numericFormat()->formatDouble( position, numericContext );
-      return QgsTextRenderer::textWidth( context,  mXAxis.textFormat(), { text } );
-
+      // this isn't accurate, as we're always considering the suffix to be present... but it's too tricky to actually consider
+      // the suffix placement!
+      return QgsTextRenderer::textWidth( context,  mXAxis.textFormat(), { text } ) + suffixWidth;
     }, availableWidth,
     IDEAL_WIDTH, TOLERANCE, labelIntervalX, majorIntervalX, minorIntervalX );
     mXAxis.setLabelInterval( labelIntervalX );
@@ -545,10 +728,13 @@ void Qgs2DPlot::calculateOptimisedIntervals( QgsRenderContext &context )
     double labelIntervalY = mYAxis.labelInterval();
     double majorIntervalY = mYAxis.gridIntervalMajor();
     double minorIntervalY = mYAxis.gridIntervalMinor();
-    refineIntervalForAxis( mMinY, mMaxY, [ = ]( double position ) -> double
+    const QString suffixY = mYAxis.labelSuffix();
+    refineIntervalForAxis( mMinY, mMaxY, [this, &context, suffixY, &numericContext]( double position ) -> double
     {
       const QString text = mYAxis.numericFormat()->formatDouble( position, numericContext );
-      return QgsTextRenderer::textHeight( context, mYAxis.textFormat(), { text } );
+      // this isn't accurate, as we're always considering the suffix to be present... but it's too tricky to actually consider
+      // the suffix placement!
+      return QgsTextRenderer::textHeight( context, mYAxis.textFormat(), { text + suffixY } );
     }, availableHeight,
     IDEAL_WIDTH, TOLERANCE, labelIntervalY, majorIntervalY, minorIntervalY );
     mYAxis.setLabelInterval( labelIntervalY );
@@ -586,3 +772,38 @@ void Qgs2DPlot::setMargins( const QgsMargins &margins )
 {
   mMargins = margins;
 }
+
+//
+// QgsPlotDefaultSettings
+//
+
+QgsNumericFormat *QgsPlotDefaultSettings::axisLabelNumericFormat()
+{
+  return new QgsBasicNumericFormat();
+}
+
+QgsLineSymbol *QgsPlotDefaultSettings::axisGridMajorSymbol()
+{
+  std::unique_ptr< QgsSimpleLineSymbolLayer > gridMajor = std::make_unique< QgsSimpleLineSymbolLayer >( QColor( 20, 20, 20, 150 ), 0.1 );
+  gridMajor->setPenCapStyle( Qt::FlatCap );
+  return new QgsLineSymbol( QgsSymbolLayerList( { gridMajor.release() } ) );
+}
+
+QgsLineSymbol *QgsPlotDefaultSettings::axisGridMinorSymbol()
+{
+  std::unique_ptr< QgsSimpleLineSymbolLayer > gridMinor = std::make_unique< QgsSimpleLineSymbolLayer >( QColor( 20, 20, 20, 50 ), 0.1 );
+  gridMinor->setPenCapStyle( Qt::FlatCap );
+  return new QgsLineSymbol( QgsSymbolLayerList( { gridMinor.release() } ) );
+}
+
+QgsFillSymbol *QgsPlotDefaultSettings::chartBackgroundSymbol()
+{
+  std::unique_ptr< QgsSimpleFillSymbolLayer > chartFill = std::make_unique< QgsSimpleFillSymbolLayer >( QColor( 255, 255, 255 ) );
+  return new QgsFillSymbol( QgsSymbolLayerList( { chartFill.release() } ) );
+}
+
+QgsFillSymbol *QgsPlotDefaultSettings::chartBorderSymbol()
+{
+  std::unique_ptr< QgsSimpleLineSymbolLayer > chartBorder = std::make_unique< QgsSimpleLineSymbolLayer >( QColor( 20, 20, 20 ), 0.1 );
+  return new QgsFillSymbol( QgsSymbolLayerList( { chartBorder.release() } ) );
+}
