@@ -20,6 +20,7 @@
 #include "qgslogger.h"
 #include "qgsblockingnetworkrequest.h"
 #include "qgsnetworkaccessmanager.h"
+#include "qgssetrequestinitiator_p.h"
 
 #include "lazperf/readers.hpp"
 
@@ -167,14 +168,17 @@ void QgsLazInfo::parseLazAttributes()
   mAttributes.push_back( QgsPointCloudAttribute( "ScanDirectionFlag", QgsPointCloudAttribute::Char ) );
   mAttributes.push_back( QgsPointCloudAttribute( "EdgeOfFlightLine", QgsPointCloudAttribute::Char ) );
   mAttributes.push_back( QgsPointCloudAttribute( "Classification", QgsPointCloudAttribute::UChar ) );
-  mAttributes.push_back( QgsPointCloudAttribute( "ScanAngleRank", QgsPointCloudAttribute::Short ) );
+  mAttributes.push_back( QgsPointCloudAttribute( "ScanAngleRank", QgsPointCloudAttribute::Float ) );
   mAttributes.push_back( QgsPointCloudAttribute( "UserData", QgsPointCloudAttribute::UChar ) );
   mAttributes.push_back( QgsPointCloudAttribute( "PointSourceId", QgsPointCloudAttribute::UShort ) );
+  mAttributes.push_back( QgsPointCloudAttribute( "Synthetic", QgsPointCloudAttribute::UChar ) );
+  mAttributes.push_back( QgsPointCloudAttribute( "KeyPoint", QgsPointCloudAttribute::UChar ) );
+  mAttributes.push_back( QgsPointCloudAttribute( "Withheld", QgsPointCloudAttribute::UChar ) );
+  mAttributes.push_back( QgsPointCloudAttribute( "Overlap", QgsPointCloudAttribute::UChar ) );
 
   if ( mPointFormat == 6 || mPointFormat == 7 || mPointFormat == 8 || mPointFormat == 9 || mPointFormat == 10 )
   {
     mAttributes.push_back( QgsPointCloudAttribute( "ScannerChannel", QgsPointCloudAttribute::Char ) );
-    mAttributes.push_back( QgsPointCloudAttribute( "ClassificationFlags", QgsPointCloudAttribute::Char ) );
   }
   if ( mPointFormat != 0 && mPointFormat != 2 )
   {
@@ -294,12 +298,6 @@ QgsLazInfo QgsLazInfo::fromUrl( QUrl &url )
 {
   QgsLazInfo lazInfo;
 
-  if ( !supportsRangeQueries( url ) )
-  {
-    lazInfo.mError = QStringLiteral( "The server of submitted URL doesn't support range queries" );
-    return lazInfo;
-  }
-
   // Fetch header data
   {
     QNetworkRequest nr( url );
@@ -312,11 +310,20 @@ QgsLazInfo QgsLazInfo::fromUrl( QUrl &url )
     if ( errCode != QgsBlockingNetworkRequest::NoError )
     {
       QgsDebugError( QStringLiteral( "Request failed: " ) + url.toString() );
-      lazInfo.mError = QStringLiteral( "Range query 0-374 to \"%1\" failed: \"%2\"" ).arg( url.toString() ).arg( req.errorMessage() );
+
+      if ( req.reply().attribute( QNetworkRequest::HttpStatusCodeAttribute ).toInt() == 200 )
+      {
+        lazInfo.mError = req.errorMessage();
+      }
+      else
+      {
+        lazInfo.mError = QStringLiteral( "Range query 0-374 to \"%1\" failed: \"%2\"" ).arg( url.toString() ).arg( req.errorMessage() );
+      }
       return lazInfo;
     }
 
     const QgsNetworkReplyContent reply = req.reply();
+
     QByteArray lazHeaderData = reply.content();
 
     lazInfo.parseRawHeader( lazHeaderData.data(), lazHeaderData.size() );
@@ -348,19 +355,3 @@ QgsLazInfo QgsLazInfo::fromUrl( QUrl &url )
 
   return lazInfo;
 }
-
-bool QgsLazInfo::supportsRangeQueries( QUrl &url )
-{
-  QNetworkRequest nr( url );
-  QgsSetRequestInitiatorClass( nr, QStringLiteral( "QgsLazInfo" ) );
-  nr.setAttribute( QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::AlwaysNetwork );
-  nr.setAttribute( QNetworkRequest::CacheSaveControlAttribute, false );
-  nr.setRawHeader( "Range", "bytes=0-0" );
-  QgsBlockingNetworkRequest req;
-  // ignore the reply's status, we only care if accept-ranges is in the headers
-  req.head( nr );
-  QgsNetworkReplyContent reply = req.reply();
-
-  const QString acceptRangesHeader = reply.rawHeader( QStringLiteral( "Accept-Ranges" ).toLocal8Bit() );
-  return acceptRangesHeader.compare( QStringLiteral( "bytes" ), Qt::CaseSensitivity::CaseInsensitive ) == 0;
-}
