@@ -21,6 +21,12 @@
 
 QgsPointCloudRequest::QgsPointCloudRequest() = default;
 
+bool QgsPointCloudRequest::operator==( const QgsPointCloudRequest &other ) const
+{
+  return mFilterRect == other.filterRect() &&
+         mAttributes.toFields() == other.attributes().toFields();
+}
+
 QgsPointCloudAttributeCollection QgsPointCloudRequest::attributes() const
 {
   return mAttributes;
@@ -30,3 +36,8 @@ void QgsPointCloudRequest::setAttributes( const QgsPointCloudAttributeCollection
 {
   mAttributes = attributes;
 }
+
+uint qHash( const QgsPointCloudRequest &request )
+{
+  return qHash( request.filterRect() ) ^ qHash( request.attributes().toFields() );
+}
