@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsprocessingmodelalgorithm.h"
+#include "moc_qgsprocessingmodelalgorithm.cpp"
 #include "qgsprocessingregistry.h"
 #include "qgsprocessingfeedback.h"
 #include "qgsprocessingutils.h"
@@ -28,6 +29,7 @@
 #include "qgsprocessingparametertype.h"
 #include "qgsexpressioncontextutils.h"
 #include "qgsprocessingmodelgroupbox.h"
+#include "qgsmessagelog.h"
 
 #include <QFile>
 #include <QTextStream>
@@ -44,6 +46,23 @@ void QgsProcessingModelAlgorithm::initAlgorithm( const QVariantMap & )
 {
 }
 
+Qgis::ProcessingAlgorithmFlags QgsProcessingModelAlgorithm::flags() const
+{
+  Qgis::ProcessingAlgorithmFlags res = QgsProcessingAlgorithm::flags();
+
+  // don't force algorithm attachment here, that's potentially too expensive
+  QMap< QString, QgsProcessingModelChildAlgorithm >::const_iterator childIt = mChildAlgorithms.constBegin();
+  for ( ; childIt != mChildAlgorithms.constEnd(); ++childIt )
+  {
+    if ( childIt->algorithm() && childIt->algorithm()->flags().testFlag( Qgis::ProcessingAlgorithmFlag::SecurityRisk ) )
+    {
+      // security risk flag propagates from child algorithms to model
+      res |= Qgis::ProcessingAlgorithmFlag::SecurityRisk;
+    }
+  }
+  return res;
+}
+
 QString QgsProcessingModelAlgorithm::name() const
 {
   return mModelName;
@@ -202,7 +221,7 @@ QVariantMap QgsProcessingModelAlgorithm::parametersForChildAlgorithm( const QgsP
 
           if ( foundParam )
           {
-            if ( value.userType() == QMetaType::type( "QgsProcessingOutputLayerDefinition" ) )
+            if ( value.userType() == qMetaTypeId<QgsProcessingOutputLayerDefinition>() )
             {
               // make sure layer output name is correctly set
               QgsProcessingOutputLayerDefinition fromVar = qvariant_cast<QgsProcessingOutputLayerDefinition>( value );
@@ -235,7 +254,7 @@ QVariantMap QgsProcessingModelAlgorithm::parametersForChildAlgorithm( const QgsP
 
         // check whether it's optional, and if so - is it required?
         bool required = true;
-        if ( destParam->flags() & QgsProcessingParameterDefinition::FlagOptional )
+        if ( destParam->flags() & Qgis::ProcessingParameterFlag::Optional )
         {
           required = childOutputIsRequired( child.childId(), destParam->name() );
         }
@@ -299,9 +318,11 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
   QSet< QString > toExecute;
   QMap< QString, QgsProcessingModelChildAlgorithm >::const_iterator childIt = mChildAlgorithms.constBegin();
   QSet< QString > broken;
+  const QSet<QString> childSubset = context.modelInitialRunConfig() ? context.modelInitialRunConfig()->childAlgorithmSubset() : QSet<QString>();
+  const bool useSubsetOfChildren = !childSubset.empty();
   for ( ; childIt != mChildAlgorithms.constEnd(); ++childIt )
   {
-    if ( childIt->isActive() )
+    if ( childIt->isActive() && ( !useSubsetOfChildren || childSubset.contains( childIt->childId() ) ) )
     {
       if ( childIt->algorithm() )
         toExecute.insert( childIt->childId() );
@@ -319,13 +340,31 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
   QgsProcessingMultiStepFeedback modelFeedback( toExecute.count(), feedback );
   QgsExpressionContext baseContext = createExpressionContext( parameters, context );
 
-  QVariantMap childResults;
-  QVariantMap childInputs;
+  QVariantMap &childInputs = context.modelResult().rawChildInputs();
+  QVariantMap &childResults = context.modelResult().rawChildOutputs();
+  QSet< QString > &executed = context.modelResult().executedChildIds();
+
+  // start with initial configuration from the context's model configuration (allowing us to
+  // resume execution using a previous state)
+  if ( QgsProcessingModelInitialRunConfig *config = context.modelInitialRunConfig() )
+  {
+    childInputs = config->initialChildInputs();
+    childResults = config->initialChildOutputs();
+    executed = config->previouslyExecutedChildAlgorithms();
+    // discard the model config, this should only be used when running the top level model
+    context.setModelInitialRunConfig( nullptr );
+  }
+  if ( useSubsetOfChildren )
+  {
+    executed.subtract( childSubset );
+  }
 
   QVariantMap finalResults;
-  QSet< QString > executed;
+
   bool executedAlg = true;
-  while ( executedAlg && executed.count() < toExecute.count() )
+  int previousHtmlLogLength = feedback->htmlLog().length();
+  int countExecuted = 0;
+  while ( executedAlg && countExecuted < toExecute.count() )
   {
     executedAlg = false;
     for ( const QString &childId : std::as_const( toExecute ) )
@@ -334,7 +373,9 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
         break;
 
       if ( executed.contains( childId ) )
+      {
         continue;
+      }
 
       bool canExecute = true;
       const QSet< QString > dependencies = dependsOnChildAlgorithms( childId );
@@ -348,7 +389,9 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
       }
 
       if ( !canExecute )
+      {
         continue;
+      }
 
       executedAlg = true;
 
@@ -358,16 +401,16 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
       bool skipGenericLogging = true;
       switch ( context.logLevel() )
       {
-        case QgsProcessingContext::DefaultLevel:
+        case Qgis::ProcessingLogLevel::DefaultLevel:
           // at default log level we skip all the generic logs about prepare steps, step inputs and outputs
           skipGenericLogging = true;
           break;
-        case QgsProcessingContext::Verbose:
+        case Qgis::ProcessingLogLevel::Verbose:
           // at verbose log level we include all the generic logs about prepare steps, step inputs and outputs
           // UNLESS the algorithm specifically tells to skip these (eg raise warning steps and other special cases)
-          skipGenericLogging = childAlg->flags() & QgsProcessingAlgorithm::FlagSkipGenericModelLogging;
+          skipGenericLogging = childAlg->flags() & Qgis::ProcessingAlgorithmFlag::SkipGenericModelLogging;
           break;
-        case QgsProcessingContext::ModelDebug:
+        case Qgis::ProcessingLogLevel::ModelDebug:
           // at model debug log level we'll show all the generic logs for step preparation, inputs and outputs
           // for every child algorithm
           skipGenericLogging = false;
@@ -390,7 +433,12 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
       if ( feedback && !skipGenericLogging )
         feedback->setProgressText( QObject::tr( "Running %1 [%2/%3]" ).arg( child.description() ).arg( executed.count() + 1 ).arg( toExecute.count() ) );
 
-      childInputs.insert( childId, QgsProcessingUtils::removePointerValuesFromMap( childParams ) );
+      QgsProcessingModelChildAlgorithmResult childResult;
+
+      const QVariantMap thisChildParams = QgsProcessingUtils::removePointerValuesFromMap( childParams );
+      childInputs.insert( childId, thisChildParams );
+      childResult.setInputs( thisChildParams );
+
       QStringList params;
       for ( auto childParamIt = childParams.constBegin(); childParamIt != childParams.constEnd(); ++childParamIt )
       {
@@ -424,21 +472,26 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
       else
       {
         context.pushToThread( qApp->thread() );
+// silence false positive leak warning
+#ifndef __clang_analyzer__
         QMetaObject::invokeMethod( qApp, prepareOnMainThread, Qt::BlockingQueuedConnection );
+#endif
       }
 
       Q_ASSERT_X( QThread::currentThread() == context.thread(), "QgsProcessingModelAlgorithm::processAlgorithm", "context was not transferred back to model thread" );
 
       if ( !ok )
       {
-        const QString error = ( childAlg->flags() & QgsProcessingAlgorithm::FlagCustomException ) ? QString() : QObject::tr( "Error encountered while running %1" ).arg( child.description() );
+        const QString error = ( childAlg->flags() & Qgis::ProcessingAlgorithmFlag::CustomException ) ? QString() : QObject::tr( "Error encountered while running %1" ).arg( child.description() );
         throw QgsProcessingException( error );
       }
 
       QVariantMap results;
+
+      bool runResult = false;
       try
       {
-        if ( ( childAlg->flags() & QgsProcessingAlgorithm::FlagNoThreading ) && ( QThread::currentThread() != qApp->thread() ) )
+        if ( ( childAlg->flags() & Qgis::ProcessingAlgorithmFlag::NoThreading ) && ( QThread::currentThread() != qApp->thread() ) )
         {
           // child algorithm run step must be called on main thread
           auto runOnMainThread = [modelThread, &context, &modelFeedback, &results, &childAlg, &childParams]
@@ -452,37 +505,45 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
             feedback->pushWarning( QObject::tr( "Algorithm “%1” cannot be run in a background thread, switching to main thread for this step" ).arg( childAlg->displayName() ) );
 
           context.pushToThread( qApp->thread() );
+// silence false positive leak warning
+#ifndef __clang_analyzer__
           QMetaObject::invokeMethod( qApp, runOnMainThread, Qt::BlockingQueuedConnection );
+#endif
         }
         else
         {
           // safe to run on model thread
           results = childAlg->runPrepared( childParams, context, &modelFeedback );
         }
+        runResult = true;
+        childResult.setExecutionStatus( Qgis::ProcessingModelChildAlgorithmExecutionStatus::Success );
       }
       catch ( QgsProcessingException &e )
       {
-        const QString error = ( childAlg->flags() & QgsProcessingAlgorithm::FlagCustomException ) ? e.what() : QObject::tr( "Error encountered while running %1: %2" ).arg( child.description(), e.what() );
-        throw QgsProcessingException( error );
+        error = ( childAlg->flags() & Qgis::ProcessingAlgorithmFlag::CustomException ) ? e.what() : QObject::tr( "Error encountered while running %1: %2" ).arg( child.description(), e.what() );
+        childResult.setExecutionStatus( Qgis::ProcessingModelChildAlgorithmExecutionStatus::Failed );
       }
 
       Q_ASSERT_X( QThread::currentThread() == context.thread(), "QgsProcessingModelAlgorithm::processAlgorithm", "context was not transferred back to model thread" );
 
       QVariantMap ppRes;
-      auto postProcessOnMainThread = [modelThread, &ppRes, &childAlg, &context, &modelFeedback]
+      auto postProcessOnMainThread = [modelThread, &ppRes, &childAlg, &context, &modelFeedback, runResult]
       {
         Q_ASSERT_X( QThread::currentThread() == qApp->thread(), "QgsProcessingModelAlgorithm::processAlgorithm", "childAlg->postProcess() must be run on the main thread" );
-        ppRes = childAlg->postProcess( context, &modelFeedback );
+        ppRes = childAlg->postProcess( context, &modelFeedback, runResult );
         context.pushToThread( modelThread );
       };
 
       // Make sure we only run postProcess steps on the main thread!
       if ( modelThread == qApp->thread() )
-        ppRes = childAlg->postProcess( context, &modelFeedback );
+        ppRes = childAlg->postProcess( context, &modelFeedback, runResult );
       else
       {
         context.pushToThread( qApp->thread() );
+// silence false positive leak warning
+#ifndef __clang_analyzer__
         QMetaObject::invokeMethod( qApp, postProcessOnMainThread, Qt::BlockingQueuedConnection );
+#endif
       }
 
       Q_ASSERT_X( QThread::currentThread() == context.thread(), "QgsProcessingModelAlgorithm::processAlgorithm", "context was not transferred back to model thread" );
@@ -490,127 +551,154 @@ QVariantMap QgsProcessingModelAlgorithm::processAlgorithm( const QVariantMap &pa
       if ( !ppRes.isEmpty() )
         results = ppRes;
 
-      if ( feedback && !skipGenericLogging )
-      {
-        const QVariantMap displayOutputs = QgsProcessingUtils::removePointerValuesFromMap( results );
-        QStringList formattedOutputs;
-        for ( auto displayOutputIt = displayOutputs.constBegin(); displayOutputIt != displayOutputs.constEnd(); ++displayOutputIt )
-        {
-          formattedOutputs << QStringLiteral( "%1: %2" ).arg( displayOutputIt.key(),
-                           QgsProcessingUtils::variantToPythonLiteral( displayOutputIt.value() ) );;
-        }
-        feedback->pushInfo( QObject::tr( "Results:" ) );
-        feedback->pushCommandInfo( QStringLiteral( "{ %1 }" ).arg( formattedOutputs.join( QLatin1String( ", " ) ) ) );
-      }
-
       childResults.insert( childId, results );
+      childResult.setOutputs( results );
 
-      // look through child alg's outputs to determine whether any of these should be copied
-      // to the final model outputs
-      const QMap<QString, QgsProcessingModelOutput> outputs = child.modelOutputs();
-      for ( auto outputIt = outputs.constBegin(); outputIt != outputs.constEnd(); ++outputIt )
+      if ( runResult )
       {
-        const int outputSortKey = mOutputOrder.indexOf( QStringLiteral( "%1:%2" ).arg( childId, outputIt->childOutputName() ) );
-        switch ( mInternalVersion )
+        if ( feedback && !skipGenericLogging )
         {
-          case QgsProcessingModelAlgorithm::InternalVersion::Version1:
-            finalResults.insert( childId + ':' + outputIt->name(), results.value( outputIt->childOutputName() ) );
-            break;
-          case QgsProcessingModelAlgorithm::InternalVersion::Version2:
-            if ( const QgsProcessingParameterDefinition *modelParam = modelParameterFromChildIdAndOutputName( child.childId(), outputIt.key() ) )
-            {
-              finalResults.insert( modelParam->name(), results.value( outputIt->childOutputName() ) );
-            }
-            break;
-        }
-
-        const QString outputLayer = results.value( outputIt->childOutputName() ).toString();
-        if ( !outputLayer.isEmpty() && context.willLoadLayerOnCompletion( outputLayer ) )
-        {
-          QgsProcessingContext::LayerDetails &details = context.layerToLoadOnCompletionDetails( outputLayer );
-          details.groupName = mOutputGroup;
-          if ( outputSortKey > 0 )
-            details.layerSortKey = outputSortKey;
-        }
-      }
-
-      executed.insert( childId );
-
-      std::function< void( const QString &, const QString & )> pruneAlgorithmBranchRecursive;
-      pruneAlgorithmBranchRecursive = [&]( const QString & id, const QString &branch = QString() )
-      {
-        const QSet<QString> toPrune = dependentChildAlgorithms( id, branch );
-        for ( const QString &targetId : toPrune )
-        {
-          if ( executed.contains( targetId ) )
-            continue;
-
-          executed.insert( targetId );
-          pruneAlgorithmBranchRecursive( targetId, branch );
-        }
-      };
-
-      // prune remaining algorithms if they are dependent on a branch from this child which didn't eventuate
-      const QgsProcessingOutputDefinitions outputDefs = childAlg->outputDefinitions();
-      for ( const QgsProcessingOutputDefinition *outputDef : outputDefs )
-      {
-        if ( outputDef->type() == QgsProcessingOutputConditionalBranch::typeName() && !results.value( outputDef->name() ).toBool() )
-        {
-          pruneAlgorithmBranchRecursive( childId, outputDef->name() );
-        }
-      }
-
-      if ( childAlg->flags() & QgsProcessingAlgorithm::FlagPruneModelBranchesBasedOnAlgorithmResults )
-      {
-        // check if any dependent algorithms should be canceled based on the outputs of this algorithm run
-        // first find all direct dependencies of this algorithm by looking through all remaining child algorithms
-        for ( const QString &candidateId : std::as_const( toExecute ) )
-        {
-          if ( executed.contains( candidateId ) )
-            continue;
-
-          // a pending algorithm was found..., check it's parameter sources to see if it links to any of the current
-          // algorithm's outputs
-          const QgsProcessingModelChildAlgorithm &candidate = mChildAlgorithms[ candidateId ];
-          const QMap<QString, QgsProcessingModelChildParameterSources> candidateParams = candidate.parameterSources();
-          QMap<QString, QgsProcessingModelChildParameterSources>::const_iterator paramIt = candidateParams.constBegin();
-          bool pruned = false;
-          for ( ; paramIt != candidateParams.constEnd(); ++paramIt )
+          const QVariantMap displayOutputs = QgsProcessingUtils::removePointerValuesFromMap( results );
+          QStringList formattedOutputs;
+          for ( auto displayOutputIt = displayOutputs.constBegin(); displayOutputIt != displayOutputs.constEnd(); ++displayOutputIt )
           {
-            for ( const QgsProcessingModelChildParameterSource &source : paramIt.value() )
-            {
-              if ( source.source() == Qgis::ProcessingModelChildParameterSource::ChildOutput && source.outputChildId() == childId )
+            formattedOutputs << QStringLiteral( "%1: %2" ).arg( displayOutputIt.key(),
+                             QgsProcessingUtils::variantToPythonLiteral( displayOutputIt.value() ) );;
+          }
+          feedback->pushInfo( QObject::tr( "Results:" ) );
+          feedback->pushCommandInfo( QStringLiteral( "{ %1 }" ).arg( formattedOutputs.join( QLatin1String( ", " ) ) ) );
+        }
+
+        // look through child alg's outputs to determine whether any of these should be copied
+        // to the final model outputs
+        const QMap<QString, QgsProcessingModelOutput> outputs = child.modelOutputs();
+        for ( auto outputIt = outputs.constBegin(); outputIt != outputs.constEnd(); ++outputIt )
+        {
+          const int outputSortKey = mOutputOrder.indexOf( QStringLiteral( "%1:%2" ).arg( childId, outputIt->childOutputName() ) );
+          switch ( mInternalVersion )
+          {
+            case QgsProcessingModelAlgorithm::InternalVersion::Version1:
+              finalResults.insert( childId + ':' + outputIt->name(), results.value( outputIt->childOutputName() ) );
+              break;
+            case QgsProcessingModelAlgorithm::InternalVersion::Version2:
+              if ( const QgsProcessingParameterDefinition *modelParam = modelParameterFromChildIdAndOutputName( child.childId(), outputIt.key() ) )
               {
-                // ok, this one is dependent on the current alg. Did we get a value for it?
-                if ( !results.contains( source.outputName() ) )
-                {
-                  // oh no, nothing returned for this parameter. Gotta trim the branch back!
-                  pruned = true;
-                  // skip the dependent alg..
-                  executed.insert( candidateId );
-                  //... and everything which depends on it
-                  pruneAlgorithmBranchRecursive( candidateId, QString() );
-                  break;
-                }
+                finalResults.insert( modelParam->name(), results.value( outputIt->childOutputName() ) );
               }
-            }
-            if ( pruned )
               break;
           }
+
+          const QString outputLayer = results.value( outputIt->childOutputName() ).toString();
+          if ( !outputLayer.isEmpty() && context.willLoadLayerOnCompletion( outputLayer ) )
+          {
+            QgsProcessingContext::LayerDetails &details = context.layerToLoadOnCompletionDetails( outputLayer );
+            details.groupName = mOutputGroup;
+            if ( outputSortKey > 0 )
+              details.layerSortKey = outputSortKey;
+          }
+        }
+
+        executed.insert( childId );
+
+        std::function< void( const QString &, const QString & )> pruneAlgorithmBranchRecursive;
+        pruneAlgorithmBranchRecursive = [&]( const QString & id, const QString &branch = QString() )
+        {
+          const QSet<QString> toPrune = dependentChildAlgorithms( id, branch );
+          for ( const QString &targetId : toPrune )
+          {
+            if ( executed.contains( targetId ) )
+              continue;
+
+            executed.insert( targetId );
+            pruneAlgorithmBranchRecursive( targetId, branch );
+          }
+        };
+
+        // prune remaining algorithms if they are dependent on a branch from this child which didn't eventuate
+        const QgsProcessingOutputDefinitions outputDefs = childAlg->outputDefinitions();
+        for ( const QgsProcessingOutputDefinition *outputDef : outputDefs )
+        {
+          if ( outputDef->type() == QgsProcessingOutputConditionalBranch::typeName() && !results.value( outputDef->name() ).toBool() )
+          {
+            pruneAlgorithmBranchRecursive( childId, outputDef->name() );
+          }
+        }
+
+        if ( childAlg->flags() & Qgis::ProcessingAlgorithmFlag::PruneModelBranchesBasedOnAlgorithmResults )
+        {
+          // check if any dependent algorithms should be canceled based on the outputs of this algorithm run
+          // first find all direct dependencies of this algorithm by looking through all remaining child algorithms
+          for ( const QString &candidateId : std::as_const( toExecute ) )
+          {
+            if ( executed.contains( candidateId ) )
+              continue;
+
+            // a pending algorithm was found..., check it's parameter sources to see if it links to any of the current
+            // algorithm's outputs
+            const QgsProcessingModelChildAlgorithm &candidate = mChildAlgorithms[ candidateId ];
+            const QMap<QString, QgsProcessingModelChildParameterSources> candidateParams = candidate.parameterSources();
+            QMap<QString, QgsProcessingModelChildParameterSources>::const_iterator paramIt = candidateParams.constBegin();
+            bool pruned = false;
+            for ( ; paramIt != candidateParams.constEnd(); ++paramIt )
+            {
+              for ( const QgsProcessingModelChildParameterSource &source : paramIt.value() )
+              {
+                if ( source.source() == Qgis::ProcessingModelChildParameterSource::ChildOutput && source.outputChildId() == childId )
+                {
+                  // ok, this one is dependent on the current alg. Did we get a value for it?
+                  if ( !results.contains( source.outputName() ) )
+                  {
+                    // oh no, nothing returned for this parameter. Gotta trim the branch back!
+                    pruned = true;
+                    // skip the dependent alg..
+                    executed.insert( candidateId );
+                    //... and everything which depends on it
+                    pruneAlgorithmBranchRecursive( candidateId, QString() );
+                    break;
+                  }
+                }
+              }
+              if ( pruned )
+                break;
+            }
+          }
+        }
+
+        childAlg.reset( nullptr );
+        countExecuted++;
+        modelFeedback.setCurrentStep( countExecuted );
+        if ( feedback && !skipGenericLogging )
+        {
+          feedback->pushInfo( QObject::tr( "OK. Execution took %1 s (%n output(s)).", nullptr, results.count() ).arg( childTime.elapsed() / 1000.0 ) );
         }
       }
 
-      childAlg.reset( nullptr );
-      modelFeedback.setCurrentStep( executed.count() );
-      if ( feedback && !skipGenericLogging )
-        feedback->pushInfo( QObject::tr( "OK. Execution took %1 s (%n output(s)).", nullptr, results.count() ).arg( childTime.elapsed() / 1000.0 ) );
+      // trim out just the portion of the overall log which relates to this child
+      const QString thisAlgorithmHtmlLog = feedback->htmlLog().mid( previousHtmlLogLength );
+      previousHtmlLogLength = feedback->htmlLog().length();
+
+      if ( !runResult )
+      {
+        const QString formattedException = QStringLiteral( "<span style=\"color:red\">%1</span><br/>" ).arg( error.toHtmlEscaped() ).replace( '\n', QLatin1String( "<br>" ) );
+        const QString formattedRunTime = QStringLiteral( "<span style=\"color:red\">%1</span><br/>" ).arg( QObject::tr( "Failed after %1 s." ).arg( childTime.elapsed() / 1000.0 ).toHtmlEscaped() ).replace( '\n', QLatin1String( "<br>" ) );
+
+        childResult.setHtmlLog( thisAlgorithmHtmlLog + formattedException + formattedRunTime );
+        context.modelResult().childResults().insert( childId, childResult );
+
+        throw QgsProcessingException( error );
+      }
+      else
+      {
+        childResult.setHtmlLog( thisAlgorithmHtmlLog );
+        context.modelResult().childResults().insert( childId, childResult );
+      }
     }
 
     if ( feedback && feedback->isCanceled() )
       break;
   }
   if ( feedback )
-    feedback->pushDebugInfo( QObject::tr( "Model processed OK. Executed %n algorithm(s) total in %1 s.", nullptr, executed.count() ).arg( totalTime.elapsed() / 1000.0 ) );
+    feedback->pushDebugInfo( QObject::tr( "Model processed OK. Executed %n algorithm(s) total in %1 s.", nullptr, countExecuted ).arg( static_cast< double >( totalTime.elapsed() ) / 1000.0 ) );
 
   mResults = finalResults;
   mResults.insert( QStringLiteral( "CHILD_RESULTS" ), childResults );
@@ -683,7 +771,7 @@ QStringList QgsProcessingModelAlgorithm::asPythonCode( const QgsProcessing::Pyth
   QStringList importLines; // not a set - we need regular ordering
   switch ( outputType )
   {
-    case QgsProcessing::PythonQgsProcessingAlgorithmSubclass:
+    case QgsProcessing::PythonOutputType::PythonQgsProcessingAlgorithmSubclass:
     {
       // add specific parameter type imports
       const auto params = parameterDefinitions();
@@ -695,7 +783,7 @@ QStringList QgsProcessingModelAlgorithm::asPythonCode( const QgsProcessing::Pyth
       bool hasAdvancedParams = false;
       for ( const QgsProcessingParameterDefinition *def : params )
       {
-        if ( def->flags() & QgsProcessingParameterDefinition::FlagAdvanced )
+        if ( def->flags() & Qgis::ProcessingParameterFlag::Advanced )
           hasAdvancedParams = true;
 
         const QString importString = QgsApplication::processingRegistry()->parameterType( def->type() )->pythonImportString();
@@ -744,7 +832,7 @@ QStringList QgsProcessingModelAlgorithm::asPythonCode( const QgsProcessing::Pyth
             }
           }
 
-          if ( defClone->flags() & QgsProcessingParameterDefinition::FlagAdvanced )
+          if ( defClone->flags() & Qgis::ProcessingParameterFlag::Advanced )
           {
             lines << indent + indent + QStringLiteral( "param = %1" ).arg( defClone->asPythonString() );
             lines << indent + indent + QStringLiteral( "param.setFlags(param.flags() | QgsProcessingParameterDefinition.FlagAdvanced)" );
@@ -869,7 +957,7 @@ QStringList QgsProcessingModelAlgorithm::asPythonCode( const QgsProcessing::Pyth
 
             // check whether it's optional, and if so - is it required?
             bool required = true;
-            if ( destParam->flags() & QgsProcessingParameterDefinition::FlagOptional )
+            if ( destParam->flags() & Qgis::ProcessingParameterFlag::Optional )
             {
               required = childOutputIsRequired( child.childId(), destParam->name() );
             }
@@ -899,7 +987,7 @@ QStringList QgsProcessingModelAlgorithm::asPythonCode( const QgsProcessing::Pyth
 
   switch ( outputType )
   {
-    case QgsProcessing::PythonQgsProcessingAlgorithmSubclass:
+    case QgsProcessing::PythonOutputType::PythonQgsProcessingAlgorithmSubclass:
       lines << currentIndent + QStringLiteral( "return results" );
       lines << QString();
 
@@ -1008,6 +1096,8 @@ QMap<QString, QgsProcessingModelAlgorithm::VariableDefinition> QgsProcessingMode
   // "static"/single value sources
   QgsProcessingModelChildParameterSources sources = availableSourcesForChild( childId, QStringList() << QgsProcessingParameterNumber::typeName()
       << QgsProcessingParameterDistance::typeName()
+      << QgsProcessingParameterArea::typeName()
+      << QgsProcessingParameterVolume::typeName()
       << QgsProcessingParameterDuration::typeName()
       << QgsProcessingParameterScale::typeName()
       << QgsProcessingParameterBoolean::typeName()
@@ -1119,11 +1209,11 @@ QMap<QString, QgsProcessingModelAlgorithm::VariableDefinition> QgsProcessingMode
 
     }
 
-    if ( value.userType() == QMetaType::type( "QgsProcessingOutputLayerDefinition" ) )
+    if ( value.userType() == qMetaTypeId<QgsProcessingOutputLayerDefinition>() )
     {
       QgsProcessingOutputLayerDefinition fromVar = qvariant_cast<QgsProcessingOutputLayerDefinition>( value );
       value = fromVar.sink;
-      if ( value.userType() == QMetaType::type( "QgsProperty" ) && context )
+      if ( value.userType() == qMetaTypeId<QgsProperty>() && context )
       {
         value = value.value< QgsProperty >().valueAsString( context->expressionContext() );
       }
@@ -1183,16 +1273,16 @@ QMap<QString, QgsProcessingModelAlgorithm::VariableDefinition> QgsProcessingMode
     }
 
     QgsFeatureSource *featureSource = nullptr;
-    if ( value.userType() == QMetaType::type( "QgsProcessingFeatureSourceDefinition" ) )
+    if ( value.userType() == qMetaTypeId<QgsProcessingFeatureSourceDefinition>() )
     {
       QgsProcessingFeatureSourceDefinition fromVar = qvariant_cast<QgsProcessingFeatureSourceDefinition>( value );
       value = fromVar.source;
     }
-    else if ( value.userType() == QMetaType::type( "QgsProcessingOutputLayerDefinition" ) )
+    else if ( value.userType() == qMetaTypeId<QgsProcessingOutputLayerDefinition>() )
     {
       QgsProcessingOutputLayerDefinition fromVar = qvariant_cast<QgsProcessingOutputLayerDefinition>( value );
       value = fromVar.sink;
-      if ( context && value.userType() == QMetaType::type( "QgsProperty" ) )
+      if ( context && value.userType() == qMetaTypeId<QgsProperty>() )
       {
         value = value.value< QgsProperty >().valueAsString( context->expressionContext() );
       }
@@ -1248,7 +1338,7 @@ QgsProcessingModelChildParameterSources QgsProcessingModelAlgorithm::availableSo
         if ( def->type() == QgsProcessingParameterField::typeName() )
         {
           const QgsProcessingParameterField *fieldDef = static_cast< const QgsProcessingParameterField * >( def );
-          if ( !( dataTypes.contains( fieldDef->dataType() ) || fieldDef->dataType() == QgsProcessingParameterField::Any ) )
+          if ( !( dataTypes.contains( static_cast< int >( fieldDef->dataType() ) ) || fieldDef->dataType() == Qgis::ProcessingFieldParameterDataType::Any ) )
           {
             continue;
           }
@@ -1263,13 +1353,13 @@ QgsProcessingModelChildParameterSources QgsProcessingModelAlgorithm::availableSo
           const auto constDataTypes = sourceDef->dataTypes();
           for ( int type : constDataTypes )
           {
-            if ( dataTypes.contains( type ) || type == QgsProcessing::TypeMapLayer || type == QgsProcessing::TypeVector || type == QgsProcessing::TypeVectorAnyGeometry )
+            if ( dataTypes.contains( type ) || type == static_cast< int >( Qgis::ProcessingSourceType::MapLayer ) || type == static_cast< int >( Qgis::ProcessingSourceType::Vector ) || type == static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) )
             {
               ok = true;
               break;
             }
           }
-          if ( dataTypes.contains( QgsProcessing::TypeMapLayer ) || dataTypes.contains( QgsProcessing::TypeVector ) || dataTypes.contains( QgsProcessing::TypeVectorAnyGeometry ) )
+          if ( dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::MapLayer ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Vector ) ) || dataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) )
             ok = true;
 
           if ( !ok )
@@ -1529,9 +1619,9 @@ void QgsProcessingModelAlgorithm::updateDestinationParameters()
       std::unique_ptr< QgsProcessingParameterDefinition > param( source->clone() );
       // Even if an output was hidden in a child algorithm, we want to show it here for the final
       // outputs.
-      param->setFlags( param->flags() & ~QgsProcessingParameterDefinition::FlagHidden );
+      param->setFlags( param->flags() & ~ static_cast< int >( Qgis::ProcessingParameterFlag::Hidden ) );
       if ( outputIt->isMandatory() )
-        param->setFlags( param->flags() & ~QgsProcessingParameterDefinition::FlagOptional );
+        param->setFlags( param->flags() & ~static_cast< int >( Qgis::ProcessingParameterFlag::Optional ) );
       if ( mInternalVersion != InternalVersion::Version1 && !outputIt->description().isEmpty() )
       {
         QString friendlyName = uniqueSafeName( outputIt->description() );
@@ -1677,7 +1767,7 @@ bool QgsProcessingModelAlgorithm::loadVariant( const QVariant &model )
   mParameters.clear();
   QVariantMap paramDefMap = map.value( QStringLiteral( "parameterDefinitions" ) ).toMap();
 
-  auto addParam = [ = ]( const QVariant & value )
+  auto addParam = [this]( const QVariant & value )
   {
     std::unique_ptr< QgsProcessingParameterDefinition > param( QgsProcessingParameters::parameterFromVariantMap( value.toMap() ) );
     // we be lenient here - even if we couldn't load a parameter, don't interrupt the model loading
@@ -1736,21 +1826,21 @@ bool QgsProcessingModelAlgorithm::loadVariant( const QVariant &model )
   return true;
 }
 
-bool QgsProcessingModelAlgorithm::vectorOutputIsCompatibleType( const QList<int> &acceptableDataTypes, QgsProcessing::SourceType outputType )
+bool QgsProcessingModelAlgorithm::vectorOutputIsCompatibleType( const QList<int> &acceptableDataTypes, Qgis::ProcessingSourceType outputType )
 {
   // This method is intended to be "permissive" rather than "restrictive".
   // I.e. we only reject outputs which we know can NEVER be acceptable, but
   // if there's doubt then we default to returning true.
   return ( acceptableDataTypes.empty()
-           || acceptableDataTypes.contains( outputType )
-           || outputType == QgsProcessing::TypeMapLayer
-           || outputType == QgsProcessing::TypeVector
-           || outputType == QgsProcessing::TypeVectorAnyGeometry
-           || acceptableDataTypes.contains( QgsProcessing::TypeVector )
-           || acceptableDataTypes.contains( QgsProcessing::TypeMapLayer )
-           || ( acceptableDataTypes.contains( QgsProcessing::TypeVectorAnyGeometry ) && ( outputType == QgsProcessing::TypeVectorPoint ||
-                outputType == QgsProcessing::TypeVectorLine ||
-                outputType == QgsProcessing::TypeVectorPolygon ) ) );
+           || acceptableDataTypes.contains( static_cast< int >( outputType ) )
+           || outputType == Qgis::ProcessingSourceType::MapLayer
+           || outputType == Qgis::ProcessingSourceType::Vector
+           || outputType == Qgis::ProcessingSourceType::VectorAnyGeometry
+           || acceptableDataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::Vector ) )
+           || acceptableDataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::MapLayer ) )
+           || ( acceptableDataTypes.contains( static_cast< int >( Qgis::ProcessingSourceType::VectorAnyGeometry ) ) && ( outputType == Qgis::ProcessingSourceType::VectorPoint ||
+                outputType == Qgis::ProcessingSourceType::VectorLine ||
+                outputType == Qgis::ProcessingSourceType::VectorPolygon ) ) );
 }
 
 void QgsProcessingModelAlgorithm::reattachAlgorithms() const
@@ -1937,10 +2027,10 @@ void QgsProcessingModelAlgorithm::changeParameterName( const QString &oldName, c
 
           case Qgis::ProcessingModelChildParameterSource::StaticValue:
           {
-            if ( valueIt->staticValue().userType() == QMetaType::type( "QgsProperty" ) )
+            if ( valueIt->staticValue().userType() == qMetaTypeId<QgsProperty>() )
             {
               QgsProperty property = valueIt->staticValue().value< QgsProperty >();
-              if ( property.propertyType() == QgsProperty::ExpressionBasedProperty )
+              if ( property.propertyType() == Qgis::PropertyType::Expression )
               {
                 bool updatedExpression = false;
                 QString newExpression;
