@@ -28,7 +28,6 @@
 
 #define SIP_NO_FILE
 
-#include "qgis_core.h"
 #include <QSharedData>
 #include <QVariant>
 #include "qgsexpression.h"
@@ -60,7 +59,7 @@ class QgsPropertyPrivate : public QSharedData
       delete transformer;
     }
 
-    int type = 0;
+    Qgis::PropertyType type = Qgis::PropertyType::Invalid;
 
     //! Stores whether the property is currently active
     bool active = true;
