@@ -19,6 +19,7 @@
 #include <QFileSystemWatcher>
 
 
+#include "qgis.h"
 #include "qgis_sip.h"
 #include "qgis_core.h"
 #include "qgserror.h"
@@ -36,7 +37,6 @@
  *
  * A user profile is all settings and anything that used to be found in .qgis3 in the users home folder.
  *
- * \since QGIS 3.0
  */
 class CORE_EXPORT QgsUserProfileManager : public QObject
 {
@@ -142,6 +142,31 @@ class CORE_EXPORT QgsUserProfileManager : public QObject
      */
     void setDefaultFromActive();
 
+    /**
+     * Returns the name of the most recently closed profile. Empty if it is the first time QGIS is run.
+     * \since QGIS 3.32
+     */
+    QString lastProfileName() const;
+
+    /**
+     * Updates the last closed profile name. Called when QGIS is closed.
+     * \since QGIS 3.32
+     */
+    void updateLastProfileName() SIP_SKIP;
+
+    /**
+     * Returns the user profile selection policy.
+     * \since QGIS 3.32
+     */
+    Qgis::UserProfileSelectionPolicy userProfileSelectionPolicy() const;
+
+    /**
+     * Sets the user profile selection policy.
+     * \param policy The policy to use when selecting a user profile.
+     * \since QGIS 3.32
+     */
+    void setUserProfileSelectionPolicy( Qgis::UserProfileSelectionPolicy policy );
+
     /**
      * Returns the profile found for a given name.
      * \param name The name of the profile to return.
@@ -185,6 +210,12 @@ class CORE_EXPORT QgsUserProfileManager : public QObject
      */
     void loadUserProfile( const QString &name );
 
+    /**
+     * Returns the settings for the profile manager.
+     * \since QGIS 3.32
+    */
+    QSettings *settings();
+
   signals:
 
     /**
