@@ -23,8 +23,9 @@
 #include <QImage>
 #include <memory>
 
-QgsSingleBandColorDataRenderer::QgsSingleBandColorDataRenderer( QgsRasterInterface *input, int band ):
-  QgsRasterRenderer( input, QStringLiteral( "singlebandcolordata" ) ), mBand( band )
+QgsSingleBandColorDataRenderer::QgsSingleBandColorDataRenderer( QgsRasterInterface *input, int band )
+  : QgsRasterRenderer( input, QStringLiteral( "singlebandcolordata" ) )
+  , mBand( band )
 {
 
 }
@@ -139,3 +140,23 @@ bool QgsSingleBandColorDataRenderer::setInput( QgsRasterInterface *input )
   }
   return false;
 }
+
+int QgsSingleBandColorDataRenderer::inputBand() const
+{
+  return mBand;
+}
+
+bool QgsSingleBandColorDataRenderer::setInputBand( int band )
+{
+  if ( !mInput )
+  {
+    mBand = band;
+    return true;
+  }
+  else if ( band > 0 && band <= mInput->bandCount() )
+  {
+    mBand = band;
+    return true;
+  }
+  return false;
+}
