@@ -36,7 +36,6 @@ class GUI_EXPORT QgsAuthIdentitiesEditor : public QWidget, private Ui::QgsAuthId
     Q_OBJECT
 
   public:
-
     /**
      * Widget for editing authentication configurations directly in database
      * \param parent Parent widget
@@ -67,7 +66,7 @@ class GUI_EXPORT QgsAuthIdentitiesEditor : public QWidget, private Ui::QgsAuthId
     void btnGroupByOrg_toggled( bool checked );
 
     //! Relay messages to widget's messagebar
-    void authMessageOut( const QString &message, const QString &authtag, QgsAuthManager::MessageLevel level );
+    void authMessageLog( const QString &message, const QString &authtag, Qgis::MessageLevel level );
 
   protected:
     //! Overridden show event of base widget
@@ -83,16 +82,11 @@ class GUI_EXPORT QgsAuthIdentitiesEditor : public QWidget, private Ui::QgsAuthId
 
     void setupIdentitiesTree();
 
-    void populateIdentitiesSection( QTreeWidgetItem *item, const QList<QSslCertificate> &certs,
-                                    QgsAuthIdentitiesEditor::IdentityType identype );
+    void populateIdentitiesSection( QTreeWidgetItem *item, const QList<QSslCertificate> &certs, QgsAuthIdentitiesEditor::IdentityType identype );
 
-    void appendIdentitiesToGroup( const QList<QSslCertificate> &certs,
-                                  QgsAuthIdentitiesEditor::IdentityType identype,
-                                  QTreeWidgetItem *parent = nullptr );
+    void appendIdentitiesToGroup( const QList<QSslCertificate> &certs, QgsAuthIdentitiesEditor::IdentityType identype, QTreeWidgetItem *parent = nullptr );
 
-    void appendIdentitiesToItem( const QList<QSslCertificate> &certs,
-                                 QgsAuthIdentitiesEditor::IdentityType identype,
-                                 QTreeWidgetItem *parent = nullptr );
+    void appendIdentitiesToItem( const QList<QSslCertificate> &certs, QgsAuthIdentitiesEditor::IdentityType identype, QTreeWidgetItem *parent = nullptr );
 
     QgsMessageBar *messageBar();
     int messageTimeout();
