@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsmodelgraphicsview.h"
+#include "moc_qgsmodelgraphicsview.cpp"
 #include "qgssettings.h"
 #include "qgsmodelviewtool.h"
 #include "qgsmodelviewmouseevent.h"
@@ -77,8 +78,7 @@ void QgsModelGraphicsView::dropEvent( QDropEvent *event )
     QString algorithmId;
     stream >> algorithmId;
 
-    QTimer::singleShot( 0, this, [this, dropPoint, algorithmId ]
-    {
+    QTimer::singleShot( 0, this, [this, dropPoint, algorithmId] {
       emit algorithmDropped( algorithmId, dropPoint );
     } );
     event->accept();
@@ -86,8 +86,7 @@ void QgsModelGraphicsView::dropEvent( QDropEvent *event )
   else if ( event->mimeData()->hasText() )
   {
     const QString itemId = event->mimeData()->text();
-    QTimer::singleShot( 0, this, [this, dropPoint, itemId ]
-    {
+    QTimer::singleShot( 0, this, [this, dropPoint, itemId] {
       emit inputDropped( itemId, dropPoint );
     } );
     event->accept();
@@ -152,8 +151,7 @@ void QgsModelGraphicsView::wheelZoom( QWheelEvent *event )
 
   //adjust view center
   QgsPointXY oldCenter( visibleRect.center() );
-  QgsPointXY newCenter( scenePoint.x() + ( ( oldCenter.x() - scenePoint.x() ) * scaleFactor ),
-                        scenePoint.y() + ( ( oldCenter.y() - scenePoint.y() ) * scaleFactor ) );
+  QgsPointXY newCenter( scenePoint.x() + ( ( oldCenter.x() - scenePoint.x() ) * scaleFactor ), scenePoint.y() + ( ( oldCenter.y() - scenePoint.y() ) * scaleFactor ) );
   centerOn( newCenter.x(), newCenter.y() );
 
   //zoom layout
@@ -329,7 +327,7 @@ void QgsModelGraphicsView::keyPressEvent( QKeyEvent *event )
   if ( mTool && event->isAccepted() )
     return;
 
-  if ( event->key() == Qt::Key_Space && ! event->isAutoRepeat() )
+  if ( event->key() == Qt::Key_Space && !event->isAutoRepeat() )
   {
     if ( !( event->modifiers() & Qt::ControlModifier ) )
     {
@@ -392,7 +390,7 @@ void QgsModelGraphicsView::setModelScene( QgsModelGraphicsScene *scene )
 
 QgsModelGraphicsScene *QgsModelGraphicsView::modelScene() const
 {
-  return qobject_cast< QgsModelGraphicsScene * >( QgsModelGraphicsView::scene() );
+  return qobject_cast<QgsModelGraphicsScene *>( QgsModelGraphicsView::scene() );
 }
 
 QgsModelViewTool *QgsModelGraphicsView::tool()
@@ -456,7 +454,7 @@ void QgsModelGraphicsView::snapSelected()
     for ( QgsModelComponentGraphicItem *item : itemList )
     {
       bool wasSnapped = false;
-      QRectF snapped = mSnapper.snapRectWithResize( item->mapRectToScene( item->itemRect( ) ), transform().m11(), wasSnapped );
+      QRectF snapped = mSnapper.snapRectWithResize( item->mapRectToScene( item->itemRect() ), transform().m11(), wasSnapped );
       if ( wasSnapped )
       {
         item->setItemRect( snapped );
@@ -486,32 +484,32 @@ void QgsModelGraphicsView::copyItems( const QList<QgsModelComponentGraphicItem *
     emit beginCommand( QString() );
   }
 
-  QList< QVariant > paramComponents;
-  QList< QVariant > groupBoxComponents;
-  QList< QVariant > algComponents;
+  QList<QVariant> paramComponents;
+  QList<QVariant> groupBoxComponents;
+  QList<QVariant> algComponents;
 
-  QList< QgsModelComponentGraphicItem * > selectedCommentParents;
-  QList< QgsProcessingModelOutput > selectedOutputs;
-  QList< QgsProcessingModelOutput > selectedOutputsComments;
+  QList<QgsModelComponentGraphicItem *> selectedCommentParents;
+  QList<QgsProcessingModelOutput> selectedOutputs;
+  QList<QgsProcessingModelOutput> selectedOutputsComments;
   for ( QgsModelComponentGraphicItem *item : items )
   {
-    if ( const QgsModelCommentGraphicItem *commentItem = dynamic_cast< QgsModelCommentGraphicItem * >( item ) )
+    if ( const QgsModelCommentGraphicItem *commentItem = dynamic_cast<QgsModelCommentGraphicItem *>( item ) )
     {
       selectedCommentParents << commentItem->parentComponentItem();
-      if ( const QgsModelOutputGraphicItem *outputItem = dynamic_cast< QgsModelOutputGraphicItem * >( commentItem->parentComponentItem() ) )
+      if ( const QgsModelOutputGraphicItem *outputItem = dynamic_cast<QgsModelOutputGraphicItem *>( commentItem->parentComponentItem() ) )
       {
-        selectedOutputsComments << *( static_cast< const QgsProcessingModelOutput *>( outputItem->component() ) );
+        selectedOutputsComments << *( static_cast<const QgsProcessingModelOutput *>( outputItem->component() ) );
       }
     }
-    else if ( const QgsModelOutputGraphicItem *outputItem = dynamic_cast< QgsModelOutputGraphicItem * >( item ) )
+    else if ( const QgsModelOutputGraphicItem *outputItem = dynamic_cast<QgsModelOutputGraphicItem *>( item ) )
     {
-      selectedOutputs << *( static_cast< const QgsProcessingModelOutput *>( outputItem->component() ) );
+      selectedOutputs << *( static_cast<const QgsProcessingModelOutput *>( outputItem->component() ) );
     }
   }
 
   for ( QgsModelComponentGraphicItem *item : items )
   {
-    if ( const QgsProcessingModelParameter *param = dynamic_cast< QgsProcessingModelParameter * >( item->component() ) )
+    if ( const QgsProcessingModelParameter *param = dynamic_cast<QgsProcessingModelParameter *>( item->component() ) )
     {
       QgsProcessingModelParameter component = *param;
 
@@ -529,11 +527,11 @@ void QgsModelGraphicsView::copyItems( const QList<QgsModelComponentGraphicItem *
 
       paramComponents << paramDef;
     }
-    else if ( QgsProcessingModelGroupBox *groupBox = dynamic_cast< QgsProcessingModelGroupBox * >( item->component() ) )
+    else if ( QgsProcessingModelGroupBox *groupBox = dynamic_cast<QgsProcessingModelGroupBox *>( item->component() ) )
     {
       groupBoxComponents << groupBox->toVariant();
     }
-    else if ( const QgsProcessingModelChildAlgorithm *alg = dynamic_cast< QgsProcessingModelChildAlgorithm * >( item->component() ) )
+    else if ( const QgsProcessingModelChildAlgorithm *alg = dynamic_cast<QgsProcessingModelChildAlgorithm *>( item->component() ) )
     {
       QgsProcessingModelChildAlgorithm childAlg = *alg;
 
@@ -547,7 +545,7 @@ void QgsModelGraphicsView::copyItems( const QList<QgsModelComponentGraphicItem *
       // don't copy outputs which weren't selected either
       QMap<QString, QgsProcessingModelOutput> clipboardOutputs;
       const QMap<QString, QgsProcessingModelOutput> existingOutputs = childAlg.modelOutputs();
-      for ( auto it = existingOutputs.constBegin(); it != existingOutputs.constEnd(); ++ it )
+      for ( auto it = existingOutputs.constBegin(); it != existingOutputs.constEnd(); ++it )
       {
         bool found = false;
         for ( const QgsProcessingModelOutput &candidate : selectedOutputs )
@@ -638,7 +636,7 @@ void QgsModelGraphicsView::pasteItems( QgsModelGraphicsView::PasteMode mode )
 
       QRectF pastedBounds;
 
-      QList< QgsProcessingModelGroupBox > pastedGroups;
+      QList<QgsProcessingModelGroupBox> pastedGroups;
       for ( const QVariant &v : res.value( QStringLiteral( "groupboxes" ) ).toList() )
       {
         QgsProcessingModelGroupBox box;
@@ -649,7 +647,7 @@ void QgsModelGraphicsView::pasteItems( QgsModelGraphicsView::PasteMode mode )
 
         modelScene()->model()->addGroupBox( box );
 
-        if ( !pastedBounds.isValid( ) )
+        if ( !pastedBounds.isValid() )
           pastedBounds = QRectF( box.position() - QPointF( box.size().width() / 2.0, box.size().height() / 2.0 ), box.size() );
         else
           pastedBounds = pastedBounds.united( QRectF( box.position() - QPointF( box.size().width() / 2.0, box.size().height() / 2.0 ), box.size() ) );
@@ -662,7 +660,7 @@ void QgsModelGraphicsView::pasteItems( QgsModelGraphicsView::PasteMode mode )
         QVariantMap componentDef = param.value( QStringLiteral( "component" ) ).toMap();
         QVariantMap paramDef = param.value( QStringLiteral( "definition" ) ).toMap();
 
-        std::unique_ptr< QgsProcessingParameterDefinition > paramDefinition( QgsProcessingParameters::parameterFromVariantMap( paramDef ) );
+        std::unique_ptr<QgsProcessingParameterDefinition> paramDefinition( QgsProcessingParameters::parameterFromVariantMap( paramDef ) );
 
         QgsProcessingModelParameter p;
         p.loadVariant( componentDef );
@@ -684,7 +682,7 @@ void QgsModelGraphicsView::pasteItems( QgsModelGraphicsView::PasteMode mode )
         modelScene()->model()->addModelParameter( paramDefinition.release(), p );
         pastedParameters << p.parameterName();
 
-        if ( !pastedBounds.isValid( ) )
+        if ( !pastedBounds.isValid() )
           pastedBounds = QRectF( p.position() - QPointF( p.size().width() / 2.0, p.size().height() / 2.0 ), p.size() );
         else
           pastedBounds = pastedBounds.united( QRectF( p.position() - QPointF( p.size().width() / 2.0, p.size().height() / 2.0 ), p.size() ) );
@@ -708,7 +706,7 @@ void QgsModelGraphicsView::pasteItems( QgsModelGraphicsView::PasteMode mode )
 
         pastedAlgorithms << alg.childId();
 
-        if ( !pastedBounds.isValid( ) )
+        if ( !pastedBounds.isValid() )
           pastedBounds = QRectF( alg.position() - QPointF( alg.size().width() / 2.0, alg.size().height() / 2.0 ), alg.size() );
         else
           pastedBounds = pastedBounds.united( QRectF( alg.position() - QPointF( alg.size().width() / 2.0, alg.size().height() / 2.0 ), alg.size() ) );
@@ -836,5 +834,3 @@ void QgsModelViewSnapMarker::paint( QPainter *p, const QStyleOptionGraphicsItem
 
 
 ///@endcond
-
-
