@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsprocessingalgorithmdialogbase.h"
+#include "moc_qgsprocessingalgorithmdialogbase.cpp"
 #include "qgssettings.h"
 #include "qgshelp.h"
 #include "qgsmessagebar.h"
@@ -27,6 +28,7 @@
 #include "qgspanelwidget.h"
 #include "qgsjsonutils.h"
 #include "qgsunittypes.h"
+#include "qgsnative.h"
 #include <QToolButton>
 #include <QDesktopServices>
 #include <QScrollBar>
@@ -86,6 +88,12 @@ void QgsProcessingAlgorithmDialogFeedback::pushConsoleInfo( const QString &info
   emit consoleInfoPushed( info );
 }
 
+void QgsProcessingAlgorithmDialogFeedback::pushFormattedMessage( const QString &html, const QString &text )
+{
+  QgsProcessingFeedback::pushFormattedMessage( html, text );
+  emit formattedMessagePushed( html );
+}
+
 //
 // QgsProcessingAlgorithmDialogBase
 //
@@ -113,6 +121,9 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
 
   QgsGui::enableAutoGeometryRestore( this );
 
+  txtLog->setOpenLinks( false );
+  connect( txtLog, &QTextBrowser::anchorClicked, this, &QgsProcessingAlgorithmDialogBase::urlClicked );
+
   const QgsSettings settings;
   splitter->restoreState( settings.value( QStringLiteral( "/Processing/dialogBaseSplitter" ), QByteArray() ).toByteArray() );
   mSplitterState = splitter->saveState();
@@ -141,8 +152,7 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
       mContextSettingsAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "/propertyicons/settings.svg" ) ) );
       mAdvancedMenu->addAction( mContextSettingsAction );
 
-      connect( mContextSettingsAction, &QAction::triggered, this, [this]
-      {
+      connect( mContextSettingsAction, &QAction::triggered, this, [this] {
         if ( QgsPanelWidget *panel = QgsPanelWidget::findParentPanel( mMainWidget ) )
         {
           mTabWidget->setCurrentIndex( 0 );
@@ -154,8 +164,7 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
             mContextOptionsWidget->setLogLevel( mLogLevel );
             panel->openPanel( mContextOptionsWidget );
 
-            connect( mContextOptionsWidget, &QgsPanelWidget::widgetChanged, this, [ = ]
-            {
+            connect( mContextOptionsWidget, &QgsPanelWidget::widgetChanged, this, [=] {
               mOverrideDefaultContextSettings = true;
               mGeometryCheck = mContextOptionsWidget->invalidGeometryCheck();
               mDistanceUnits = mContextOptionsWidget->distanceUnit();
@@ -173,8 +182,7 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
       copyAsPythonCommand->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mIconPythonFile.svg" ) ) );
 
       mAdvancedMenu->addAction( copyAsPythonCommand );
-      connect( copyAsPythonCommand, &QAction::triggered, this, [this]
-      {
+      connect( copyAsPythonCommand, &QAction::triggered, this, [this] {
         if ( const QgsProcessingAlgorithm *alg = algorithm() )
         {
           QgsProcessingContext *context = processingContext();
@@ -197,8 +205,7 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
       mCopyAsQgisProcessCommand->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mActionTerminal.svg" ) ) );
       mAdvancedMenu->addAction( mCopyAsQgisProcessCommand );
 
-      connect( mCopyAsQgisProcessCommand, &QAction::triggered, this, [this]
-      {
+      connect( mCopyAsQgisProcessCommand, &QAction::triggered, this, [this] {
         if ( const QgsProcessingAlgorithm *alg = algorithm() )
         {
           QgsProcessingContext *context = processingContext();
@@ -207,7 +214,7 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
 
           bool ok = false;
           const QString command = alg->asQgisProcessCommand( createProcessingParameters(), *context, ok );
-          if ( ! ok )
+          if ( !ok )
           {
             mMessageBar->pushMessage( tr( "Current settings cannot be specified as arguments to qgis_process (Pipe parameters as JSON to qgis_process instead)" ), Qgis::MessageLevel::Warning );
           }
@@ -231,8 +238,7 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
       copyAsJson->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mActionEditCopy.svg" ) ) );
 
       mAdvancedMenu->addAction( copyAsJson );
-      connect( copyAsJson, &QAction::triggered, this, [this]
-      {
+      connect( copyAsJson, &QAction::triggered, this, [this] {
         if ( const QgsProcessingAlgorithm *alg = algorithm() )
         {
           QgsProcessingContext *context = processingContext();
@@ -257,8 +263,7 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
       mPasteJsonAction->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "mActionEditPaste.svg" ) ) );
 
       mAdvancedMenu->addAction( mPasteJsonAction );
-      connect( mPasteJsonAction, &QAction::triggered, this, [this]
-      {
+      connect( mPasteJsonAction, &QAction::triggered, this, [this] {
         const QString text = QApplication::clipboard()->text();
         if ( text.isEmpty() )
           return;
@@ -284,10 +289,8 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
 
   if ( mAdvancedMenu )
   {
-    connect( mAdvancedMenu, &QMenu::aboutToShow, this, [ = ]
-    {
-      mCopyAsQgisProcessCommand->setEnabled( algorithm()
-                                             && !( algorithm()->flags() & QgsProcessingAlgorithm::FlagNotAvailableInStandaloneTool ) );
+    connect( mAdvancedMenu, &QMenu::aboutToShow, this, [=] {
+      mCopyAsQgisProcessCommand->setEnabled( algorithm() && !( algorithm()->flags() & Qgis::ProcessingAlgorithmFlag::NotAvailableInStandaloneTool ) );
       mPasteJsonAction->setEnabled( !QApplication::clipboard()->text().isEmpty() );
     } );
   }
@@ -307,7 +310,7 @@ QgsProcessingAlgorithmDialogBase::QgsProcessingAlgorithmDialogBase( QWidget *par
 
   mMessageBar = new QgsMessageBar();
   mMessageBar->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Fixed );
-  verticalLayout->insertWidget( 0,  mMessageBar );
+  verticalLayout->insertWidget( 0, mMessageBar );
 
   connect( QgsApplication::taskManager(), &QgsTaskManager::taskTriggered, this, &QgsProcessingAlgorithmDialogBase::taskTriggered );
 }
@@ -321,14 +324,19 @@ void QgsProcessingAlgorithmDialogBase::setAlgorithm( QgsProcessingAlgorithm *alg
 {
   mAlgorithm.reset( algorithm );
   QString title;
-  if ( ( QgsGui::higFlags() & QgsGui::HigDialogTitleIsTitleCase ) && !( algorithm->flags() & QgsProcessingAlgorithm::FlagDisplayNameIsLiteral ) )
+  if ( ( QgsGui::higFlags() & QgsGui::HigDialogTitleIsTitleCase ) && !( algorithm->flags() & Qgis::ProcessingAlgorithmFlag::DisplayNameIsLiteral ) )
   {
-    title = QgsStringUtils::capitalize( mAlgorithm->displayName(), Qgis::Capitalization::TitleCase );
+    title = mAlgorithm->group().isEmpty()
+              ? QgsStringUtils::capitalize( mAlgorithm->displayName(), Qgis::Capitalization::TitleCase )
+              : QStringLiteral( "%1 - %2" ).arg( QgsStringUtils::capitalize( mAlgorithm->group(), Qgis::Capitalization::TitleCase ), QgsStringUtils::capitalize( mAlgorithm->displayName(), Qgis::Capitalization::TitleCase ) );
   }
   else
   {
-    title = mAlgorithm->displayName();
+    title = mAlgorithm->group().isEmpty()
+              ? mAlgorithm->displayName()
+              : QStringLiteral( "%1 - %2" ).arg( mAlgorithm->group(), mAlgorithm->displayName() );
   }
+
   setWindowTitle( title );
 
   const QString algHelp = formatHelp( algorithm );
@@ -337,11 +345,11 @@ void QgsProcessingAlgorithmDialogBase::setAlgorithm( QgsProcessingAlgorithm *alg
   else
   {
     textShortHelp->document()->setDefaultStyleSheet( QStringLiteral( ".summary { margin-left: 10px; margin-right: 10px; }\n"
-        "h2 { color: #555555; padding-bottom: 15px; }\n"
-        "a { text - decoration: none; color: #3498db; font-weight: bold; }\n"
-        "p { color: #666666; }\n"
-        "b { color: #333333; }\n"
-        "dl dd { margin - bottom: 5px; }" ) );
+                                                                     "h2 { color: #555555; padding-bottom: 15px; }\n"
+                                                                     "a { text - decoration: none; color: #3498db; font-weight: bold; }\n"
+                                                                     "p, ul, li { color: #666666; }\n"
+                                                                     "b { color: #333333; }\n"
+                                                                     "dl dd { margin - bottom: 5px; }" ) );
     textShortHelp->setHtml( algHelp );
     connect( textShortHelp, &QTextBrowser::anchorClicked, this, &QgsProcessingAlgorithmDialogBase::linkClicked );
     textShortHelp->show();
@@ -406,7 +414,7 @@ void QgsProcessingAlgorithmDialogBase::saveLogToFile( const QString &path, const
 
 QgsProcessingFeedback *QgsProcessingAlgorithmDialogBase::createFeedback()
 {
-  auto feedback = std::make_unique< QgsProcessingAlgorithmDialogFeedback >();
+  auto feedback = std::make_unique<QgsProcessingAlgorithmDialogFeedback>();
   connect( feedback.get(), &QgsProcessingFeedback::progressChanged, this, &QgsProcessingAlgorithmDialogBase::setPercentage );
   connect( feedback.get(), &QgsProcessingAlgorithmDialogFeedback::commandInfoPushed, this, &QgsProcessingAlgorithmDialogBase::pushCommandInfo );
   connect( feedback.get(), &QgsProcessingAlgorithmDialogFeedback::consoleInfoPushed, this, &QgsProcessingAlgorithmDialogBase::pushConsoleInfo );
@@ -414,6 +422,7 @@ QgsProcessingFeedback *QgsProcessingAlgorithmDialogBase::createFeedback()
   connect( feedback.get(), &QgsProcessingAlgorithmDialogFeedback::errorReported, this, &QgsProcessingAlgorithmDialogBase::reportError );
   connect( feedback.get(), &QgsProcessingAlgorithmDialogFeedback::warningPushed, this, &QgsProcessingAlgorithmDialogBase::pushWarning );
   connect( feedback.get(), &QgsProcessingAlgorithmDialogFeedback::infoPushed, this, &QgsProcessingAlgorithmDialogBase::pushInfo );
+  connect( feedback.get(), &QgsProcessingAlgorithmDialogFeedback::formattedMessagePushed, this, &QgsProcessingAlgorithmDialogBase::pushFormattedMessage );
   connect( feedback.get(), &QgsProcessingAlgorithmDialogFeedback::progressTextChanged, this, &QgsProcessingAlgorithmDialogBase::setProgressText );
   connect( buttonCancel, &QPushButton::clicked, feedback.get(), &QgsProcessingFeedback::cancel );
   return feedback.release();
@@ -476,7 +485,6 @@ void QgsProcessingAlgorithmDialogBase::setResults( const QVariantMap &results )
 
 void QgsProcessingAlgorithmDialogBase::finished( bool, const QVariantMap &, QgsProcessingContext &, QgsProcessingFeedback * )
 {
-
 }
 
 void QgsProcessingAlgorithmDialogBase::openHelp()
@@ -484,7 +492,7 @@ void QgsProcessingAlgorithmDialogBase::openHelp()
   QUrl algHelp = mAlgorithm->helpUrl();
   if ( algHelp.isEmpty() && mAlgorithm->provider() )
   {
-    algHelp = QgsHelp::helpUrl( QStringLiteral( "processing_algs/%1/%2.html#%3" ).arg( mAlgorithm->provider()->helpId(), mAlgorithm->groupId(), QStringLiteral( "%1%2" ).arg( mAlgorithm->provider()->helpId() ).arg( mAlgorithm->name() ) ) );
+    algHelp = QgsHelp::helpUrl( QStringLiteral( "processing_algs/%1/%2.html#%3" ).arg( mAlgorithm->provider()->helpId(), mAlgorithm->groupId(), QStringLiteral( "%1%2" ).arg( mAlgorithm->provider()->helpId() ).arg( mAlgorithm->name().replace( "_", "-" ) ) ) );
   }
 
   if ( !algHelp.isEmpty() )
@@ -577,12 +585,21 @@ void QgsProcessingAlgorithmDialogBase::closeClicked()
   close();
 }
 
-QgsProcessingContext::LogLevel QgsProcessingAlgorithmDialogBase::logLevel() const
+void QgsProcessingAlgorithmDialogBase::urlClicked( const QUrl &url )
+{
+  const QFileInfo file( url.toLocalFile() );
+  if ( file.exists() && !file.isDir() )
+    QgsGui::nativePlatformInterface()->openFileExplorerAndSelectFile( url.toLocalFile() );
+  else
+    QDesktopServices::openUrl( url );
+}
+
+Qgis::ProcessingLogLevel QgsProcessingAlgorithmDialogBase::logLevel() const
 {
   return mLogLevel;
 }
 
-void QgsProcessingAlgorithmDialogBase::setLogLevel( QgsProcessingContext::LogLevel level )
+void QgsProcessingAlgorithmDialogBase::setLogLevel( Qgis::ProcessingLogLevel level )
 {
   mLogLevel = level;
 }
@@ -608,6 +625,12 @@ void QgsProcessingAlgorithmDialogBase::pushInfo( const QString &info )
   processEvents();
 }
 
+void QgsProcessingAlgorithmDialogBase::pushFormattedMessage( const QString &html )
+{
+  setInfo( html, false, false );
+  processEvents();
+}
+
 void QgsProcessingAlgorithmDialogBase::pushCommandInfo( const QString &command )
 {
   txtLog->append( QStringLiteral( "<code>%1<code>" ).arg( formatStringForLog( command.toHtmlEscaped() ) ) );
@@ -638,8 +661,7 @@ QDialog *QgsProcessingAlgorithmDialogBase::createProgressDialog()
   connect( progressBar, &QProgressBar::valueChanged, dialog->progressBar(), &QProgressBar::setValue );
   connect( dialog->cancelButton(), &QPushButton::clicked, buttonCancel, &QPushButton::click );
   dialog->logTextEdit()->setHtml( txtLog->toHtml() );
-  connect( txtLog, &QTextEdit::textChanged, dialog, [this, dialog]()
-  {
+  connect( txtLog, &QTextEdit::textChanged, dialog, [this, dialog]() {
     dialog->logTextEdit()->setHtml( txtLog->toHtml() );
     QScrollBar *sb = dialog->logTextEdit()->verticalScrollBar();
     sb->setValue( sb->maximum() );
@@ -714,7 +736,6 @@ void QgsProcessingAlgorithmDialogBase::closeEvent( QCloseEvent *e )
 
 void QgsProcessingAlgorithmDialogBase::runAlgorithm()
 {
-
 }
 
 void QgsProcessingAlgorithmDialogBase::setPercentage( double percent )
@@ -736,6 +757,7 @@ void QgsProcessingAlgorithmDialogBase::setProgressText( const QString &text )
 
 QString QgsProcessingAlgorithmDialogBase::formatHelp( QgsProcessingAlgorithm *algorithm )
 {
+  QString result;
   const QString text = algorithm->shortHelpString();
   if ( !text.isEmpty() )
   {
@@ -745,14 +767,35 @@ QString QgsProcessingAlgorithmDialogBase::formatHelp( QgsProcessingAlgorithm *al
     {
       help += QStringLiteral( "<p>%1</p>" ).arg( paragraph );
     }
-    return QStringLiteral( "<h2>%1</h2>%2" ).arg( algorithm->displayName(), help );
+    result = QStringLiteral( "<h2>%1</h2>%2" ).arg( algorithm->displayName(), help );
   }
   else if ( !algorithm->shortDescription().isEmpty() )
   {
-    return QStringLiteral( "<h2>%1</h2><p>%2</p>" ).arg( algorithm->displayName(), algorithm->shortDescription() );
+    result = QStringLiteral( "<h2>%1</h2><p>%2</p>" ).arg( algorithm->displayName(), algorithm->shortDescription() );
   }
-  else
-    return QString();
+
+  if ( algorithm->documentationFlags() != Qgis::ProcessingAlgorithmDocumentationFlags() )
+  {
+    QStringList flags;
+    for ( Qgis::ProcessingAlgorithmDocumentationFlag flag : qgsEnumList<Qgis::ProcessingAlgorithmDocumentationFlag>() )
+    {
+      if ( algorithm->documentationFlags() & flag )
+      {
+        flags << QgsProcessing::documentationFlagToString( flag );
+      }
+    }
+    result += QStringLiteral( "<ul><li><i>%1</i></li></ul>" ).arg( flags.join( QLatin1String( "</i></li><li><i>" ) ) );
+  }
+  if ( algorithm->flags() & Qgis::ProcessingAlgorithmFlag::SecurityRisk )
+  {
+    result += QStringLiteral( "<p><b>%1</b></p>" ).arg( tr( "Warning: This algorithm is a potential security risk if executed with unchecked inputs, and may result in system damage or data leaks." ) );
+  }
+  if ( algorithm->flags() & Qgis::ProcessingAlgorithmFlag::KnownIssues )
+  {
+    result += QStringLiteral( "<p><b>%1</b></p>" ).arg( tr( "Warning: This algorithm has known issues. The results must be carefully validated by the user." ) );
+  }
+
+  return result;
 }
 
 void QgsProcessingAlgorithmDialogBase::processEvents()
@@ -814,7 +857,6 @@ void QgsProcessingAlgorithmDialogBase::updateRunButtonVisibility()
 
 void QgsProcessingAlgorithmDialogBase::resetAdditionalGui()
 {
-
 }
 
 void QgsProcessingAlgorithmDialogBase::blockControlsWhileRunning()
@@ -830,7 +872,6 @@ void QgsProcessingAlgorithmDialogBase::blockControlsWhileRunning()
 
 void QgsProcessingAlgorithmDialogBase::blockAdditionalControlsWhileRunning()
 {
-
 }
 
 QgsMessageBar *QgsProcessingAlgorithmDialogBase::messageBar()
@@ -937,7 +978,6 @@ QTextEdit *QgsProcessingAlgorithmProgressDialog::logTextEdit()
 
 void QgsProcessingAlgorithmProgressDialog::reject()
 {
-
 }
 
 
@@ -951,17 +991,17 @@ QgsProcessingContextOptionsWidget::QgsProcessingContextOptionsWidget( QWidget *p
   setupUi( this );
   setPanelTitle( tr( "Algorithm Settings" ) );
 
-  mComboInvalidFeatureFiltering->addItem( tr( "Do not Filter (Better Performance)" ), QgsFeatureRequest::GeometryNoCheck );
-  mComboInvalidFeatureFiltering->addItem( tr( "Skip (Ignore) Features with Invalid Geometries" ), QgsFeatureRequest::GeometrySkipInvalid );
-  mComboInvalidFeatureFiltering->addItem( tr( "Stop Algorithm Execution When a Geometry is Invalid" ), QgsFeatureRequest::GeometryAbortOnInvalid );
+  mComboInvalidFeatureFiltering->addItem( tr( "Do not Filter (Better Performance)" ), QVariant::fromValue( Qgis::InvalidGeometryCheck::NoCheck ) );
+  mComboInvalidFeatureFiltering->addItem( tr( "Skip (Ignore) Features with Invalid Geometries" ), QVariant::fromValue( Qgis::InvalidGeometryCheck::SkipInvalid ) );
+  mComboInvalidFeatureFiltering->addItem( tr( "Stop Algorithm Execution When a Geometry is Invalid" ), QVariant::fromValue( Qgis::InvalidGeometryCheck::AbortOnInvalid ) );
 
   mTemporaryFolderWidget->setDialogTitle( tr( "Select Temporary Directory" ) );
   mTemporaryFolderWidget->setStorageMode( QgsFileWidget::GetDirectory );
   mTemporaryFolderWidget->lineEdit()->setPlaceholderText( tr( "Default" ) );
 
-  mLogLevelComboBox->addItem( tr( "Default" ), QgsProcessingContext::LogLevel::DefaultLevel );
-  mLogLevelComboBox->addItem( tr( "Verbose" ), QgsProcessingContext::LogLevel::Verbose );
-  mLogLevelComboBox->addItem( tr( "Verbose (Model Debugging)" ), QgsProcessingContext::LogLevel::ModelDebug );
+  mLogLevelComboBox->addItem( tr( "Default" ), static_cast<int>( Qgis::ProcessingLogLevel::DefaultLevel ) );
+  mLogLevelComboBox->addItem( tr( "Verbose" ), static_cast<int>( Qgis::ProcessingLogLevel::Verbose ) );
+  mLogLevelComboBox->addItem( tr( "Verbose (Model Debugging)" ), static_cast<int>( Qgis::ProcessingLogLevel::ModelDebug ) );
 
   mDistanceUnitsCombo->addItem( tr( "Default" ), QVariant::fromValue( Qgis::DistanceUnit::Unknown ) );
   for ( Qgis::DistanceUnit unit :
@@ -1023,37 +1063,37 @@ QgsProcessingContextOptionsWidget::QgsProcessingContextOptionsWidget( QWidget *p
 
   mThreadsSpinBox->setRange( 1, QThread::idealThreadCount() );
 
-  connect( mLogLevelComboBox, qOverload< int >( &QComboBox::currentIndexChanged ), this, &QgsPanelWidget::widgetChanged );
-  connect( mComboInvalidFeatureFiltering, qOverload< int >( &QComboBox::currentIndexChanged ), this, &QgsPanelWidget::widgetChanged );
-  connect( mDistanceUnitsCombo, qOverload< int >( &QComboBox::currentIndexChanged ), this, &QgsPanelWidget::widgetChanged );
-  connect( mAreaUnitsCombo, qOverload< int >( &QComboBox::currentIndexChanged ), this, &QgsPanelWidget::widgetChanged );
+  connect( mLogLevelComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsPanelWidget::widgetChanged );
+  connect( mComboInvalidFeatureFiltering, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsPanelWidget::widgetChanged );
+  connect( mDistanceUnitsCombo, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsPanelWidget::widgetChanged );
+  connect( mAreaUnitsCombo, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsPanelWidget::widgetChanged );
   connect( mTemporaryFolderWidget, &QgsFileWidget::fileChanged, this, &QgsPanelWidget::widgetChanged );
-  connect( mThreadsSpinBox, qOverload< int >( &QSpinBox::valueChanged ), this, &QgsPanelWidget::widgetChanged );
+  connect( mThreadsSpinBox, qOverload<int>( &QSpinBox::valueChanged ), this, &QgsPanelWidget::widgetChanged );
 }
 
 void QgsProcessingContextOptionsWidget::setFromContext( const QgsProcessingContext *context )
 {
-  whileBlocking( mComboInvalidFeatureFiltering )->setCurrentIndex( mComboInvalidFeatureFiltering->findData( static_cast< int >( context->invalidGeometryCheck() ) ) );
+  whileBlocking( mComboInvalidFeatureFiltering )->setCurrentIndex( mComboInvalidFeatureFiltering->findData( QVariant::fromValue( context->invalidGeometryCheck() ) ) );
   whileBlocking( mDistanceUnitsCombo )->setCurrentIndex( mDistanceUnitsCombo->findData( QVariant::fromValue( context->distanceUnit() ) ) );
   whileBlocking( mAreaUnitsCombo )->setCurrentIndex( mAreaUnitsCombo->findData( QVariant::fromValue( context->areaUnit() ) ) );
   whileBlocking( mTemporaryFolderWidget )->setFilePath( context->temporaryFolder() );
   whileBlocking( mThreadsSpinBox )->setValue( context->maximumThreads() );
-  whileBlocking( mLogLevelComboBox )->setCurrentIndex( mLogLevelComboBox->findData( static_cast< int >( context->logLevel() ) ) );
+  whileBlocking( mLogLevelComboBox )->setCurrentIndex( mLogLevelComboBox->findData( static_cast<int>( context->logLevel() ) ) );
 }
 
-QgsFeatureRequest::InvalidGeometryCheck QgsProcessingContextOptionsWidget::invalidGeometryCheck() const
+Qgis::InvalidGeometryCheck QgsProcessingContextOptionsWidget::invalidGeometryCheck() const
 {
-  return static_cast< QgsFeatureRequest::InvalidGeometryCheck >( mComboInvalidFeatureFiltering->currentData().toInt() );
+  return mComboInvalidFeatureFiltering->currentData().value<Qgis::InvalidGeometryCheck>();
 }
 
 Qgis::DistanceUnit QgsProcessingContextOptionsWidget::distanceUnit() const
 {
-  return mDistanceUnitsCombo->currentData().value< Qgis::DistanceUnit >();
+  return mDistanceUnitsCombo->currentData().value<Qgis::DistanceUnit>();
 }
 
 Qgis::AreaUnit QgsProcessingContextOptionsWidget::areaUnit() const
 {
-  return mAreaUnitsCombo->currentData().value< Qgis::AreaUnit >();
+  return mAreaUnitsCombo->currentData().value<Qgis::AreaUnit>();
 }
 
 QString QgsProcessingContextOptionsWidget::temporaryFolder()
@@ -1066,14 +1106,14 @@ int QgsProcessingContextOptionsWidget::maximumThreads() const
   return mThreadsSpinBox->value();
 }
 
-void QgsProcessingContextOptionsWidget::setLogLevel( QgsProcessingContext::LogLevel level )
+void QgsProcessingContextOptionsWidget::setLogLevel( Qgis::ProcessingLogLevel level )
 {
-  whileBlocking( mLogLevelComboBox )->setCurrentIndex( mLogLevelComboBox->findData( static_cast< int >( level ) ) );
+  whileBlocking( mLogLevelComboBox )->setCurrentIndex( mLogLevelComboBox->findData( static_cast<int>( level ) ) );
 }
 
-QgsProcessingContext::LogLevel QgsProcessingContextOptionsWidget::logLevel() const
+Qgis::ProcessingLogLevel QgsProcessingContextOptionsWidget::logLevel() const
 {
-  return static_cast< QgsProcessingContext::LogLevel >( mLogLevelComboBox->currentData().toInt() );
+  return static_cast<Qgis::ProcessingLogLevel>( mLogLevelComboBox->currentData().toInt() );
 }
 
 ///@endcond
