@@ -14,6 +14,7 @@
  ***************************************************************************/
 
 #include "qgsprocessingmeshdatasetwidget.h"
+#include "moc_qgsprocessingmeshdatasetwidget.cpp"
 #include "qgsdatetimeedit.h"
 #include "qgsprocessingmultipleselectiondialog.h"
 #include "qgsprocessingoutputs.h"
@@ -34,8 +35,7 @@
 /// @cond PRIVATE
 
 QgsProcessingMeshDatasetGroupsWidget::QgsProcessingMeshDatasetGroupsWidget( QWidget *parent, const QgsProcessingParameterMeshDatasetGroups *param )
-  : QWidget( parent ),
-    mParam( param )
+  : QWidget( parent ), mParam( param )
 {
   QHBoxLayout *hl = new QHBoxLayout();
   hl->setContentsMargins( 0, 0, 0, 0 );
@@ -55,8 +55,7 @@ QgsProcessingMeshDatasetGroupsWidget::QgsProcessingMeshDatasetGroupsWidget( QWid
   mToolButton->setPopupMode( QToolButton::InstantPopup );
   QMenu *toolButtonMenu = new QMenu( this );
   mActionCurrentActiveDatasetGroups = toolButtonMenu->addAction( tr( "Current Active Dataset Group" ) );
-  connect( mActionCurrentActiveDatasetGroups,
-           &QAction::triggered, this, &QgsProcessingMeshDatasetGroupsWidget::selectCurrentActiveDatasetGroup );
+  connect( mActionCurrentActiveDatasetGroups, &QAction::triggered, this, &QgsProcessingMeshDatasetGroupsWidget::selectCurrentActiveDatasetGroup );
 
   mActionAvailableDatasetGroups = toolButtonMenu->addAction( tr( "Select in Available Dataset Groups" ) );
   connect( mActionAvailableDatasetGroups, &QAction::triggered, this, &QgsProcessingMeshDatasetGroupsWidget::showDialog );
@@ -100,7 +99,7 @@ void QgsProcessingMeshDatasetGroupsWidget::setMeshLayer( QgsMeshLayer *layer, bo
 void QgsProcessingMeshDatasetGroupsWidget::setValue( const QVariant &value )
 {
   if ( value.isValid() )
-    mValue = value.type() == QVariant::List ? value.toList() : QVariantList() << value;
+    mValue = value.userType() == QMetaType::Type::QVariantList ? value.toList() : QVariantList() << value;
   else
     mValue.clear();
 
@@ -146,15 +145,13 @@ void QgsProcessingMeshDatasetGroupsWidget::showDialog()
     QgsProcessingMultipleSelectionPanelWidget *widget = new QgsProcessingMultipleSelectionPanelWidget( availableOptions, mValue );
     widget->setPanelTitle( tr( "Dataset Groups Available" ) );
 
-    widget->setValueFormatter( [availableOptions, options]( const QVariant & v ) -> QString
-    {
+    widget->setValueFormatter( [availableOptions, options]( const QVariant &v ) -> QString {
       const int index = v.toInt();
       const int pos = availableOptions.indexOf( index );
       return ( pos >= 0 && pos < options.size() ) ? options.at( pos ) : QString();
     } );
 
-    connect( widget, &QgsProcessingMultipleSelectionPanelWidget::selectionChanged, this, [ = ]()
-    {
+    connect( widget, &QgsProcessingMultipleSelectionPanelWidget::selectionChanged, this, [=]() {
       setValue( widget->selectedOptions() );
     } );
     connect( widget, &QgsProcessingMultipleSelectionPanelWidget::acceptClicked, widget, &QgsPanelWidget::acceptPanel );
@@ -164,8 +161,7 @@ void QgsProcessingMeshDatasetGroupsWidget::showDialog()
   {
     QgsProcessingMultipleSelectionDialog dlg( availableOptions, mValue, this, Qt::WindowFlags() );
 
-    dlg.setValueFormatter( [datasetGroupsIndexes, options]( const QVariant & v ) -> QString
-    {
+    dlg.setValueFormatter( [datasetGroupsIndexes, options]( const QVariant &v ) -> QString {
       const int index = v.toInt();
       const int pos = datasetGroupsIndexes.indexOf( index );
       return ( pos >= 0 && pos < options.size() ) ? options.at( pos ) : QString();
@@ -197,8 +193,8 @@ void QgsProcessingMeshDatasetGroupsWidget::selectCurrentActiveDatasetGroup()
   setValue( options );
 }
 
-QgsProcessingMeshDatasetGroupsWidgetWrapper::QgsProcessingMeshDatasetGroupsWidgetWrapper( const QgsProcessingParameterDefinition *parameter, QgsProcessingGui::WidgetType type, QWidget *parent ):
-  QgsAbstractProcessingParameterWidgetWrapper( parameter, type, parent )
+QgsProcessingMeshDatasetGroupsWidgetWrapper::QgsProcessingMeshDatasetGroupsWidgetWrapper( const QgsProcessingParameterDefinition *parameter, QgsProcessingGui::WidgetType type, QWidget *parent )
+  : QgsAbstractProcessingParameterWidgetWrapper( parameter, type, parent )
 {}
 
 QString QgsProcessingMeshDatasetGroupsWidgetWrapper::parameterType() const
@@ -226,11 +222,10 @@ void QgsProcessingMeshDatasetGroupsWidgetWrapper::postInitialize( const QList<Qg
     {
       for ( const QgsAbstractProcessingParameterWidgetWrapper *wrapper : wrappers )
       {
-        if ( wrapper->parameterDefinition()->name() == static_cast< const QgsProcessingParameterMeshDatasetGroups * >( parameterDefinition() )->meshLayerParameterName() )
+        if ( wrapper->parameterDefinition()->name() == static_cast<const QgsProcessingParameterMeshDatasetGroups *>( parameterDefinition() )->meshLayerParameterName() )
         {
           setMeshLayerWrapperValue( wrapper );
-          connect( wrapper, &QgsAbstractProcessingParameterWidgetWrapper::widgetValueHasChanged, this, [ = ]
-          {
+          connect( wrapper, &QgsAbstractProcessingParameterWidgetWrapper::widgetValueHasChanged, this, [=] {
             setMeshLayerWrapperValue( wrapper );
           } );
           break;
@@ -245,7 +240,7 @@ void QgsProcessingMeshDatasetGroupsWidgetWrapper::postInitialize( const QList<Qg
 
 void QgsProcessingMeshDatasetGroupsWidgetWrapper::setMeshLayerWrapperValue( const QgsAbstractProcessingParameterWidgetWrapper *wrapper )
 {
-  if ( ! mWidget )
+  if ( !mWidget )
     return;
 
   // evaluate value to layer
@@ -274,21 +269,20 @@ void QgsProcessingMeshDatasetGroupsWidgetWrapper::setMeshLayerWrapperValue( cons
 QStringList QgsProcessingMeshDatasetGroupsWidgetWrapper::compatibleParameterTypes() const
 {
   return QStringList() << QgsProcessingParameterMeshDatasetGroups::typeName()
-         << QgsProcessingParameterString::typeName()
-         << QgsProcessingParameterNumber::typeName();
+                       << QgsProcessingParameterString::typeName()
+                       << QgsProcessingParameterNumber::typeName();
 }
 
 QStringList QgsProcessingMeshDatasetGroupsWidgetWrapper::compatibleOutputTypes() const
 {
   return QStringList() << QgsProcessingOutputString::typeName()
-         << QgsProcessingOutputNumber::typeName();
+                       << QgsProcessingOutputNumber::typeName();
 }
 
 QWidget *QgsProcessingMeshDatasetGroupsWidgetWrapper::createWidget() SIP_FACTORY
 {
   mWidget = new QgsProcessingMeshDatasetGroupsWidget( nullptr, static_cast<const QgsProcessingParameterMeshDatasetGroups *>( parameterDefinition() ) );
-  connect( mWidget, &QgsProcessingMeshDatasetGroupsWidget::changed, this, [ = ]
-  {
+  connect( mWidget, &QgsProcessingMeshDatasetGroupsWidget::changed, this, [=] {
     emit widgetValueHasChanged( this );
   } );
 
@@ -301,7 +295,7 @@ void QgsProcessingMeshDatasetGroupsWidgetWrapper::setWidgetValue( const QVariant
     return;
 
   QList<int> datasetGroupIndexes;
-  if ( value.type() == QVariant::List )
+  if ( value.userType() == QMetaType::Type::QVariantList )
   {
     //here we can't use  QgsProcessingParameters::parameterAsInts() because this method return empry list when first value is 0...
     datasetGroupIndexes = QgsProcessingParameters::parameterAsInts( parameterDefinition(), value, context );
@@ -329,12 +323,9 @@ void QgsProcessingMeshDatasetGroupsWidget::updateSummaryText()
   mLineEdit->setText( tr( "%n option(s) selected", nullptr, mValue.count() ) );
 }
 
-QgsProcessingMeshDatasetTimeWidgetWrapper::QgsProcessingMeshDatasetTimeWidgetWrapper( const QgsProcessingParameterDefinition *parameter,
-    QgsProcessingGui::WidgetType type,
-    QWidget *parent )
+QgsProcessingMeshDatasetTimeWidgetWrapper::QgsProcessingMeshDatasetTimeWidgetWrapper( const QgsProcessingParameterDefinition *parameter, QgsProcessingGui::WidgetType type, QWidget *parent )
   : QgsAbstractProcessingParameterWidgetWrapper( parameter, type, parent )
 {
-
 }
 
 QString QgsProcessingMeshDatasetTimeWidgetWrapper::parameterType() const
@@ -359,16 +350,15 @@ void QgsProcessingMeshDatasetTimeWidgetWrapper::postInitialize( const QList<QgsA
       const QgsAbstractProcessingParameterWidgetWrapper *datasetGroupsParameterWrapper = nullptr;
       for ( const QgsAbstractProcessingParameterWidgetWrapper *wrapper : wrappers )
       {
-        if ( wrapper->parameterDefinition()->name() == static_cast< const QgsProcessingParameterMeshDatasetTime * >( parameterDefinition() )->meshLayerParameterName() )
+        if ( wrapper->parameterDefinition()->name() == static_cast<const QgsProcessingParameterMeshDatasetTime *>( parameterDefinition() )->meshLayerParameterName() )
           layerParameterWrapper = wrapper;
 
-        if ( wrapper->parameterDefinition()->name() == static_cast< const QgsProcessingParameterMeshDatasetTime * >( parameterDefinition() )->datasetGroupParameterName() )
+        if ( wrapper->parameterDefinition()->name() == static_cast<const QgsProcessingParameterMeshDatasetTime *>( parameterDefinition() )->datasetGroupParameterName() )
           datasetGroupsParameterWrapper = wrapper;
       }
       setMeshLayerWrapperValue( layerParameterWrapper );
       setDatasetGroupIndexesWrapperValue( datasetGroupsParameterWrapper );
-      connect( datasetGroupsParameterWrapper, &QgsAbstractProcessingParameterWidgetWrapper::widgetValueHasChanged, this, [ = ]
-      {
+      connect( datasetGroupsParameterWrapper, &QgsAbstractProcessingParameterWidgetWrapper::widgetValueHasChanged, this, [=] {
         setMeshLayerWrapperValue( layerParameterWrapper );
         setDatasetGroupIndexesWrapperValue( datasetGroupsParameterWrapper );
       } );
@@ -420,7 +410,7 @@ void QgsProcessingMeshDatasetTimeWidgetWrapper::setDatasetGroupIndexesWrapperVal
 
   QVariant datasetGroupsVariant = wrapper->parameterValue();
 
-  if ( !datasetGroupsVariant.isValid() || datasetGroupsVariant.type() != QVariant::List )
+  if ( !datasetGroupsVariant.isValid() || datasetGroupsVariant.userType() != QMetaType::Type::QVariantList )
     mWidget->setDatasetGroupIndexes( QList<int>() );
 
   QVariantList datasetGroupsListVariant = datasetGroupsVariant.toList();
@@ -430,7 +420,6 @@ void QgsProcessingMeshDatasetTimeWidgetWrapper::setDatasetGroupIndexesWrapperVal
     datasetGroupsIndexes << variantIndex.toInt();
 
   mWidget->setDatasetGroupIndexes( datasetGroupsIndexes );
-
 }
 
 QStringList QgsProcessingMeshDatasetTimeWidgetWrapper::compatibleParameterTypes() const
@@ -456,8 +445,7 @@ QWidget *QgsProcessingMeshDatasetTimeWidgetWrapper::createWidget()
   {
     connect( canvas, &QgsMapCanvas::temporalRangeChanged, mWidget, &QgsProcessingMeshDatasetTimeWidget::updateValue );
   }
-  connect( mWidget, &QgsProcessingMeshDatasetTimeWidget::changed, this, [ = ]
-  {
+  connect( mWidget, &QgsProcessingMeshDatasetTimeWidget::changed, this, [=] {
     emit widgetValueHasChanged( this );
   } );
 
@@ -478,11 +466,8 @@ QVariant QgsProcessingMeshDatasetTimeWidgetWrapper::widgetValue() const
   return QVariant();
 }
 
-QgsProcessingMeshDatasetTimeWidget::QgsProcessingMeshDatasetTimeWidget( QWidget *parent,
-    const QgsProcessingParameterMeshDatasetTime *param,
-    const QgsProcessingParameterWidgetContext &context ):
-  QWidget( parent ),
-  mParam( param )
+QgsProcessingMeshDatasetTimeWidget::QgsProcessingMeshDatasetTimeWidget( QWidget *parent, const QgsProcessingParameterMeshDatasetTime *param, const QgsProcessingParameterWidgetContext &context )
+  : QWidget( parent ), mParam( param )
 {
   setupUi( this );
 
@@ -492,12 +477,11 @@ QgsProcessingMeshDatasetTimeWidget::QgsProcessingMeshDatasetTimeWidget( QWidget
 
   mCanvas = context.mapCanvas();
 
-  connect( radioButtonCurrentCanvasTime, &QRadioButton::toggled, this, [this]( bool isChecked ) {if ( isChecked ) this->updateValue();} );
-  connect( radioButtonDefinedDateTime, &QRadioButton::toggled, this, [this]( bool isChecked ) {if ( isChecked ) this->updateValue();} );
-  connect( radioButtonDatasetGroupTimeStep, &QRadioButton::toggled, this, [this]( bool isChecked ) {if ( isChecked ) this->updateValue();} );
+  connect( radioButtonCurrentCanvasTime, &QRadioButton::toggled, this, [this]( bool isChecked ) {if ( isChecked ) this->updateValue(); } );
+  connect( radioButtonDefinedDateTime, &QRadioButton::toggled, this, [this]( bool isChecked ) {if ( isChecked ) this->updateValue(); } );
+  connect( radioButtonDatasetGroupTimeStep, &QRadioButton::toggled, this, [this]( bool isChecked ) {if ( isChecked ) this->updateValue(); } );
   connect( dateTimeEdit, &QgsDateTimeEdit::dateTimeChanged, this, &QgsProcessingMeshDatasetTimeWidget::updateValue );
-  connect( comboBoxDatasetTimeStep, qOverload<int>( &QComboBox::currentIndexChanged ),
-           this, &QgsProcessingMeshDatasetTimeWidget::updateValue );
+  connect( comboBoxDatasetTimeStep, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsProcessingMeshDatasetTimeWidget::updateValue );
 
   updateWidget();
 }
@@ -539,7 +523,7 @@ void QgsProcessingMeshDatasetTimeWidget::setDatasetGroupIndexes( const QList<int
 
 void QgsProcessingMeshDatasetTimeWidget::setValue( const QVariant &value )
 {
-  if ( !value.isValid() || ( value.type() != QVariant::Map && !value.toDateTime().isValid() ) )
+  if ( !value.isValid() || ( value.userType() != QMetaType::Type::QVariantMap && !value.toDateTime().isValid() ) )
     return;
 
   mValue.clear();
@@ -593,7 +577,7 @@ void QgsProcessingMeshDatasetTimeWidget::updateWidget()
   bool isStatic = !hasTemporalDataset();
   setEnabled( !isStatic );
 
-  if ( mCanvas != nullptr  && mCanvas->mapSettings().isTemporal() )
+  if ( mCanvas && mCanvas->mapSettings().isTemporal() )
   {
     whileBlocking( radioButtonCurrentCanvasTime )->setEnabled( true && mReferenceTime.isValid() );
     labelCurrentCanvasTime->setText( mCanvas->mapSettings().temporalRange().begin().toString( "yyyy-MM-dd HH:mm:ss" ) );
@@ -605,7 +589,7 @@ void QgsProcessingMeshDatasetTimeWidget::updateWidget()
       whileBlocking( radioButtonDefinedDateTime )->setChecked( true );
   }
 
-  if ( ! mReferenceTime.isValid() )
+  if ( !mReferenceTime.isValid() )
     whileBlocking( radioButtonDatasetGroupTimeStep )->setChecked( true );
 
   whileBlocking( radioButtonDefinedDateTime )->setEnabled( mReferenceTime.isValid() );
@@ -660,7 +644,6 @@ void QgsProcessingMeshDatasetTimeWidget::populateTimeSteps()
     data << index.group() << index.dataset();
     whileBlocking( comboBoxDatasetTimeStep )->addItem( stringTime, data );
   }
-
 }
 
 void QgsProcessingMeshDatasetTimeWidget::populateTimeStepsFromLayer()
@@ -756,7 +739,8 @@ QgsProcessingMeshDatasetGroupsParameterDefinitionWidget::QgsProcessingMeshDatase
   const QgsProcessingParameterWidgetContext &widgetContext,
   const QgsProcessingParameterDefinition *definition,
   const QgsProcessingAlgorithm *algorithm,
-  QWidget *parent )
+  QWidget *parent
+)
   : QgsProcessingAbstractParameterDefinitionWidget( context, widgetContext, definition, algorithm, parent )
 {
   QVBoxLayout *vlayout = new QVBoxLayout();
@@ -780,8 +764,7 @@ QgsProcessingMeshDatasetGroupsParameterDefinitionWidget::QgsProcessingMeshDatase
     }
   }
 
-  const QgsProcessingParameterMeshDatasetGroups *datasetGroupDef =
-    static_cast< const QgsProcessingParameterMeshDatasetGroups *>( definition );
+  const QgsProcessingParameterMeshDatasetGroups *datasetGroupDef = static_cast<const QgsProcessingParameterMeshDatasetGroups *>( definition );
   if ( datasetGroupDef )
   {
     int currentIndex = mParentLayerComboBox->findData( datasetGroupDef->meshLayerParameterName() );
@@ -801,15 +784,15 @@ QgsProcessingMeshDatasetGroupsParameterDefinitionWidget::QgsProcessingMeshDatase
 QgsProcessingParameterDefinition *QgsProcessingMeshDatasetGroupsParameterDefinitionWidget::createParameter(
   const QString &name,
   const QString &description,
-  QgsProcessingParameterDefinition::Flags flags ) const
+  Qgis::ProcessingParameterFlags flags
+) const
 {
   QSet<int> supportedDataType;
   supportedDataType.insert( QgsMeshDatasetGroupMetadata::DataOnEdges );
   supportedDataType.insert( QgsMeshDatasetGroupMetadata::DataOnVertices );
   supportedDataType.insert( QgsMeshDatasetGroupMetadata::DataOnFaces );
   supportedDataType.insert( QgsMeshDatasetGroupMetadata::DataOnVolumes );
-  std::unique_ptr<QgsProcessingParameterMeshDatasetGroups> param =
-    std::make_unique<QgsProcessingParameterMeshDatasetGroups>( name, description, mParentLayerComboBox->currentData().toString(), supportedDataType );
+  std::unique_ptr<QgsProcessingParameterMeshDatasetGroups> param = std::make_unique<QgsProcessingParameterMeshDatasetGroups>( name, description, mParentLayerComboBox->currentData().toString(), supportedDataType );
   param->setFlags( flags );
   return param.release();
 }
@@ -819,13 +802,13 @@ QgsProcessingMeshDatasetTimeParameterDefinitionWidget::QgsProcessingMeshDatasetT
   const QgsProcessingParameterWidgetContext &widgetContext,
   const QgsProcessingParameterDefinition *definition,
   const QgsProcessingAlgorithm *algorithm,
-  QWidget *parent )
+  QWidget *parent
+)
   : QgsProcessingAbstractParameterDefinitionWidget( context, widgetContext, definition, algorithm, parent )
 {
   if ( definition )
   {
-    const QgsProcessingParameterMeshDatasetTime *datasetTimeDef =
-      static_cast< const QgsProcessingParameterMeshDatasetTime *>( definition );
+    const QgsProcessingParameterMeshDatasetTime *datasetTimeDef = static_cast<const QgsProcessingParameterMeshDatasetTime *>( definition );
     mMeshLayerParameterName = datasetTimeDef->meshLayerParameterName();
   }
 
@@ -851,8 +834,7 @@ QgsProcessingMeshDatasetTimeParameterDefinitionWidget::QgsProcessingMeshDatasetT
 
   if ( definition )
   {
-    const QgsProcessingParameterMeshDatasetTime *datasetTimeDef =
-      static_cast< const QgsProcessingParameterMeshDatasetTime *>( definition );
+    const QgsProcessingParameterMeshDatasetTime *datasetTimeDef = static_cast<const QgsProcessingParameterMeshDatasetTime *>( definition );
     int currentIndex = mParentDatasetComboBox->findData( datasetTimeDef->datasetGroupParameterName() );
     if ( currentIndex != -1 )
       mParentDatasetComboBox->setCurrentIndex( currentIndex );
@@ -870,8 +852,7 @@ QgsProcessingMeshDatasetTimeParameterDefinitionWidget::QgsProcessingMeshDatasetT
     if ( currentDef )
       mMeshLayerParameterName = static_cast<const QgsProcessingParameterMeshDatasetGroups *>( currentDef )->meshLayerParameterName();
 
-    connect( mParentDatasetComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [this, model]
-    {
+    connect( mParentDatasetComboBox, qOverload<int>( &QComboBox::currentIndexChanged ), this, [this, model] {
       const QgsProcessingParameterDefinition *currentDef = model->parameterDefinition( mParentDatasetComboBox->currentData().toString() );
       if ( currentDef )
         mMeshLayerParameterName = static_cast<const QgsProcessingParameterMeshDatasetGroups *>( currentDef )->meshLayerParameterName();
@@ -881,10 +862,11 @@ QgsProcessingMeshDatasetTimeParameterDefinitionWidget::QgsProcessingMeshDatasetT
   setLayout( vlayout );
 }
 
-QgsProcessingParameterDefinition *QgsProcessingMeshDatasetTimeParameterDefinitionWidget::createParameter( const QString &name, const QString &description, QgsProcessingParameterDefinition::Flags flags ) const
+QgsProcessingParameterDefinition *QgsProcessingMeshDatasetTimeParameterDefinitionWidget::createParameter( const QString &name, const QString &description, Qgis::ProcessingParameterFlags flags ) const
 {
   std::unique_ptr<QgsProcessingParameterMeshDatasetTime> param = std::make_unique<QgsProcessingParameterMeshDatasetTime>(
-        name, description, mMeshLayerParameterName, mParentDatasetComboBox->currentData().toString() );
+    name, description, mMeshLayerParameterName, mParentDatasetComboBox->currentData().toString()
+  );
 
   param->setFlags( flags );
   return param.release();
