@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsgdalguiprovider.h"
+#include "moc_qgsgdalguiprovider.cpp"
 ///@cond PRIVATE
 
 #include <QList>
@@ -35,6 +36,7 @@
 #include "qgsgdalfilesourcewidget.h"
 #include "qgsabstractdatabaseproviderconnection.h"
 #include "qgslayeritem.h"
+#include "qgsgdalclouddataitemguiprovider.h"
 
 static QString PROVIDER_KEY = QStringLiteral( "gdal" );
 
@@ -53,7 +55,7 @@ void QgsGdalItemGuiProvider::onDeletePostgresRasterLayer( QgsDataItemGuiContext
   QVariantMap data = s->data().toMap();
   const QString uri = data[QStringLiteral( "uri" )].toString();
   const QString path = data[QStringLiteral( "path" )].toString();
-  const QPointer< QgsDataItem > parent = data[QStringLiteral( "parentItem" )].value<QPointer< QgsDataItem >>();
+  const QPointer<QgsDataItem> parent = data[QStringLiteral( "parentItem" )].value<QPointer<QgsDataItem>>();
 
   const QString title = tr( "Delete Table" );
 
@@ -68,13 +70,11 @@ void QgsGdalItemGuiProvider::onDeletePostgresRasterLayer( QgsDataItemGuiContext
     }
   }
 
-  if ( ! projectLayer )
+  if ( !projectLayer )
   {
     const QString confirmMessage = tr( "Are you sure you want to delete table “%1”?" ).arg( path );
 
-    if ( QMessageBox::question( nullptr, title,
-                                confirmMessage,
-                                QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
+    if ( QMessageBox::question( nullptr, title, confirmMessage, QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) != QMessageBox::Yes )
       return;
 
     QString errorMessage;
@@ -101,7 +101,6 @@ void QgsGdalItemGuiProvider::onDeletePostgresRasterLayer( QgsDataItemGuiContext
 
           connection->dropRasterTable( schema, dsUri.table() );
           deleted = true;
-
         }
         catch ( QgsProviderConnectionException &ex )
         {
@@ -126,15 +125,15 @@ void QgsGdalItemGuiProvider::onDeletePostgresRasterLayer( QgsDataItemGuiContext
     }
     else
     {
-      notify( title, errorMessage.isEmpty() ?
-              tr( "Could not delete table." ) :
-              tr( "Could not delete table, reason: %1." ).arg( errorMessage ), context, Qgis::MessageLevel::Warning );
+      notify( title, errorMessage.isEmpty() ? tr( "Could not delete table." ) : tr( "Could not delete table, reason: %1." ).arg( errorMessage ), context, Qgis::MessageLevel::Warning );
     }
   }
   else
   {
     notify( title, tr( "The layer “%1” cannot be deleted because it is in the current project as “%2”,"
-                       " remove it from the project and retry." ).arg( path, projectLayer->name() ), context, Qgis::MessageLevel::Warning );
+                       " remove it from the project and retry." )
+                     .arg( path, projectLayer->name() ),
+            context, Qgis::MessageLevel::Warning );
   }
 }
 
@@ -142,7 +141,7 @@ void QgsGdalItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu *menu
 {
   Q_UNUSED( selectedItems )
 
-  if ( QgsLayerItem *layerItem = qobject_cast< QgsLayerItem * >( item ) )
+  if ( QgsLayerItem *layerItem = qobject_cast<QgsLayerItem *>( item ) )
   {
     if ( layerItem->providerKey() == QLatin1String( "gdal" ) )
     {
@@ -156,9 +155,9 @@ void QgsGdalItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu *menu
         QVariantMap data;
         data.insert( QStringLiteral( "uri" ), layerItem->uri() );
         data.insert( QStringLiteral( "path" ), layerItem->name() );
-        data.insert( QStringLiteral( "parentItem" ), QVariant::fromValue( QPointer< QgsDataItem >( layerItem->parent() ) ) );
+        data.insert( QStringLiteral( "parentItem" ), QVariant::fromValue( QPointer<QgsDataItem>( layerItem->parent() ) ) );
         actionDeleteLayer->setData( data );
-        connect( actionDeleteLayer, &QAction::triggered, this, [ = ] { onDeletePostgresRasterLayer( context ); } );
+        connect( actionDeleteLayer, &QAction::triggered, this, [=] { onDeletePostgresRasterLayer( context ); } );
         menu->addAction( actionDeleteLayer );
       }
     }
@@ -169,7 +168,6 @@ void QgsGdalItemGuiProvider::populateContextMenu( QgsDataItem *item, QMenu *menu
 class QgsGdalRasterSourceSelectProvider : public QgsSourceSelectProvider
 {
   public:
-
     QString providerKey() const override { return QStringLiteral( "gdal" ); }
     QString text() const override { return QObject::tr( "Raster" ); }
     int ordering() const override { return QgsSourceSelectProvider::OrderLocalProvider + 20; }
@@ -178,6 +176,10 @@ class QgsGdalRasterSourceSelectProvider : public QgsSourceSelectProvider
     {
       return new QgsGdalSourceSelect( parent, fl, widgetMode );
     }
+    QgsSourceSelectProvider::Capabilities capabilities() override
+    {
+      return QgsSourceSelectProvider::Capability::ConfigureFromUri;
+    };
 };
 
 //
@@ -186,7 +188,6 @@ class QgsGdalRasterSourceSelectProvider : public QgsSourceSelectProvider
 
 QgsGdalSourceWidgetProvider::QgsGdalSourceWidgetProvider()
 {
-
 }
 
 QString QgsGdalSourceWidgetProvider::providerKey() const
@@ -222,8 +223,8 @@ QgsProviderSourceWidget *QgsGdalSourceWidgetProvider::createWidget( QgsMapLayer
 //
 // QgsGdalGuiProviderMetadata
 //
-QgsGdalGuiProviderMetadata::QgsGdalGuiProviderMetadata():
-  QgsProviderGuiMetadata( PROVIDER_KEY )
+QgsGdalGuiProviderMetadata::QgsGdalGuiProviderMetadata()
+  : QgsProviderGuiMetadata( PROVIDER_KEY )
 {
 }
 
@@ -236,9 +237,10 @@ QList<QgsSourceSelectProvider *> QgsGdalGuiProviderMetadata::sourceSelectProvide
 
 QList<QgsDataItemGuiProvider *> QgsGdalGuiProviderMetadata::dataItemGuiProviders()
 {
-  QList<QgsDataItemGuiProvider *> providers;
-  providers << new QgsGdalItemGuiProvider();
-  return providers;
+  return {
+    new QgsGdalItemGuiProvider(),
+    new QgsGdalCloudDataItemGuiProvider()
+  };
 }
 
 QList<QgsProviderSourceWidgetProvider *> QgsGdalGuiProviderMetadata::sourceWidgetProviders()
