@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgscheckablecombobox.h"
+#include "moc_qgscheckablecombobox.cpp"
 #include "qgsapplication.h"
 
 #include <QEvent>
@@ -49,7 +50,7 @@ QVariant QgsCheckableItemModel::data( const QModelIndex &index, int role ) const
 
 bool QgsCheckableItemModel::setData( const QModelIndex &index, const QVariant &value, int role )
 {
-  bool ok = QStandardItemModel::setData( index, value, role );
+  const bool ok = QStandardItemModel::setData( index, value, role );
 
   if ( ok && role == Qt::CheckStateRole )
   {
@@ -76,9 +77,10 @@ void QgsCheckBoxDelegate::paint( QPainter *painter, const QStyleOptionViewItem &
 
 QgsCheckableComboBox::QgsCheckableComboBox( QWidget *parent )
   : QComboBox( parent )
+  , mModel( new QgsCheckableItemModel( this ) )
   , mSeparator( QStringLiteral( ", " ) )
 {
-  setModel( new QgsCheckableItemModel( this ) );
+  setModel( mModel );
   setItemDelegate( new QgsCheckBoxDelegate( this ) );
 
   QLineEdit *lineEdit = new QLineEdit( this );
@@ -87,6 +89,9 @@ QgsCheckableComboBox::QgsCheckableComboBox( QWidget *parent )
   pal.setBrush( QPalette::Base, pal.button() );
   lineEdit->setPalette( pal );
   setLineEdit( lineEdit );
+  lineEdit->installEventFilter( this );
+  lineEdit->setContextMenuPolicy( Qt::CustomContextMenu );
+  connect( lineEdit, &QAbstractItemView::customContextMenuRequested, this, &QgsCheckableComboBox::showContextMenu );
 
   mContextMenu = new QMenu( this );
   mSelectAllAction = mContextMenu->addAction( tr( "Select All" ) );
@@ -98,9 +103,9 @@ QgsCheckableComboBox::QgsCheckableComboBox( QWidget *parent )
   view()->setContextMenuPolicy( Qt::CustomContextMenu );
   connect( view(), &QAbstractItemView::customContextMenuRequested, this, &QgsCheckableComboBox::showContextMenu );
 
-  connect( model(), &QStandardItemModel::rowsInserted, this, [ = ]( const QModelIndex &, int, int ) { updateDisplayText(); } );
-  connect( model(), &QStandardItemModel::rowsRemoved, this, [ = ]( const QModelIndex &, int, int ) { updateDisplayText(); } );
-  connect( model(), &QStandardItemModel::dataChanged, this, [ = ]( const QModelIndex &, const QModelIndex &, const QVector< int > & ) { updateDisplayText(); } );
+  connect( model(), &QStandardItemModel::rowsInserted, this, [=]( const QModelIndex &, int, int ) { updateDisplayText(); } );
+  connect( model(), &QStandardItemModel::rowsRemoved, this, [=]( const QModelIndex &, int, int ) { updateDisplayText(); } );
+  connect( model(), &QStandardItemModel::dataChanged, this, [=]( const QModelIndex &, const QModelIndex &, const QVector<int> & ) { updateDisplayText(); } );
 }
 
 QString QgsCheckableComboBox::separator() const
@@ -131,14 +136,20 @@ void QgsCheckableComboBox::setDefaultText( const QString &text )
   }
 }
 
+void QgsCheckableComboBox::addItemWithCheckState( const QString &text, Qt::CheckState state, const QVariant &userData )
+{
+  QComboBox::addItem( text, userData );
+  setItemCheckState( count() - 1, state );
+}
+
 QStringList QgsCheckableComboBox::checkedItems() const
 {
   QStringList items;
 
-  if ( model() )
+  if ( auto *lModel = model() )
   {
-    QModelIndex index = model()->index( 0, modelColumn(), rootModelIndex() );
-    QModelIndexList indexes = model()->match( index, Qt::CheckStateRole, Qt::Checked, -1, Qt::MatchExactly );
+    const QModelIndex index = lModel->index( 0, modelColumn(), rootModelIndex() );
+    const QModelIndexList indexes = lModel->match( index, Qt::CheckStateRole, Qt::Checked, -1, Qt::MatchExactly );
     const auto constIndexes = indexes;
     for ( const QModelIndex &index : constIndexes )
     {
@@ -149,6 +160,24 @@ QStringList QgsCheckableComboBox::checkedItems() const
   return items;
 }
 
+QVariantList QgsCheckableComboBox::checkedItemsData() const
+{
+  QVariantList data;
+
+  if ( auto *lModel = model() )
+  {
+    const QModelIndex index = lModel->index( 0, modelColumn(), rootModelIndex() );
+    const QModelIndexList indexes = lModel->match( index, Qt::CheckStateRole, Qt::Checked, -1, Qt::MatchExactly );
+    const auto constIndexes = indexes;
+    for ( const QModelIndex &index : constIndexes )
+    {
+      data += index.data( Qt::UserRole ).toString();
+    }
+  }
+
+  return data;
+}
+
 Qt::CheckState QgsCheckableComboBox::itemCheckState( int index ) const
 {
   return static_cast<Qt::CheckState>( itemData( index, Qt::CheckStateRole ).toInt() );
@@ -161,12 +190,13 @@ void QgsCheckableComboBox::setItemCheckState( int index, Qt::CheckState state )
 
 void QgsCheckableComboBox::toggleItemCheckState( int index )
 {
-  QVariant value = itemData( index, Qt::CheckStateRole );
+  const QVariant value = itemData( index, Qt::CheckStateRole );
   if ( value.isValid() )
   {
-    Qt::CheckState state = static_cast<Qt::CheckState>( value.toInt() );
+    const Qt::CheckState state = static_cast<Qt::CheckState>( value.toInt() );
     setItemData( index, ( state == Qt::Unchecked ? Qt::Checked : Qt::Unchecked ), Qt::CheckStateRole );
   }
+  updateCheckedItems();
 }
 
 void QgsCheckableComboBox::hidePopup()
@@ -188,7 +218,7 @@ void QgsCheckableComboBox::showContextMenu( QPoint pos )
 void QgsCheckableComboBox::selectAllOptions()
 {
   blockSignals( true );
-  for ( int i = 0;  i < count(); i++ )
+  for ( int i = 0; i < count(); i++ )
   {
     setItemData( i, Qt::Checked, Qt::CheckStateRole );
   }
@@ -199,7 +229,7 @@ void QgsCheckableComboBox::selectAllOptions()
 void QgsCheckableComboBox::deselectAllOptions()
 {
   blockSignals( true );
-  for ( int i = 0;  i < count(); i++ )
+  for ( int i = 0; i < count(); i++ )
   {
     setItemData( i, Qt::Unchecked, Qt::CheckStateRole );
   }
@@ -209,8 +239,16 @@ void QgsCheckableComboBox::deselectAllOptions()
 
 bool QgsCheckableComboBox::eventFilter( QObject *object, QEvent *event )
 {
-  if ( ( event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonRelease )
-       && object == view()->viewport() )
+  if ( object == lineEdit() )
+  {
+    if ( event->type() == QEvent::MouseButtonPress && static_cast<QMouseEvent *>( event )->button() == Qt::LeftButton && object == lineEdit() )
+    {
+      mSkipHide = true;
+      showPopup();
+    }
+  }
+  else if ( ( event->type() == QEvent::MouseButtonPress || event->type() == QEvent::MouseButtonRelease )
+            && object == view()->viewport() )
   {
     mSkipHide = true;
 
@@ -221,12 +259,13 @@ bool QgsCheckableComboBox::eventFilter( QObject *object, QEvent *event )
 
     if ( event->type() == QEvent::MouseButtonRelease )
     {
-      QModelIndex index = view()->indexAt( static_cast<QMouseEvent *>( event )->pos() );
+      const QModelIndex index = view()->indexAt( static_cast<QMouseEvent *>( event )->pos() );
       if ( index.isValid() )
       {
         QgsCheckableItemModel *myModel = qobject_cast<QgsCheckableItemModel *>( model() );
         QStandardItem *item = myModel->itemFromIndex( index );
-        item->checkState() == Qt::Checked ? item->setCheckState( Qt::Unchecked ) : item->setCheckState( Qt::Checked );
+        item->setCheckState( item->checkState() == Qt::Checked ? Qt::Unchecked : Qt::Checked );
+        updateCheckedItems();
       }
       return true;
     }
@@ -254,15 +293,19 @@ void QgsCheckableComboBox::resizeEvent( QResizeEvent *event )
 
 void QgsCheckableComboBox::updateCheckedItems()
 {
-  QStringList items = checkedItems();
+  const QStringList items = checkedItems();
   updateDisplayText();
   emit checkedItemsChanged( items );
 }
 
 void QgsCheckableComboBox::updateDisplayText()
 {
+  // There is only a line edit if the combobox is in editable state
+  if ( !lineEdit() )
+    return;
+
   QString text;
-  QStringList items = checkedItems();
+  const QStringList items = checkedItems();
   if ( items.isEmpty() )
   {
     text = mDefaultText;
@@ -272,8 +315,8 @@ void QgsCheckableComboBox::updateDisplayText()
     text = items.join( mSeparator );
   }
 
-  QRect rect = lineEdit()->rect();
-  QFontMetrics fontMetrics( font() );
+  const QRect rect = lineEdit()->rect();
+  const QFontMetrics fontMetrics( font() );
   text = fontMetrics.elidedText( text, Qt::ElideRight, rect.width() );
   setEditText( text );
 }
