@@ -34,7 +34,7 @@
 #include <QDomDocument>
 #include <QGraphicsView>
 
-#include "qgsmapsettings.h" // TEMPORARY
+#include "qgsmapsettings.h"   // TEMPORARY
 #include "qgsprevieweffect.h" //for QgsPreviewEffect::PreviewMode
 
 #include <QTimer>
@@ -73,6 +73,7 @@ class QgsMapCanvasAnnotationItem;
 class QgsReferencedRectangle;
 class QgsRenderedItemResults;
 class QgsTemporaryCursorOverride;
+class QgsOverlayWidgetLayout;
 
 class QgsTemporalController;
 class QgsScreenHelper;
@@ -90,7 +91,6 @@ class QgsMapMouseEvent;
 
 class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContextGenerator
 {
-
 #ifdef SIP_RUN
     SIP_CONVERT_TO_SUBCLASS_CODE
     if ( qobject_cast<QgsMapCanvas *>( sipCpp ) != nullptr )
@@ -105,15 +105,25 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     Q_PROPERTY( bool previewJobsEnabled READ previewJobsEnabled WRITE setPreviewJobsEnabled )
 
   public:
-
     //! Constructor
     QgsMapCanvas( QWidget *parent SIP_TRANSFERTHIS = nullptr );
 
     ~QgsMapCanvas() override;
 
+    /**
+     * Adds an overlay \a widget to the layout, which will be bound to the specified \a edge.
+     *
+     * The widget will always float above the map canvas.
+     *
+     * \note Widgets on the left and right edges will always be positioned first, with
+     * top and bottom edge widgets expanding to take the remaining horizontal space.
+     *
+     * \since QGIS 3.38
+     */
+    void addOverlayWidget( QWidget *widget SIP_TRANSFER, Qt::Edge edge );
+
     /**
      * Returns the magnification factor
-     * \since QGIS 2.16
      */
     double magnificationFactor() const;
 
@@ -126,15 +136,29 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * empty string before setLayers() calls can be made.
      *
      * \see layers()
-     * \since QGIS 3.0
      */
     void setLayers( const QList<QgsMapLayer *> &layers );
 
+    /**
+     * Sets \a flags which control how the map canvas behaves.
+     *
+     * \see flags()
+     * \since QGIS 3.40
+     */
+    void setFlags( Qgis::MapCanvasFlags flags );
+
+    /**
+     * Returns flags which control how the map canvas behaves.
+     *
+     * \see setFlags()
+     * \since QGIS 3.40
+     */
+    Qgis::MapCanvasFlags flags() const;
+
     void setCurrentLayer( QgsMapLayer *layer );
 
     /**
      * Gets access to properties used for map rendering
-     * \since QGIS 2.4
      */
     const QgsMapSettings &mapSettings() const SIP_KEEPREFERENCE;
 
@@ -164,13 +188,11 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     /**
      * Sets destination coordinate reference system
-     * \since QGIS 2.4
      */
     void setDestinationCrs( const QgsCoordinateReferenceSystem &crs );
 
     /**
      * Resets the \a flags for the canvas' map settings.
-     * \since QGIS 3.0
      */
     void setMapSettingsFlags( Qgis::MapSettingsFlags flags );
 
@@ -180,7 +202,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * Since QGIS 3.20, if the \a allowOutdatedResults flag is FALSE then outdated labeling results (e.g.
      * as a result of an ongoing canvas render) will not be returned, and instead NULLPTR will be returned.
      *
-     * \since QGIS 2.4
      */
     const QgsLabelingResults *labelingResults( bool allowOutdatedResults = true ) const;
 
@@ -201,7 +222,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \see isCachingEnabled()
      * \see cache()
      *
-     * \since QGIS 2.4
      */
     void setCachingEnabled( bool enabled );
 
@@ -211,13 +231,11 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \see setCachingEnabled()
      * \see cache()
      *
-     * \since QGIS 2.4
      */
     bool isCachingEnabled() const;
 
     /**
      * Make sure to remove any rendered images from cache (does nothing if cache is not enabled)
-     * \since QGIS 2.4
      */
     void clearCache();
 
@@ -244,31 +262,26 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * until the rendering job is complete. It's included in API solely for
      * unit testing and standalone Python scripts.
      *
-     * \since QGIS 3.0
      */
     void waitWhileRendering();
 
     /**
      * Set whether the layers are rendered in parallel or sequentially
-     * \since QGIS 2.4
      */
     void setParallelRenderingEnabled( bool enabled );
 
     /**
      * Check whether the layers are rendered in parallel or sequentially
-     * \since QGIS 2.4
      */
     bool isParallelRenderingEnabled() const;
 
     /**
      * Set how often map preview should be updated while it is being rendered (in milliseconds)
-     * \since QGIS 2.4
      */
     void setMapUpdateInterval( int timeMilliseconds );
 
     /**
      * Find out how often map preview should be updated while it is being rendered (in milliseconds)
-     * \since QGIS 2.4
      */
     int mapUpdateInterval() const;
 
@@ -330,25 +343,21 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     /**
      * Gets the current map canvas rotation in clockwise degrees
-     * \since QGIS 2.8
      */
     double rotation() const;
 
     /**
      * Set the rotation of the map canvas in clockwise degrees
-     * \since QGIS 2.8
      */
     void setRotation( double degrees );
 
     /**
      * Set the center of the map canvas, in geographical coordinates
-     * \since QGIS 2.8
      */
     void setCenter( const QgsPointXY &center );
 
     /**
      * Gets map center, in geographical coordinates
-     * \since QGIS 2.8
      */
     QgsPointXY center() const;
 
@@ -414,11 +423,8 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \note If the features or geometries are already available, flashGeometries() is much more efficient.
      *
      * \see flashGeometries()
-     * \since QGIS 3.0
      */
-    void flashFeatureIds( QgsVectorLayer *layer, const QgsFeatureIds &ids,
-                          const QColor &startColor = QColor( 255, 0, 0, 255 ), const QColor &endColor = QColor( 255, 0, 0, 0 ),
-                          int flashes = 3, int duration = 500 );
+    void flashFeatureIds( QgsVectorLayer *layer, const QgsFeatureIds &ids, const QColor &startColor = QColor( 255, 0, 0, 255 ), const QColor &endColor = QColor( 255, 0, 0, 0 ), int flashes = 3, int duration = 500 );
 
     /**
      * Causes a set of \a geometries to flash within the canvas.
@@ -430,11 +436,8 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \a flashes and \a duration of each flash (in milliseconds).
      *
      * \see flashFeatureIds()
-     * \since QGIS 3.0
      */
-    void flashGeometries( const QList< QgsGeometry > &geometries, const QgsCoordinateReferenceSystem &crs = QgsCoordinateReferenceSystem(),
-                          const QColor &startColor = QColor( 255, 0, 0, 255 ), const QColor &endColor = QColor( 255, 0, 0, 0 ),
-                          int flashes = 3, int duration = 500 );
+    void flashGeometries( const QList<QgsGeometry> &geometries, const QgsCoordinateReferenceSystem &crs = QgsCoordinateReferenceSystem(), const QColor &startColor = QColor( 255, 0, 0, 255 ), const QColor &endColor = QColor( 255, 0, 0, 0 ), int flashes = 3, int duration = 500 );
 
     //! Sets the map tool currently being used on the canvas
     void setMapTool( QgsMapTool *mapTool, bool clean = false );
@@ -449,7 +452,7 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     void unsetMapTool( QgsMapTool *mapTool );
 
     //! Returns the currently active tool
-    QgsMapTool *mapTool();
+    QgsMapTool *mapTool() const;
 
     /**
      * Sets the \a project linked to this canvas.
@@ -473,13 +476,11 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     /**
      * Set color of selected vector features
-     * \since QGIS 2.4
      */
     void setSelectionColor( const QColor &color );
 
     /**
      * Returns color for selected features
-     * \since QGIS 3.0
      */
     QColor selectionColor() const;
 
@@ -516,6 +517,17 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      */
     QList<QgsMapLayer *> layers( bool expandGroupLayers = false ) const;
 
+#ifndef SIP_RUN
+    /**
+     * Returns a list of registered map layers with a specified layer type.
+     *
+     * \note not available in Python bindings
+     * \since QGIS 3.40
+     */
+    template<typename T>
+    QVector<T> layers() const { return mapSettings().layers<T>(); }
+#endif
+
     /**
      * Freeze/thaw the map canvas. This is used to prevent the canvas from
      * responding to events while layers are being added/removed etc.
@@ -555,7 +567,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     /**
      * Returns the stored overrides of styles for layers.
      * \see setLayerStyleOverrides().
-     * \since QGIS 2.12
      */
     QMap<QString, QString> layerStyleOverrides() const;
 
@@ -568,7 +579,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * empty string before setLayerStyleOverrides() calls can be made.
      *
      * \see layerStyleOverrides()
-     * \since QGIS 2.12
      */
     void setLayerStyleOverrides( const QMap<QString, QString> &overrides );
 
@@ -588,14 +598,12 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * If an empty string is passed then the current theme association will be
      * cleared.
      * \see theme()
-     * \since QGIS 3.0
      */
     void setTheme( const QString &theme );
 
     /**
      * Returns the map's theme shown in the canvas, if set.
      * \see setTheme()
-     * \since QGIS 3.0
      */
     QString theme() const { return mTheme; }
 
@@ -641,9 +649,8 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     /**
      * Returns whether the scale is locked, so zooming can be performed using magnication.
      * \see setScaleLocked()
-     * \since QGIS 2.16
      */
-    bool scaleLocked() const { return mScaleLocked;}
+    bool scaleLocked() const { return mScaleLocked; }
 
     //! used to determine if anti-aliasing is enabled or not
     void enableAntiAliasing( bool flag );
@@ -679,7 +686,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * Enables a preview mode for the map canvas
      * \param previewEnabled set to TRUE to enable a preview mode
      * \see setPreviewMode
-     * \since QGIS 2.3
     */
     void setPreviewModeEnabled( bool previewEnabled );
 
@@ -688,7 +694,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \returns TRUE if a preview mode is currently enabled
      * \see setPreviewModeEnabled
      * \see previewMode
-     * \since QGIS 2.3
     */
     bool previewModeEnabled() const;
 
@@ -699,7 +704,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \see previewMode
      * \see setPreviewModeEnabled
      * \see previewModeEnabled
-     * \since QGIS 2.3
     */
     void setPreviewMode( QgsPreviewEffect::PreviewMode mode );
 
@@ -709,7 +713,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \returns preview mode for map canvas
      * \see setPreviewMode
      * \see previewModeEnabled
-     * \since QGIS 2.3
     */
     QgsPreviewEffect::PreviewMode previewMode() const;
 
@@ -719,7 +722,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      *  (so map tools do not need to test for existence of the instance).
      *
      * Main canvas in QGIS returns an instance which is always up-to-date with the project's snapping configuration.
-     *  \since QGIS 2.8
      */
     QgsSnappingUtils *snappingUtils() const;
 
@@ -729,7 +731,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      *
      * For main canvas in QGIS, do not associate a different instance from the existing one (it is updated from
      * the project's snapping configuration).
-     * \since QGIS 2.8
      */
     void setSnappingUtils( QgsSnappingUtils *utils );
 
@@ -741,7 +742,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \param scope new expression context scope
      * \see expressionContextScope()
      * \see defaultExpressionContextScope()
-     * \since QGIS 2.12
      */
     void setExpressionContextScope( const QgsExpressionContextScope &scope ) { mExpressionContextScope = scope; }
 
@@ -751,7 +751,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * overrides for expression evaluation for the map canvas render.
      * \see setExpressionContextScope()
      * \see defaultExpressionContextScope()
-     * \since QGIS 2.12
      */
     QgsExpressionContextScope &expressionContextScope() { return mExpressionContextScope; }
 
@@ -760,9 +759,11 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \see setExpressionContextScope()
      * \see defaultExpressionContextScope()
      * \note not available in Python bindings
-     * \since QGIS 2.12
      */
-    const QgsExpressionContextScope &expressionContextScope() const { return mExpressionContextScope; } SIP_SKIP
+    const QgsExpressionContextScope &expressionContextScope() const SIP_SKIP
+    {
+      return mExpressionContextScope;
+    }
 
     /**
      * Creates a new scope which contains default variables and functions relating to the map canvas.
@@ -788,33 +789,28 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     /**
      * Returns a list of all annotation items in the canvas.
-     * \since QGIS 3.0
      */
-    QList< QgsMapCanvasAnnotationItem *> annotationItems() const;
+    QList<QgsMapCanvasAnnotationItem *> annotationItems() const;
 
     /**
      * Returns TRUE if annotations are visible within the map canvas.
      * \see setAnnotationsVisible()
-     * \since QGIS 3.0
      */
     bool annotationsVisible() const { return mAnnotationsVisible; }
 
     /**
      * Sets whether annotations are \a visible in the canvas.
      * \see annotationsVisible()
-     * \since QGIS 3.0
      */
     void setAnnotationsVisible( bool visible );
 
     /**
      * Sets global labeling engine settings in the internal map settings
-     * \since QGIS 3.0
      */
     void setLabelingEngineSettings( const QgsLabelingEngineSettings &settings );
 
     /**
      * Returns global labeling engine settings from the internal map settings
-     * \since QGIS 3.0
      */
     const QgsLabelingEngineSettings &labelingEngineSettings() const;
 
@@ -824,7 +820,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * out-of-canvas areas when panning or zooming out the map) are enabled
      * for the canvas.
      * \see setPreviewJobsEnabled()
-     * \since QGIS 3.0
      */
     bool previewJobsEnabled() const;
 
@@ -834,7 +829,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * out-of-canvas areas when panning or zooming out the map) are \a enabled
      * for the canvas.
      * \see previewJobsEnabled()
-     * \since QGIS 3.0
      */
     void setPreviewJobsEnabled( bool enabled );
 
@@ -843,7 +837,7 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \note Not available in Python bindings
      * \since QGIS 3.10
      */
-    void setCustomDropHandlers( const QVector<QPointer<QgsCustomDropHandler >> &handlers ) SIP_SKIP;
+    void setCustomDropHandlers( const QVector<QPointer<QgsCustomDropHandler>> &handlers ) SIP_SKIP;
 
     /**
      * Set datetime \a range for the map canvas.
@@ -915,7 +909,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * \note Consider using the less expensive redrawAllLayers() method if a layer reload
      * from the data provider is not required.
      *
-     * \since QGIS 2.9
      */
     void refreshAllLayers();
 
@@ -949,7 +942,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     /**
      * stop rendering (if there is any right now)
-     * \since QGIS 2.4
      */
     void stopRendering();
 
@@ -965,14 +957,12 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * in order to render marker point, labels, ... bigger.
      * \param factor The factor of magnification
      * \param center Optional point to re-center the map
-     * \since QGIS 2.16
      */
     void setMagnificationFactor( double factor, const QgsPointXY *center = nullptr );
 
     /**
      * Lock the scale, so zooming can be performed using magnication
      * \see scaleLocked()
-     * \since QGIS 2.16
      */
     void setScaleLocked( bool isLocked );
 
@@ -1070,7 +1060,7 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     void xyCoordinates( const QgsPointXY &p );
 
     //! Emitted when the scale of the map changes
-    void scaleChanged( double );
+    void scaleChanged( double scale );
 
     /**
      * Emitted when the scale locked state of the map changes
@@ -1086,19 +1076,16 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     /**
      * Emitted when the rotation of the map changes
-     * \since QGIS 2.8
      */
-    void rotationChanged( double );
+    void rotationChanged( double rotation );
 
     /**
      * Emitted when the scale of the map changes
-     * \since QGIS 2.16
      */
-    void magnificationChanged( double );
+    void magnificationChanged( double magnification );
 
     /**
      * Emitted when canvas background color changes
-     * \since QGIS 3.0
      */
     void canvasColorChanged();
 
@@ -1114,7 +1101,7 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * - anything related to rendering progress is not visible outside of map canvas
      * - additional drawing shall be done directly within the renderer job or independently as a map canvas item
      */
-    void renderComplete( QPainter * );
+    void renderComplete( QPainter *painter );
 
     // ### QGIS 3: renamte to mapRefreshFinished()
     //! Emitted when canvas finished a refresh request.
@@ -1141,7 +1128,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     /**
      * Emit map tool changed with the old tool
-     * \since QGIS 2.3
      */
     void mapToolSet( QgsMapTool *newTool, QgsMapTool *oldTool );
 
@@ -1153,44 +1139,39 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     void selectionChanged( QgsMapLayer *layer );
 
     //! Emitted when zoom last status changed
-    void zoomLastStatusChanged( bool );
+    void zoomLastStatusChanged( bool available );
 
     //! Emitted when zoom next status changed
-    void zoomNextStatusChanged( bool );
+    void zoomNextStatusChanged( bool available );
 
     /**
      * Emitted when map CRS has changed
-     * \since QGIS 2.4
      */
     void destinationCrsChanged();
 
     /**
      * Emitted when the canvas transform context is changed.
-     * \since QGIS 3.0
      */
     void transformContextChanged();
 
     /**
      * Emitted when the current layer is changed
-     * \since QGIS 2.8
      */
     void currentLayerChanged( QgsMapLayer *layer );
 
     /**
      * Emitted when the configuration of overridden layer styles changes
-     * \since QGIS 2.12
      */
     void layerStyleOverridesChanged();
 
     /**
      * Emitted when the canvas has been assigned a different map theme.
      * \see setTheme()
-     * \since QGIS 3.0
      */
     void themeChanged( const QString &theme );
 
     //! emit a message (usually to be displayed in a message bar)
-    void messageEmitted( const QString &title, const QString &message, Qgis::MessageLevel = Qgis::MessageLevel::Info );
+    void messageEmitted( const QString &title, const QString &message, Qgis::MessageLevel level = Qgis::MessageLevel::Info );
 
     /**
      * Emitted whenever an error is encountered during a map render operation.
@@ -1245,7 +1226,6 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     void contextMenuAboutToShow( QMenu *menu, QgsMapMouseEvent *event );
 
   protected:
-
     bool event( QEvent *e ) override;
     void keyPressEvent( QKeyEvent *e ) override;
     void keyReleaseEvent( QKeyEvent *e ) override;
@@ -1307,13 +1287,12 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     void temporalControllerModeChanged();
 
   private:
-
     // Restore scale RAII
     class ScaleRestorer
     {
       public:
-        ScaleRestorer( QgsMapCanvas *canvas ):
-          mCanvas( canvas )
+        ScaleRestorer( QgsMapCanvas *canvas )
+          : mCanvas( canvas )
         {
           mLockedScale = mCanvas->mapSettings().scale();
         };
@@ -1330,6 +1309,16 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
         double mLockedScale;
     };
 
+    enum class CacheInvalidationType
+    {
+      Temporal = 1 << 0,
+      Elevation = 1 << 1,
+    };
+
+    QgsOverlayWidgetLayout *mLayout = nullptr;
+
+    Qgis::MapCanvasFlags mFlags;
+
     //! encompases all map settings necessary for map rendering
     QgsMapSettings mSettings;
 
@@ -1356,8 +1345,10 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     //! determines whether user has requested to suppress rendering
     bool mRenderFlag = true;
 
+    QFlags<CacheInvalidationType> mCacheInvalidations;
+
     //! current layer in legend
-    QPointer< QgsMapLayer > mCurrentLayer;
+    QPointer<QgsMapLayer> mCurrentLayer;
 
     //! graphics scene manages canvas items
     QGraphicsScene *mScene = nullptr;
@@ -1365,14 +1356,11 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     //! pointer to current map tool
     QgsMapTool *mMapTool = nullptr;
 
-    //! previous tool if current is for zooming/panning
-    QgsMapTool *mLastNonZoomMapTool = nullptr;
-
     //! Pointer to project linked to this canvas
     QgsProject *mProject = nullptr;
 
     //! recently used extent
-    QList <QgsRectangle> mLastExtent;
+    QList<QgsRectangle> mLastExtent;
     int mLastExtentIndex = -1;
 
     //! Scale factor multiple for default zoom in/out
@@ -1388,7 +1376,7 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     bool mJobCanceled = false;
 
     //! Labeling results from the recently rendered map
-    std::unique_ptr< QgsLabelingResults > mLabelingResults;
+    std::unique_ptr<QgsLabelingResults> mLabelingResults;
 
     //! TRUE if the labeling results stored in mLabelingResults are outdated (e.g. as a result of an ongoing canvas render)
     bool mLabelingResultsOutdated = false;
@@ -1397,13 +1385,13 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * Rendered results from the recently rendered map.
      * \since QGIS 3.22
      */
-    std::unique_ptr< QgsRenderedItemResults > mRenderedItemResults;
+    std::unique_ptr<QgsRenderedItemResults> mRenderedItemResults;
 
     /**
      * Rendered results stored from previously rendered maps
      * \since QGIS 3.22
      */
-    std::unique_ptr< QgsRenderedItemResults > mPreviousRenderedItemResults;
+    std::unique_ptr<QgsRenderedItemResults> mPreviousRenderedItemResults;
 
     /**
      * TRUE if the rendered item results stored in mRenderedItemResults are outdated (e.g. as a result of an ongoing canvas render)
@@ -1430,7 +1418,7 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     QgsSnappingUtils *mSnappingUtils = nullptr;
 
-    QList< QgsMapRendererQImageJob * > mPreviewJobs;
+    QList<QgsMapRendererQImageJob *> mPreviewJobs;
 
     //! lock the scale, so zooming can be performed using magnication
     bool mScaleLocked = false;
@@ -1444,7 +1432,7 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
     bool mZoomDragging = false;
 
     //! Zoom by rectangle rubber band
-    std::unique_ptr< QgsRubberBand > mZoomRubberBand;
+    std::unique_ptr<QgsRubberBand> mZoomRubberBand;
 
     QCursor mZoomCursor;
 
@@ -1461,20 +1449,20 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     bool mUsePreviewJobs = false;
 
-    QHash< QString, int > mLastLayerRenderTime;
+    QHash<QString, int> mLastLayerRenderTime;
 
-    QVector<QPointer<QgsCustomDropHandler >> mDropHandlers;
+    QVector<QPointer<QgsCustomDropHandler>> mDropHandlers;
 
     QgsDistanceArea mDa;
     QList<double> mZoomResolutions;
 
-    QList< QgsMapCanvasInteractionBlocker * > mInteractionBlockers;
+    QList<QgsMapCanvasInteractionBlocker *> mInteractionBlockers;
 
     int mBlockItemPositionUpdates = 0;
     int mBlockExtentChangedSignal = 0;
     int mBlockScaleChangedSignal = 0;
 
-    std::unique_ptr< QgsTemporaryCursorOverride > mTemporaryCursorOverride;
+    std::unique_ptr<QgsTemporaryCursorOverride> mTemporaryCursorOverride;
 
     /**
      * This attribute maps error strings occurred during rendering with time.
@@ -1483,10 +1471,10 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
      * in a short time range (\see notifyRendererErrors())
      *
      */
-    QMap <QString, QDateTime> mRendererErrors;
+    QMap<QString, QDateTime> mRendererErrors;
 
 
-    QPointer< QgsAbstract2DMapController > mMapController;
+    QPointer<QgsAbstract2DMapController> mMapController;
 
     /**
      * Returns the last cursor position on the canvas in geographical coordinates
@@ -1496,21 +1484,18 @@ class GUI_EXPORT QgsMapCanvas : public QGraphicsView, public QgsExpressionContex
 
     /**
      * Force a resize of the map canvas item
-     * \since QGIS 2.16
      */
     void updateMapSize();
 
     /**
      * Starts zooming via rectangle
      * \param pos start position for rectangle
-     * \since QGIS 2.16
      */
     void beginZoomRect( QPoint pos );
 
     /**
      * Ends zooming via rectangle
      * \param pos end position for rectangle
-     * \since QGIS 2.16
      */
     void endZoomRect( QPoint pos );
 
