@@ -22,13 +22,11 @@
 #include <QSqlQuery>
 
 
-struct QgssMssqlProviderResultIterator: public QgsAbstractDatabaseProviderConnection::QueryResult::QueryResultIterator
+struct QgssMssqlProviderResultIterator : public QgsAbstractDatabaseProviderConnection::QueryResult::QueryResultIterator
 {
-
     QgssMssqlProviderResultIterator( bool resolveTypes, int columnCount, std::unique_ptr<QSqlQuery> query );
 
   private:
-
     bool mResolveTypes = true;
     int mColumnCount = 0;
     std::unique_ptr<QSqlQuery> mQuery;
@@ -48,29 +46,21 @@ class QgsMssqlProviderConnection : public QgsAbstractDatabaseProviderConnection
 
 {
   public:
-
     QgsMssqlProviderConnection( const QString &name );
     QgsMssqlProviderConnection( const QString &uri, const QVariantMap &configuration );
 
     // QgsAbstractProviderConnection interface
 
   public:
-
-    void createVectorTable( const QString &schema,
-                            const QString &name,
-                            const QgsFields &fields,
-                            QgsWkbTypes::Type wkbType,
-                            const QgsCoordinateReferenceSystem &srs, bool overwrite,
-                            const QMap<QString, QVariant> *options ) const override;
+    void createVectorTable( const QString &schema, const QString &name, const QgsFields &fields, Qgis::WkbType wkbType, const QgsCoordinateReferenceSystem &srs, bool overwrite, const QMap<QString, QVariant> *options ) const override;
 
     QString tableUri( const QString &schema, const QString &name ) const override;
     void dropVectorTable( const QString &schema, const QString &name ) const override;
     void createSchema( const QString &name ) const override;
     void dropSchema( const QString &name, bool force = false ) const override;
     QgsAbstractDatabaseProviderConnection::QueryResult execSql( const QString &sql, QgsFeedback *feedback ) const override;
-    QList<QgsAbstractDatabaseProviderConnection::TableProperty> tables( const QString &schema,
-        const TableFlags &flags = TableFlags() ) const override;
-    QStringList schemas( ) const override;
+    QList<QgsAbstractDatabaseProviderConnection::TableProperty> tables( const QString &schema, const TableFlags &flags = TableFlags(), QgsFeedback *feedback = nullptr ) const override;
+    QStringList schemas() const override;
     void store( const QString &name ) const override;
     void remove( const QString &name ) const override;
     QIcon icon() const override;
@@ -78,16 +68,13 @@ class QgsMssqlProviderConnection : public QgsAbstractDatabaseProviderConnection
     QgsProviderSqlQueryBuilder *queryBuilder() const override;
 
   private:
-
     QgsAbstractDatabaseProviderConnection::QueryResult executeSqlPrivate( const QString &sql, bool resolveTypes = true, QgsFeedback *feedback = nullptr ) const;
     void setDefaultCapabilities();
     void dropTablePrivate( const QString &schema, const QString &name ) const;
     void renameTablePrivate( const QString &schema, const QString &name, const QString &newName ) const;
 
     static const QStringList EXTRA_CONNECTION_PARAMETERS;
-
 };
 
 
-
 #endif // QGSMSSQLPROVIDERCONNECTION_H
