@@ -20,7 +20,7 @@
 #include "qgis_server.h"
 #include "qgsserverquerystringparameter.h"
 #include "qgsserverogcapi.h"
-#include "nlohmann/json_fwd.hpp"
+#include <nlohmann/json_fwd.hpp>
 #include "inja/inja.hpp"
 
 #ifndef SIP_RUN
@@ -93,9 +93,7 @@ class QgsServerApiContext;
  */
 class SERVER_EXPORT QgsServerOgcApiHandler
 {
-
   public:
-
     virtual ~QgsServerOgcApiHandler();
 
     // /////////////////////////////////////////////
@@ -121,7 +119,11 @@ class SERVER_EXPORT QgsServerOgcApiHandler
      * Depending on the handler, it may be dynamic (per-request) or static.
      * \param context the request context
      */
-    virtual QList<QgsServerQueryStringParameter> parameters( const QgsServerApiContext &context ) const  { Q_UNUSED( context ); return { }; }
+    virtual QList<QgsServerQueryStringParameter> parameters( const QgsServerApiContext &context ) const
+    {
+      Q_UNUSED( context );
+      return {};
+    }
 
     // /////////////////////////////////////////////
     // METADATA Sections (informative)
@@ -197,7 +199,7 @@ class SERVER_EXPORT QgsServerOgcApiHandler
     // /////////////////////////////////////////////////////
     // Utility methods: override should not be required
 
-#ifndef SIP_RUN  // Skip SIP
+#ifndef SIP_RUN // Skip SIP
 
     /**
      * Writes \a data to the \a context response stream, content-type is calculated from the \a context request,
@@ -212,13 +214,14 @@ class SERVER_EXPORT QgsServerOgcApiHandler
      * Available custom template functions:
      *
      * - path_append( path ): appends a directory path to the current url
-     * - path_chomp( n ):removes the specified number "n" of directory components from the current url path
+     * - path_chomp( n ): removes the specified number "n" of directory components from the current url path
      * - json_dump( ): prints current JSON data passed to the template
      * - static( path ): returns the full URL to the specified static path, for example:
-     *   static( "/style/black.css" ) will return something like "/wfs3/static/style/black.css".
-     * - links_filter( links, key, value ): Returns filtered links from a link list
-     * - content_type_name( content_type ): Returns a short name from a content type for example "text/html" will return "HTML"
-     * - nl2br( text ): Returns the input text with all newlines replaced by "<br>" tags
+     *   static( "/style/black.css" ) will return something like "/wfs3/static/style/black.css"
+     * - links_filter( links, key, value ): returns filtered links from a link list
+     * - content_type_name( content_type ): returns a short name from a content type for example "text/html" will return "HTML"
+     * - nl2br( text ): returns the input text with all newlines replaced by "<br>" tags
+     * - starts_with( string, prefix ): returns true if a string begins with the provided string prefix, false otherwise
      *
      * \note not available in Python bindings
      */
@@ -258,10 +261,7 @@ class SERVER_EXPORT QgsServerOgcApiHandler
      * \param title title of the link
      * \note not available in Python bindings
      */
-    json link( const QgsServerApiContext &context,
-               const QgsServerOgcApi::Rel &linkType = QgsServerOgcApi::Rel::self,
-               const QgsServerOgcApi::ContentType contentType = QgsServerOgcApi::ContentType::JSON,
-               const std::string &title = "" ) const;
+    json link( const QgsServerApiContext &context, const QgsServerOgcApi::Rel &linkType = QgsServerOgcApi::Rel::self, const QgsServerOgcApi::ContentType contentType = QgsServerOgcApi::ContentType::JSON, const std::string &title = "" ) const;
 
     /**
      * Returns all the links for the given request \a context.
@@ -285,7 +285,7 @@ class SERVER_EXPORT QgsServerOgcApiHandler
      */
     QgsVectorLayer *layerFromContext( const QgsServerApiContext &context ) const;
 
-#endif  // SIP skipped
+#endif // SIP skipped
 
     /**
      * Writes \a data to the \a context response stream, content-type is calculated from the \a context request,
@@ -301,11 +301,13 @@ class SERVER_EXPORT QgsServerOgcApiHandler
      *
      * - path_append( path ): appends a directory path to the current url
      * - path_chomp( n ): removes the specified number "n" of directory components from the current url path
-     * - json_dump(): prints current JSON data passed to the template
-     * - static( path): returns the full URL to the specified static path, for example:
-     *   static("/style/black.css") will return something like "/wfs3/static/style/black.css".
+     * - json_dump( ): prints current JSON data passed to the template
+     * - static( path ): returns the full URL to the specified static path, for example:
+     *   static( "/style/black.css" ) will return something like "/wfs3/static/style/black.css"
      * - links_filter( links, key, value ): returns filtered links from a link list
      * - content_type_name( content_type ): returns a short name from a content type for example "text/html" will return "HTML"
+     * - nl2br( text ): returns the input text with all newlines replaced by "<br>" tags
+     * - starts_with( string, prefix ): returns true if a string begins with the provided string prefix, false otherwise
      *
      */
     void write( QVariant &data, const QgsServerApiContext &context, const QVariantMap &htmlMetadata = QVariantMap() ) const SIP_THROW( QgsServerApiBadRequestException );
@@ -372,10 +374,9 @@ class SERVER_EXPORT QgsServerOgcApiHandler
      *
      * \note not available in Python bindings
      */
-    json jsonTags( ) const SIP_SKIP;
+    json jsonTags() const SIP_SKIP;
 
   protected:
-
     /**
      * Set the content types to \a contentTypes
      */
@@ -388,11 +389,8 @@ class SERVER_EXPORT QgsServerOgcApiHandler
     void setContentTypes( const QList<QgsServerOgcApi::ContentType> &contentTypes ) SIP_SKIP;
 
   private:
-
     //! List of content types this handler can serve, first is the default
     QList<QgsServerOgcApi::ContentType> mContentTypes = { QgsServerOgcApi::ContentType::JSON, QgsServerOgcApi::ContentType::HTML };
-
-
 };
 
 #endif // QGSSERVEROGCAPIHANDLER_H
