@@ -9,6 +9,7 @@ it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 """
+
 import os
 import random
 import string
@@ -24,13 +25,13 @@ from qgis.core import (
 import unittest
 from qgis.testing import start_app, QgisTestCase
 
-__author__ = 'Alessandro Pasotti'
-__date__ = '27/09/2017'
-__copyright__ = 'Copyright 2017, The QGIS Project'
+__author__ = "Alessandro Pasotti"
+__date__ = "27/09/2017"
+__copyright__ = "Copyright 2017, The QGIS Project"
 
 QGIS_AUTH_DB_DIR_PATH = tempfile.mkdtemp()
 
-os.environ['QGIS_AUTH_DB_DIR_PATH'] = QGIS_AUTH_DB_DIR_PATH
+os.environ["QGIS_AUTH_DB_DIR_PATH"] = QGIS_AUTH_DB_DIR_PATH
 
 qgis_app = start_app()
 
@@ -45,14 +46,16 @@ class TestAuthManager(QgisTestCase):
         # Enable auth
         # os.environ['QGIS_AUTH_PASSWORD_FILE'] = QGIS_AUTH_PASSWORD_FILE
         authm = QgsApplication.authManager()
-        assert (authm.setMasterPassword('masterpassword', True))
-        cls.auth_config = QgsAuthMethodConfig('Basic')
-        cls.auth_config.setName('test_auth_config')
-        cls.username = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(6))
+        assert authm.setMasterPassword("masterpassword", True)
+        cls.auth_config = QgsAuthMethodConfig("Basic")
+        cls.auth_config.setName("test_auth_config")
+        cls.username = "".join(
+            random.choice(string.ascii_uppercase + string.digits) for _ in range(6)
+        )
         cls.password = cls.username[::-1]  # reversed
-        cls.auth_config.setConfig('username', cls.username)
-        cls.auth_config.setConfig('password', cls.password)
-        assert (authm.storeAuthenticationConfig(cls.auth_config)[0])
+        cls.auth_config.setConfig("username", cls.username)
+        cls.auth_config.setConfig("password", cls.password)
+        assert authm.storeAuthenticationConfig(cls.auth_config)[0]
 
     @classmethod
     def tearDownClass(cls):
@@ -75,8 +78,8 @@ class TestAuthManager(QgisTestCase):
         authm = QgsApplication.authManager()
         nam = QgsNetworkAccessManager.instance()
         proxy = nam.proxy()
-        self.assertEqual(proxy.password(), '')
-        self.assertEqual(proxy.user(), '')
+        self.assertEqual(proxy.password(), "")
+        self.assertEqual(proxy.user(), "")
         self.assertTrue(authm.updateNetworkProxy(proxy, self.auth_config.id()))
         self.assertEqual(proxy.user(), self.username)
         self.assertEqual(proxy.password(), self.password)
@@ -88,17 +91,17 @@ class TestAuthManager(QgisTestCase):
         nam = QgsNetworkAccessManager.instance()
         nam.setupDefaultProxyAndCache()
         proxy = nam.proxy()
-        self.assertEqual(proxy.password(), '')
-        self.assertEqual(proxy.user(), '')
+        self.assertEqual(proxy.password(), "")
+        self.assertEqual(proxy.user(), "")
         settings = QgsSettings()
         settings.setValue("proxy/authcfg", self.auth_config.id())
         settings.setValue("proxy/proxyEnabled", True)
-        del (settings)
+        del settings
         nam.setupDefaultProxyAndCache()
         proxy = nam.fallbackProxy()
         self.assertEqual(proxy.password(), self.password)
         self.assertEqual(proxy.user(), self.username)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
